/**
 * ==============================================
 *  DQL : Descartes Query Language
 * ==============================================
 *
 * (c) Copyright 2014-2016, by Juergen Walter, Fabian Gorsler, Fabian Brosig and other contributors.
 *
 * Project Info:   http://descartes.tools/dql
 *
 * All rights reserved. This software is made available under the terms of the
 * Eclipse Public License (EPL) v1.0 as published by the Eclipse Foundation
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * This software is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the Eclipse Public License (EPL)
 * for more details.
 *
 * You should have received a copy of the Eclipse Public License (EPL)
 * along with this software; if not visit http://www.eclipse.org or write to
 * Eclipse Foundation, Inc., 308 SW First Avenue, Suite 110, Portland, 97204 USA
 * Email: license (at) eclipse.org
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
 * in the United States and other countries.]
 */
package tools.descartes.dql.connector.nop;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Map.Entry;

import org.eclipse.emf.ecore.util.EcoreUtil;

import tools.descartes.dql.connector.ModelStructureQueryConnector;
import tools.descartes.dql.models.mapping.domain.DoF;
import tools.descartes.dql.models.mapping.domain.DomainFactory;
import tools.descartes.dql.models.mapping.domain.Entity;
import tools.descartes.dql.models.mapping.domain.Probe;
import tools.descartes.dql.models.mapping.domain.StatType;
import tools.descartes.dql.models.mapping.mapping.EntityMapping;

public class ModelStructureQueryConnectorImpl extends AbstractNopQueryConnector implements ModelStructureQueryConnector {

	private final DomainFactory domainFactory = DomainFactory.eINSTANCE;
	
	@Override
	public EntityMapping requestDoF(final EntityMapping request) {
		for (Entry<String, String> entry : getDofMap().entrySet())
			addDoF(request, entry.getKey(), entry.getValue());
		return request;
	}

	private void addDoF(EntityMapping request, String identifier, String currentState) {
		DoF dof1 = domainFactory.createDoF();
		dof1.setIdentifier(identifier);
		dof1.setCurrentState(currentState);
		request.getDoF().add(dof1);
	}

	@Override
	public EntityMapping requestEntities(final EntityMapping request) {
		final EntityMapping response = EcoreUtil.copy(request);
		final List<Entity> resources = response.getEntities();

		resources.add(createEntity("res1", domainFactory, "RESOURCE"));
		resources.add(createEntity("res2", domainFactory, "RESOURCE"));
		resources.add(createEntity("res1", domainFactory, "MISC"));
		Entity parent = createEntity("parent", domainFactory, "MISCA");
		Entity child1 = createEntity("child1", domainFactory, "MISCB");
		Entity child2 = createEntity("child2", domainFactory, "MISCC");
		resources.add(parent);
		resources.add(child1);
		resources.add(child2);
		parent.getChildren().add(child1);
		parent.getChildren().add(child2);
		child1.setParent(parent);
		child2.setParent(parent);
		Entity grandChild = createEntity("grandChild", domainFactory, "MISCD");
		resources.add(grandChild);
		grandChild.setParent(child1);
		child1.getChildren().add(grandChild);
		return response;
	}

	@Override
	public EntityMapping requestProbes(final EntityMapping request) {
		final EntityMapping response = EcoreUtil.copy(request);

		for (final Entity entity : response.getEntities()) {
			final Probe aProbe = createStringProbe(domainFactory);
			final Probe bProbe = createProbeWithStatTypes(domainFactory);
			final Probe cProbe = createContinuousSeriesProbe(domainFactory);
			final Probe dProbe = createDiscreteSeriesProbe(domainFactory);
			final Probe eProbe = createListOfContinuousSeriesProbe(domainFactory);
			final Probe fProbe = createOnlineSeriesProbe(domainFactory);
			final Probe gProbe = createPieSeriesProbe(domainFactory);
			entity.getProbes().add(aProbe);
			entity.getProbes().add(bProbe);
			entity.getProbes().add(cProbe);
			entity.getProbes().add(dProbe);
			entity.getProbes().add(eProbe);
			entity.getProbes().add(fProbe);
			entity.getProbes().add(gProbe);
				
			for (int i = 0; i < 3; i++) {
				final Probe decimalProbe = createDecimalProbe(domainFactory, i + 1);
				entity.getProbes().add(decimalProbe);
			}
		}

		return response;
	}

	private Probe createProbeWithStatTypes(DomainFactory domainFactory2) {
		Probe p = domainFactory2.createProbe();
		p.setMetricName("metricWithStatTypes");
		StatType st1 = domainFactory2.createStatType();
		st1.setTypeName("min");
		p.getStatTypes().add(st1);
		StatType st2 = domainFactory2.createStatType();
		st2.setTypeName("max");
		p.getStatTypes().add(st2);
		StatType st3 = domainFactory2.createStatType();
		st3.setTypeName("sample");
		p.getStatTypes().add(st3);
		return p;
	}

	@Override
	public boolean supportsDoFRequests() {
		return true;
	}

	@Override
	public boolean supportsEntityRequests() {
		return true;
	}

	@Override
	public boolean supportsProbeRequests() {
		return true;
	}

	public static Map<String, String> getDofMap() {
		Map<String, String> dofsWithDefault = new HashMap<String, String>();
		dofsWithDefault.put("ServerCount", "2");
		dofsWithDefault.put("UserCount", "50");
		dofsWithDefault.put("CPUFreq", "10");
		dofsWithDefault.put("RAM", "128");
		dofsWithDefault.put("ResourceDemandPerUser", "1");
		return dofsWithDefault;
	}
}
