/**
 * ==============================================
 *  DQL : Descartes Query Language
 * ==============================================
 *
 * (c) Copyright 2014-2016, by Juergen Walter, Fabian Gorsler, Fabian Brosig and other contributors.
 *
 * Project Info:   http://descartes.tools/dql
 *
 * All rights reserved. This software is made available under the terms of the
 * Eclipse Public License (EPL) v1.0 as published by the Eclipse Foundation
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * This software is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the Eclipse Public License (EPL)
 * for more details.
 *
 * You should have received a copy of the Eclipse Public License (EPL)
 * along with this software; if not visit http://www.eclipse.org or write to
 * Eclipse Foundation, Inc., 308 SW First Avenue, Suite 110, Portland, 97204 USA
 * Email: license (at) eclipse.org
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
 * in the United States and other countries.]
 */
/*
 * generated by Xtext
 */
package tools.descartes.dql.lang.ui.contentassist;

import java.util.HashMap;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

import org.eclipse.emf.common.util.EList;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.util.EcoreUtil;
import org.eclipse.xtext.Assignment;
import org.eclipse.xtext.RuleCall;
import org.eclipse.xtext.ui.editor.contentassist.ContentAssistContext;
import org.eclipse.xtext.ui.editor.contentassist.ICompletionProposalAcceptor;
import org.eclipse.xtext.util.Tuples;
import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceReference;

import tools.descartes.dql.core.engine.interpreter.DefaultProvider;
import tools.descartes.dql.core.engine.query.QueryExecutionEngine;
import tools.descartes.dql.core.engine.query.QueryExecutionEngineImpl;
import tools.descartes.dql.core.registry.ConnectorRegistry;
import tools.descartes.dql.lang.descartesQL.AliasClause;
import tools.descartes.dql.lang.descartesQL.DescartesQL;
import tools.descartes.dql.lang.descartesQL.DescartesQLFactory;
import tools.descartes.dql.lang.descartesQL.EntityReference;
import tools.descartes.dql.lang.descartesQL.EntityReferenceClause;
import tools.descartes.dql.lang.descartesQL.ForClause;
import tools.descartes.dql.lang.descartesQL.ListQuery;
import tools.descartes.dql.lang.descartesQL.MetricReference;
import tools.descartes.dql.lang.descartesQL.SelectQuery;
import tools.descartes.dql.lang.descartesQL.UsingClause;
import tools.descartes.dql.lang.ui.internal.DescartesQLActivator;
import tools.descartes.dql.models.mapping.domain.Entity;
import tools.descartes.dql.models.mapping.domain.Probe;
import tools.descartes.dql.models.mapping.mapping.EntityMapping;

/**
 * see
 * http://www.eclipse.org/Xtext/documentation/latest/xtext.html#contentAssist on
 * how to customize content assistant
 */
public class DescartesQLProposalProvider extends AbstractDescartesQLProposalProvider {
	private final BundleContext context = DescartesQLActivator.getInstance().getBundle().getBundleContext();
	private ConnectorRegistry registry = null;
	private final DescartesQLFactory dqlFactory = DescartesQLFactory.eINSTANCE;

	@Override
	public void completeEntityReference_Type(EObject model, Assignment assignment, ContentAssistContext context,
			ICompletionProposalAcceptor acceptor) {
		super.completeRuleCall(((RuleCall) assignment.getTerminal()), context, acceptor);
		UsingClause uc = getUsingClause(context.getCurrentModel().eContainer());
		DefaultProvider dp = new DefaultProvider(uc);
		for (String entityType : dp.getAllEntityTypes())
			acceptor.accept(createCompletionProposal(entityType, context));
	}

	@Override
	public void completeEntityReference_Identifier(final EObject model, final Assignment assignment,
			final ContentAssistContext context, final ICompletionProposalAcceptor acceptor) {
		super.completeEntityReference_Identifier(model, assignment, context, acceptor);
		UsingClause uc = getUsingClause(context.getCurrentModel());
		DefaultProvider dp = new DefaultProvider(uc);
		String entityType = getEntityType(context.getCurrentModel());

		for (Entity e : dp.getAllEntities())
			if (entityType == null || entityType.equals(e.getEntityType()))
				acceptor.accept(createCompletionProposal("'" + e.getIdentifier() + "'", context));
	}

	private String getEntityType(EObject currentModel) {
		if (currentModel instanceof EntityReference)
			return ((EntityReference) currentModel).getType();
		if (currentModel instanceof ForClause) {
			EntityReferenceClause erc = ((ForClause) currentModel).getEntityReferenceClause();
			erc.getEntityReferences().get(0).getType();
		}
		return null;
	}

	private UsingClause getUsingClause(EObject model) {
		if (model instanceof SelectQuery)
			return ((SelectQuery) model).getUsingClause();
		if (model instanceof ListQuery)
			return ((ListQuery) model).getUsingClause();
		if (model.eContainer() != null)
			return getUsingClause(model.eContainer());
		throw new IllegalStateException("Unknown Querytype");
	}

	@Override
	public void completeMetricReference_StatTypeReference(EObject model, Assignment assignment,
			ContentAssistContext context, ICompletionProposalAcceptor acceptor) {
		SelectQuery sq = getSelectQuery(context.getCurrentModel());
		MetricReference mr = getMetricReference(context.getCurrentModel());
		if (mr.getEntityReference() == null && mr.getMetricReference() == null)
			return;
		ForClause fc = sq.getForClause();
		if (fc == null)
			return;
		EntityReferenceClause erc = fc.getEntityReferenceClause();
		String identifier = null;
		String entityType = null;
		for (EntityReference er : erc.getEntityReferences())
			if (er.getAlias().getAlias().equals(mr.getEntityReference())) {
				identifier = er.getIdentifier();
				entityType = er.getType();
			}
		UsingClause uc = getUsingClause(context.getCurrentModel());
		DefaultProvider dp = new DefaultProvider(uc);
		for (String statType : dp.getAllStatTypes(Tuples.create(entityType, identifier), mr.getMetricReference()))
			acceptor.accept(createCompletionProposal(statType, context));
	}

	private MetricReference getMetricReference(EObject currentModel) {
		if (currentModel instanceof MetricReference)
			return (MetricReference) currentModel;
		if (currentModel.eContainer() != null)
			return getMetricReference(currentModel.eContainer());
		throw new IllegalStateException("Unknown Querytype");
	}

	@Override
	public void complete_ModelFamily(final EObject model, final RuleCall ruleCall, final ContentAssistContext context,
			final ICompletionProposalAcceptor acceptor) {
		super.complete_ModelFamily(model, ruleCall, context, acceptor);

		for (final String modelFamily : retrieveSupportedModelFamilies()) {
			acceptor.accept(createCompletionProposal(modelFamily, context));
		}
	}

	@Override
	public void completeMetricReference_EntityReference(final EObject model, final Assignment assignment,
			final ContentAssistContext context, final ICompletionProposalAcceptor acceptor) {
		super.completeMetricReference_EntityReference(model, assignment, context, acceptor);

		SelectQuery sq = getSelectQuery(context.getCurrentModel());
		ForClause fc = sq.getForClause();
		if (fc == null)
			return;
		EntityReferenceClause erc = fc.getEntityReferenceClause();
		for (EntityReference er : erc.getEntityReferences())
			if (er.getAlias() != null)
				acceptor.accept(createCompletionProposal(er.getAlias().getAlias(), context));
	}

	private SelectQuery getSelectQuery(EObject currentModel) {
		if (currentModel instanceof SelectQuery)
			return (SelectQuery) currentModel;
		if (currentModel.eContainer() != null)
			return getSelectQuery(currentModel.eContainer());
		throw new IllegalStateException("Unknown Querytype");
	}

	@Override
	public void completeMetricReference_MetricReference(final EObject model, final Assignment assignment,
			final ContentAssistContext context, final ICompletionProposalAcceptor acceptor) {
		super.completeMetricReference_MetricReference(model, assignment, context, acceptor);
		SelectQuery sq = getSelectQuery(context.getCurrentModel());
		MetricReference mr = getMetricReference(context.getCurrentModel());
		if (mr.getEntityReference() == null)
			return;
		ForClause fc = sq.getForClause();
		if (fc == null)
			return;
		EntityReferenceClause erc = fc.getEntityReferenceClause();
		String identifier = null;
		String entityType = null;
		for (EntityReference er : erc.getEntityReferences())
			if (er.getAlias().getAlias().equals(mr.getEntityReference())) {
				identifier = er.getIdentifier();
				entityType = er.getType();
			}
		UsingClause uc = getUsingClause(context.getCurrentModel());
		DefaultProvider dp = new DefaultProvider(uc);
		for (String metricName : dp.getAllMetrics(Tuples.create(entityType, identifier)))
			acceptor.accept(createCompletionProposal(metricName, context));
	}

	private synchronized void createConnectorRegistryInstance() {
		if (registry != null) {
			return;
		}

		registry = lookupConnectorRegistryInstance();
	}

	private Set<String> filterPrefixes(final Set<String> elements, final String prefix) {
		final Set<String> filteredElements = new HashSet<String>(elements.size());

		if (prefix.isEmpty()) {
			filteredElements.addAll(elements);
		} else {
			for (final String element : elements) {
				if (element.startsWith(prefix)) {
					filteredElements.add(element);
				}
			}
		}

		return filteredElements;
	}

	// Stolen from AbstractQueryInterpreter
	private ConnectorRegistry lookupConnectorRegistryInstance() {
		final ServiceReference<ConnectorRegistry> registryServiceRef = context
				.getServiceReference(ConnectorRegistry.class);
		return context.getService(registryServiceRef);
	}

	private void propose(final ContentAssistContext context, final ICompletionProposalAcceptor acceptor,
			final Set<String> proposals, final String prefix) {
		for (final String alias : proposals) {
			final String proposal = alias.substring(prefix.length());
			acceptor.accept(createCompletionProposal(proposal, alias, null, context));
		}
	}

	private void provideEntityContentAssistEntry(final ContentAssistContext context,
			final ICompletionProposalAcceptor acceptor, final String availableType, final String identifier) {
		final String proposal = "'" + identifier + "'";
		final String displayString = availableType + ": " + identifier;
		acceptor.accept(createCompletionProposal(proposal, displayString, null, context));
	}

	private Set<String> retrieveAliases(final ForClause forClause) {
		final HashSet<String> aliases = new HashSet<String>();

		final EntityReferenceClause entityReferenceClause = forClause.getEntityReferenceClause();

		if (entityReferenceClause == null) {
			return aliases;
		}

		for (final EntityReference e : entityReferenceClause.getEntityReferences()) {
			final AliasClause alias = e.getAlias();

			if (alias != null) {
				aliases.add(alias.getAlias());
			} else {
				aliases.add(e.getIdentifier());
			}
		}

		return aliases;
	}

	private Set<String> retrieveSupportedModelFamilies() {
		createConnectorRegistryInstance();

		return registry.getRegisteredConnectorNames();
	}

	private EntityReference searchForClause(final ForClause forClause, final String entity) {
		if (forClause == null) {
			return null;
		}

		final EntityReferenceClause entityReferenceClause = forClause.getEntityReferenceClause();

		if (entityReferenceClause == null) {
			return null;
		}

		for (final EntityReference e : entityReferenceClause.getEntityReferences()) {
			final String identifier = e.getIdentifier();
			final AliasClause alias = e.getAlias();

			// Found the same identifier
			if (entity.equals(identifier)) {
				return EcoreUtil.copy(e);
			}

			// Found the same alias
			if (alias != null) {
				if (entity.equals(alias.getAlias())) {
					return EcoreUtil.copy(e);
				}
			}

		}

		return null;
	}

	private HashMap<String, Set<String>> submitListEntitiesQuery(final DescartesQL root) {
		final HashMap<String, Set<String>> identifiers = new HashMap<String, Set<String>>(2);
		final QueryExecutionEngine qee = new QueryExecutionEngineImpl();
		final List<EntityMapping> results = qee.execute(root);

		if (qee.isValidQuery()) {
			final EntityMapping result = results.get(0);
			final EList<Entity> resources = result.getEntities();

			for (final Entity r : resources) {
				String type = r.getEntityType();
				if (!identifiers.containsKey(type)) {
					final Set<String> resourceIdentifiers = new HashSet<String>(resources.size());
					resourceIdentifiers.add(r.getIdentifier());
					identifiers.put(type, resourceIdentifiers);
				} else {
					identifiers.get(type).add(r.getIdentifier());
				}
			}

		}

		return identifiers;
	}

	private Set<String> submitListMetricsQuery(final EntityReference entityReference, final DescartesQL metricsQuery) {
		final Set<String> metrics = new HashSet<String>();
		final QueryExecutionEngine qee = new QueryExecutionEngineImpl();
		final List<EntityMapping> results = qee.execute(metricsQuery);

		if (!qee.isValidQuery()) {
			return metrics;
		}

		final EntityMapping result = results.get(0);
		final String type = entityReference.getType();
		Entity resultEntity = null;

		for (Entity e : result.getEntities())
			if ((e.getEntityType() == null && type == null) || e.getEntityType().equals(type))
				resultEntity = e;

		if (resultEntity == null)
			return metrics;

		for (final Probe p : resultEntity.getProbes()) {
			final String retrievedMetricName = p.getMetricName();
			metrics.add(retrievedMetricName);
		}

		return metrics;
	}
}
