/**
 * ==============================================
 *  DQL : Descartes Query Language
 * ==============================================
 * 
 * (c) Copyright 2014-2016, by Juergen Walter, Fabian Gorsler, Fabian Brosig and other contributors.
 * 
 * Project Info:   http://descartes.tools/dql
 * 
 * All rights reserved. This software is made available under the terms of the 
 * Eclipse Public License (EPL) v1.0 as published by the Eclipse Foundation
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * This software is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the Eclipse Public License (EPL)
 * for more details.
 * 
 * You should have received a copy of the Eclipse Public License (EPL)
 * along with this software; if not visit http://www.eclipse.org or write to
 * Eclipse Foundation, Inc., 308 SW First Avenue, Suite 110, Portland, 97204 USA
 * Email: license (at) eclipse.org 
 * 
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
 * in the United States and other countries.]
 */
package tools.descartes.dql.lang.descartesQL.impl;

import org.eclipse.emf.ecore.EAttribute;
import org.eclipse.emf.ecore.EClass;
import org.eclipse.emf.ecore.EEnum;
import org.eclipse.emf.ecore.EPackage;
import org.eclipse.emf.ecore.EReference;

import org.eclipse.emf.ecore.impl.EPackageImpl;

import tools.descartes.dql.lang.descartesQL.AbsoluteTimeClause;
import tools.descartes.dql.lang.descartesQL.AggregateMetricClause;
import tools.descartes.dql.lang.descartesQL.AliasClause;
import tools.descartes.dql.lang.descartesQL.ArithmeticClause;
import tools.descartes.dql.lang.descartesQL.BetweenTimeClause;
import tools.descartes.dql.lang.descartesQL.ChildrenClause;
import tools.descartes.dql.lang.descartesQL.Comparator;
import tools.descartes.dql.lang.descartesQL.ConfigurationPropertiesClause;
import tools.descartes.dql.lang.descartesQL.ConfigurationPropertyClause;
import tools.descartes.dql.lang.descartesQL.ConnectorCapabilityQuery;
import tools.descartes.dql.lang.descartesQL.ConnectorInstanceReferenceClause;
import tools.descartes.dql.lang.descartesQL.ConnectorTimeUnitClause;
import tools.descartes.dql.lang.descartesQL.ConstraintClause;
import tools.descartes.dql.lang.descartesQL.Currency;
import tools.descartes.dql.lang.descartesQL.DescartesQL;
import tools.descartes.dql.lang.descartesQL.DescartesQLFactory;
import tools.descartes.dql.lang.descartesQL.DescartesQLPackage;
import tools.descartes.dql.lang.descartesQL.DetectBottlenecksQuery;
import tools.descartes.dql.lang.descartesQL.DetectQuery;
import tools.descartes.dql.lang.descartesQL.DoFClause;
import tools.descartes.dql.lang.descartesQL.DoFReference;
import tools.descartes.dql.lang.descartesQL.DoFVariationClause;
import tools.descartes.dql.lang.descartesQL.EntityReference;
import tools.descartes.dql.lang.descartesQL.EntityReferenceClause;
import tools.descartes.dql.lang.descartesQL.ExplorationStrategyClause;
import tools.descartes.dql.lang.descartesQL.FilterClause;
import tools.descartes.dql.lang.descartesQL.FilterConditionClause;
import tools.descartes.dql.lang.descartesQL.FilterConditionType;
import tools.descartes.dql.lang.descartesQL.FilterConditionValue;
import tools.descartes.dql.lang.descartesQL.FilterConjunction;
import tools.descartes.dql.lang.descartesQL.FilterigRule;
import tools.descartes.dql.lang.descartesQL.FilteringClause;
import tools.descartes.dql.lang.descartesQL.FilteringStrategy;
import tools.descartes.dql.lang.descartesQL.FindClause;
import tools.descartes.dql.lang.descartesQL.ForClause;
import tools.descartes.dql.lang.descartesQL.Fuzziness;
import tools.descartes.dql.lang.descartesQL.GetConstraintsQuery;
import tools.descartes.dql.lang.descartesQL.GetExplorationStrategiesQuery;
import tools.descartes.dql.lang.descartesQL.GetQuery;
import tools.descartes.dql.lang.descartesQL.GetTimeUnitsQuery;
import tools.descartes.dql.lang.descartesQL.Goal;
import tools.descartes.dql.lang.descartesQL.IntervalVariationClause;
import tools.descartes.dql.lang.descartesQL.ListDoFQuery;
import tools.descartes.dql.lang.descartesQL.ListEntitiesQuery;
import tools.descartes.dql.lang.descartesQL.ListMetricsQuery;
import tools.descartes.dql.lang.descartesQL.ListQuery;
import tools.descartes.dql.lang.descartesQL.MetricClause;
import tools.descartes.dql.lang.descartesQL.MetricClauseType;
import tools.descartes.dql.lang.descartesQL.MetricClauses;
import tools.descartes.dql.lang.descartesQL.MetricReference;
import tools.descartes.dql.lang.descartesQL.MetricReferenceClauses;
import tools.descartes.dql.lang.descartesQL.MetricStarClause;
import tools.descartes.dql.lang.descartesQL.ModelFamily;
import tools.descartes.dql.lang.descartesQL.ModelLocation;
import tools.descartes.dql.lang.descartesQL.ModelReferenceClause;
import tools.descartes.dql.lang.descartesQL.ModelStructureQuery;
import tools.descartes.dql.lang.descartesQL.MultipleArithmeticClause;
import tools.descartes.dql.lang.descartesQL.NavigationClause;
import tools.descartes.dql.lang.descartesQL.ObservationClause;
import tools.descartes.dql.lang.descartesQL.ObserveBetweenClause;
import tools.descartes.dql.lang.descartesQL.ObserveClause;
import tools.descartes.dql.lang.descartesQL.ObserveRelativeClause;
import tools.descartes.dql.lang.descartesQL.ObserveRelativeDirectionType;
import tools.descartes.dql.lang.descartesQL.ParentClause;
import tools.descartes.dql.lang.descartesQL.Penalty;
import tools.descartes.dql.lang.descartesQL.PerformanceIssueQuery;
import tools.descartes.dql.lang.descartesQL.PerformanceMetricsQuery;
import tools.descartes.dql.lang.descartesQL.RelativeTimeClause;
import tools.descartes.dql.lang.descartesQL.RelativeTimeDurationClause;
import tools.descartes.dql.lang.descartesQL.RelativeTimeSignType;
import tools.descartes.dql.lang.descartesQL.RelativeTimeWithSignClause;
import tools.descartes.dql.lang.descartesQL.SampleClause;
import tools.descartes.dql.lang.descartesQL.SelectQuery;
import tools.descartes.dql.lang.descartesQL.Sla;
import tools.descartes.dql.lang.descartesQL.SlaQuery;
import tools.descartes.dql.lang.descartesQL.Slo;
import tools.descartes.dql.lang.descartesQL.SloQuery;
import tools.descartes.dql.lang.descartesQL.StatisticalAggregateType;
import tools.descartes.dql.lang.descartesQL.TimeClause;
import tools.descartes.dql.lang.descartesQL.TimeModifierType;
import tools.descartes.dql.lang.descartesQL.UsingClause;
import tools.descartes.dql.lang.descartesQL.ValueVariationClause;
import tools.descartes.dql.lang.descartesQL.VariableValue;
import tools.descartes.dql.lang.descartesQL.VaryingClause;
import tools.descartes.dql.lang.descartesQL.Violation;
import tools.descartes.dql.lang.descartesQL.WeightedSlo;
import tools.descartes.dql.lang.descartesQL.WhatIfQuery;
import tools.descartes.dql.lang.descartesQL.WhatIfValueVariationClause;
import tools.descartes.dql.lang.descartesQL.WhatIfVariation;
import tools.descartes.dql.lang.descartesQL.WhatIfVariationClause;
import tools.descartes.dql.lang.descartesQL.WithClause;

/**
 * <!-- begin-user-doc -->
 * An implementation of the model <b>Package</b>.
 * <!-- end-user-doc -->
 * @generated
 */
public class DescartesQLPackageImpl extends EPackageImpl implements DescartesQLPackage
{
  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass descartesQLEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass goalEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass slaQueryEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass sloQueryEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass slaEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass sloEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass weightedSloEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass fuzzinessEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass penaltyEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass violationEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass modelStructureQueryEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass performanceMetricsQueryEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass performanceIssueQueryEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass connectorCapabilityQueryEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass listQueryEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass getQueryEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass getConstraintsQueryEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass getExplorationStrategiesQueryEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass getTimeUnitsQueryEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass listDoFQueryEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass listEntitiesQueryEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass listMetricsQueryEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass selectQueryEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass metricReferenceClausesEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass metricClauseTypeEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass detectQueryEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass detectBottlenecksQueryEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass constraintClauseEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass doFClauseEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass explorationStrategyClauseEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass configurationPropertiesClauseEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass configurationPropertyClauseEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass doFVariationClauseEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass valueVariationClauseEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass intervalVariationClauseEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass varyingClauseEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass doFReferenceEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass metricClauseEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass aggregateMetricClauseEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass metricClausesEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass metricStarClauseEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass metricReferenceEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass navigationClauseEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass childrenClauseEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass parentClauseEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass findClauseEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass forClauseEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass entityReferenceClauseEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass entityReferenceEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass aliasClauseEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass usingClauseEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass withClauseEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass modelReferenceClauseEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass modelFamilyEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass modelLocationEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass filterClauseEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass filterConditionClauseEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass filterConditionValueEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass observeClauseEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass observationClauseEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass sampleClauseEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass connectorTimeUnitClauseEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass connectorInstanceReferenceClauseEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass observeRelativeClauseEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass observeBetweenClauseEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass relativeTimeWithSignClauseEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass betweenTimeClauseEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass timeClauseEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass absoluteTimeClauseEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass relativeTimeClauseEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass relativeTimeDurationClauseEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass whatIfQueryEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass whatIfVariationEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass filteringClauseEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass filteringStrategyEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass filterigRuleEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass whatIfVariationClauseEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass whatIfValueVariationClauseEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass multipleArithmeticClauseEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass arithmeticClauseEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EClass variableValueEClass = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EEnum comparatorEEnum = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EEnum currencyEEnum = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EEnum filterConjunctionEEnum = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EEnum filterConditionTypeEEnum = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EEnum observeRelativeDirectionTypeEEnum = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EEnum relativeTimeSignTypeEEnum = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EEnum timeModifierTypeEEnum = null;

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private EEnum statisticalAggregateTypeEEnum = null;

  /**
   * Creates an instance of the model <b>Package</b>, registered with
   * {@link org.eclipse.emf.ecore.EPackage.Registry EPackage.Registry} by the package
   * package URI value.
   * <p>Note: the correct way to create the package is via the static
   * factory method {@link #init init()}, which also performs
   * initialization of the package, or returns the registered package,
   * if one already exists.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see org.eclipse.emf.ecore.EPackage.Registry
   * @see tools.descartes.dql.lang.descartesQL.DescartesQLPackage#eNS_URI
   * @see #init()
   * @generated
   */
  private DescartesQLPackageImpl()
  {
    super(eNS_URI, DescartesQLFactory.eINSTANCE);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private static boolean isInited = false;

  /**
   * Creates, registers, and initializes the <b>Package</b> for this model, and for any others upon which it depends.
   * 
   * <p>This method is used to initialize {@link DescartesQLPackage#eINSTANCE} when that field is accessed.
   * Clients should not invoke it directly. Instead, they should simply access that field to obtain the package.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @see #eNS_URI
   * @see #createPackageContents()
   * @see #initializePackageContents()
   * @generated
   */
  public static DescartesQLPackage init()
  {
    if (isInited) return (DescartesQLPackage)EPackage.Registry.INSTANCE.getEPackage(DescartesQLPackage.eNS_URI);

    // Obtain or create and register package
    DescartesQLPackageImpl theDescartesQLPackage = (DescartesQLPackageImpl)(EPackage.Registry.INSTANCE.get(eNS_URI) instanceof DescartesQLPackageImpl ? EPackage.Registry.INSTANCE.get(eNS_URI) : new DescartesQLPackageImpl());

    isInited = true;

    // Create package meta-data objects
    theDescartesQLPackage.createPackageContents();

    // Initialize created meta-data
    theDescartesQLPackage.initializePackageContents();

    // Mark meta-data to indicate it can't be changed
    theDescartesQLPackage.freeze();

  
    // Update the registry and return the package
    EPackage.Registry.INSTANCE.put(DescartesQLPackage.eNS_URI, theDescartesQLPackage);
    return theDescartesQLPackage;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getDescartesQL()
  {
    return descartesQLEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getDescartesQL_Query()
  {
    return (EReference)descartesQLEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getGoal()
  {
    return goalEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getGoal_QueryType()
  {
    return (EAttribute)goalEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getGoal_SlaQuery()
  {
    return (EReference)goalEClass.getEStructuralFeatures().get(1);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getGoal_SloQuery()
  {
    return (EReference)goalEClass.getEStructuralFeatures().get(2);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getGoal_ForClause()
  {
    return (EReference)goalEClass.getEStructuralFeatures().get(3);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getGoal_UsingClause()
  {
    return (EReference)goalEClass.getEStructuralFeatures().get(4);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getSlaQuery()
  {
    return slaQueryEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getSlaQuery_Type()
  {
    return (EAttribute)slaQueryEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getSlaQuery_Slas()
  {
    return (EReference)slaQueryEClass.getEStructuralFeatures().get(1);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getSlaQuery_Sloa()
  {
    return (EReference)slaQueryEClass.getEStructuralFeatures().get(2);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getSloQuery()
  {
    return sloQueryEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getSloQuery_Type()
  {
    return (EAttribute)sloQueryEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getSloQuery_Slos()
  {
    return (EReference)sloQueryEClass.getEStructuralFeatures().get(1);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getSla()
  {
    return slaEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getSla_Name()
  {
    return (EAttribute)slaEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getSla_WeightedSlo()
  {
    return (EReference)slaEClass.getEStructuralFeatures().get(1);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getSlo()
  {
    return sloEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getSlo_Name()
  {
    return (EAttribute)sloEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getSlo_MetricClauseType()
  {
    return (EReference)sloEClass.getEStructuralFeatures().get(1);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getSlo_Comparator()
  {
    return (EAttribute)sloEClass.getEStructuralFeatures().get(2);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getSlo_Value()
  {
    return (EReference)sloEClass.getEStructuralFeatures().get(3);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getSlo_Fuz()
  {
    return (EReference)sloEClass.getEStructuralFeatures().get(4);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getSlo_Pen()
  {
    return (EReference)sloEClass.getEStructuralFeatures().get(5);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getWeightedSlo()
  {
    return weightedSloEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getWeightedSlo_Slo()
  {
    return (EReference)weightedSloEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getWeightedSlo_Weight()
  {
    return (EAttribute)weightedSloEClass.getEStructuralFeatures().get(1);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getFuzziness()
  {
    return fuzzinessEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getFuzziness_Type()
  {
    return (EAttribute)fuzzinessEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getFuzziness_Deviation()
  {
    return (EReference)fuzzinessEClass.getEStructuralFeatures().get(1);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getPenalty()
  {
    return penaltyEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getPenalty_Type()
  {
    return (EAttribute)penaltyEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getPenalty_Value()
  {
    return (EAttribute)penaltyEClass.getEStructuralFeatures().get(1);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getPenalty_Currency()
  {
    return (EAttribute)penaltyEClass.getEStructuralFeatures().get(2);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getPenalty_Violation()
  {
    return (EReference)penaltyEClass.getEStructuralFeatures().get(3);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getViolation()
  {
    return violationEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getViolation_Amount()
  {
    return (EAttribute)violationEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getModelStructureQuery()
  {
    return modelStructureQueryEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getPerformanceMetricsQuery()
  {
    return performanceMetricsQueryEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getPerformanceIssueQuery()
  {
    return performanceIssueQueryEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getConnectorCapabilityQuery()
  {
    return connectorCapabilityQueryEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getListQuery()
  {
    return listQueryEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getListQuery_QueryType()
  {
    return (EReference)listQueryEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getListQuery_FilterClause()
  {
    return (EReference)listQueryEClass.getEStructuralFeatures().get(1);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getListQuery_UsingClause()
  {
    return (EReference)listQueryEClass.getEStructuralFeatures().get(2);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getGetQuery()
  {
    return getQueryEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getGetQuery_QueryTape()
  {
    return (EReference)getQueryEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getGetQuery_UsingClause()
  {
    return (EReference)getQueryEClass.getEStructuralFeatures().get(1);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getGetConstraintsQuery()
  {
    return getConstraintsQueryEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getGetConstraintsQuery_Mode()
  {
    return (EAttribute)getConstraintsQueryEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getGetExplorationStrategiesQuery()
  {
    return getExplorationStrategiesQueryEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getGetExplorationStrategiesQuery_Mode()
  {
    return (EAttribute)getExplorationStrategiesQueryEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getGetTimeUnitsQuery()
  {
    return getTimeUnitsQueryEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getGetTimeUnitsQuery_Mode()
  {
    return (EAttribute)getTimeUnitsQueryEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getListDoFQuery()
  {
    return listDoFQueryEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getListDoFQuery_Mode()
  {
    return (EAttribute)listDoFQueryEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getListDoFQuery_WithClause()
  {
    return (EReference)listDoFQueryEClass.getEStructuralFeatures().get(1);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getListEntitiesQuery()
  {
    return listEntitiesQueryEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getListEntitiesQuery_Mode()
  {
    return (EAttribute)listEntitiesQueryEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getListMetricsQuery()
  {
    return listMetricsQueryEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getListMetricsQuery_Mode()
  {
    return (EAttribute)listMetricsQueryEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getListMetricsQuery_EntityReferenceClause()
  {
    return (EReference)listMetricsQueryEClass.getEStructuralFeatures().get(1);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getSelectQuery()
  {
    return selectQueryEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getSelectQuery_MetricReferenceClauses()
  {
    return (EReference)selectQueryEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getSelectQuery_ConstraintClause()
  {
    return (EReference)selectQueryEClass.getEStructuralFeatures().get(1);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getSelectQuery_DofClause()
  {
    return (EReference)selectQueryEClass.getEStructuralFeatures().get(2);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getSelectQuery_ForClause()
  {
    return (EReference)selectQueryEClass.getEStructuralFeatures().get(3);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getSelectQuery_UsingClause()
  {
    return (EReference)selectQueryEClass.getEStructuralFeatures().get(4);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getSelectQuery_ObserveClause()
  {
    return (EReference)selectQueryEClass.getEStructuralFeatures().get(5);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getMetricReferenceClauses()
  {
    return metricReferenceClausesEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getMetricReferenceClauses_MetricClauseTypes()
  {
    return (EReference)metricReferenceClausesEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getMetricClauseType()
  {
    return metricClauseTypeEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getDetectQuery()
  {
    return detectQueryEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getDetectQuery_QueryType()
  {
    return (EReference)detectQueryEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getDetectBottlenecksQuery()
  {
    return detectBottlenecksQueryEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getDetectBottlenecksQuery_DofClause()
  {
    return (EReference)detectBottlenecksQueryEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getDetectBottlenecksQuery_UsingClause()
  {
    return (EReference)detectBottlenecksQueryEClass.getEStructuralFeatures().get(1);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getConstraintClause()
  {
    return constraintClauseEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getConstraintClause_Type()
  {
    return (EAttribute)constraintClauseEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getDoFClause()
  {
    return doFClauseEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getDoFClause_Mode()
  {
    return (EAttribute)doFClauseEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getDoFClause_VaryingClause()
  {
    return (EReference)doFClauseEClass.getEStructuralFeatures().get(1);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getDoFClause_ExplorationStrategy()
  {
    return (EReference)doFClauseEClass.getEStructuralFeatures().get(2);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getDoFClause_ConstraintClause()
  {
    return (EReference)doFClauseEClass.getEStructuralFeatures().get(3);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getDoFClause_WithClause()
  {
    return (EReference)doFClauseEClass.getEStructuralFeatures().get(4);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getExplorationStrategyClause()
  {
    return explorationStrategyClauseEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getExplorationStrategyClause_Mode()
  {
    return (EAttribute)explorationStrategyClauseEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getExplorationStrategyClause_Name()
  {
    return (EAttribute)explorationStrategyClauseEClass.getEStructuralFeatures().get(1);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getExplorationStrategyClause_ParameterClause()
  {
    return (EReference)explorationStrategyClauseEClass.getEStructuralFeatures().get(2);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getConfigurationPropertiesClause()
  {
    return configurationPropertiesClauseEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getConfigurationPropertiesClause_Mode1()
  {
    return (EAttribute)configurationPropertiesClauseEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getConfigurationPropertiesClause_Properties()
  {
    return (EReference)configurationPropertiesClauseEClass.getEStructuralFeatures().get(1);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getConfigurationPropertiesClause_Mode2()
  {
    return (EAttribute)configurationPropertiesClauseEClass.getEStructuralFeatures().get(2);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getConfigurationPropertyClause()
  {
    return configurationPropertyClauseEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getConfigurationPropertyClause_Key()
  {
    return (EAttribute)configurationPropertyClauseEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getConfigurationPropertyClause_Value()
  {
    return (EAttribute)configurationPropertyClauseEClass.getEStructuralFeatures().get(1);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getDoFVariationClause()
  {
    return doFVariationClauseEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getDoFVariationClause_Mode1()
  {
    return (EAttribute)doFVariationClauseEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getDoFVariationClause_Variation()
  {
    return (EReference)doFVariationClauseEClass.getEStructuralFeatures().get(1);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getDoFVariationClause_Mode2()
  {
    return (EAttribute)doFVariationClauseEClass.getEStructuralFeatures().get(2);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getValueVariationClause()
  {
    return valueVariationClauseEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getValueVariationClause_Value()
  {
    return (EAttribute)valueVariationClauseEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getIntervalVariationClause()
  {
    return intervalVariationClauseEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getIntervalVariationClause_Start()
  {
    return (EAttribute)intervalVariationClauseEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getIntervalVariationClause_End()
  {
    return (EAttribute)intervalVariationClauseEClass.getEStructuralFeatures().get(1);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getIntervalVariationClause_Step()
  {
    return (EAttribute)intervalVariationClauseEClass.getEStructuralFeatures().get(2);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getVaryingClause()
  {
    return varyingClauseEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getVaryingClause_Mode()
  {
    return (EAttribute)varyingClauseEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getVaryingClause_DofReferences()
  {
    return (EReference)varyingClauseEClass.getEStructuralFeatures().get(1);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getDoFReference()
  {
    return doFReferenceEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getDoFReference_DoFIdentifier()
  {
    return (EAttribute)doFReferenceEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getDoFReference_DoFAliasClause()
  {
    return (EReference)doFReferenceEClass.getEStructuralFeatures().get(1);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getDoFReference_DoFVariationClause()
  {
    return (EReference)doFReferenceEClass.getEStructuralFeatures().get(2);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getMetricClause()
  {
    return metricClauseEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getMetricClause_MetricReference()
  {
    return (EReference)metricClauseEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getAggregateMetricClause()
  {
    return aggregateMetricClauseEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getAggregateMetricClause_Function()
  {
    return (EAttribute)aggregateMetricClauseEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getAggregateMetricClause_Metrics()
  {
    return (EReference)aggregateMetricClauseEClass.getEStructuralFeatures().get(1);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getAggregateMetricClause_Properties()
  {
    return (EReference)aggregateMetricClauseEClass.getEStructuralFeatures().get(2);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getMetricClauses()
  {
    return metricClausesEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getMetricClauses_Metrics()
  {
    return (EReference)metricClausesEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getMetricStarClause()
  {
    return metricStarClauseEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getMetricStarClause_MetricName()
  {
    return (EAttribute)metricStarClauseEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getMetricReference()
  {
    return metricReferenceEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getMetricReference_EntityReference()
  {
    return (EAttribute)metricReferenceEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getMetricReference_Seperatorn()
  {
    return (EAttribute)metricReferenceEClass.getEStructuralFeatures().get(1);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getMetricReference_NavigationClause()
  {
    return (EReference)metricReferenceEClass.getEStructuralFeatures().get(2);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getMetricReference_Separator()
  {
    return (EAttribute)metricReferenceEClass.getEStructuralFeatures().get(3);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getMetricReference_MetricReference()
  {
    return (EAttribute)metricReferenceEClass.getEStructuralFeatures().get(4);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getMetricReference_Separatorv()
  {
    return (EAttribute)metricReferenceEClass.getEStructuralFeatures().get(5);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getMetricReference_StatTypeReference()
  {
    return (EAttribute)metricReferenceEClass.getEStructuralFeatures().get(6);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getNavigationClause()
  {
    return navigationClauseEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getChildrenClause()
  {
    return childrenClauseEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getChildrenClause_Content()
  {
    return (EAttribute)childrenClauseEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getParentClause()
  {
    return parentClauseEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getParentClause_Content()
  {
    return (EAttribute)parentClauseEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getFindClause()
  {
    return findClauseEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getFindClause_Start()
  {
    return (EAttribute)findClauseEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getFindClause_ChildName()
  {
    return (EAttribute)findClauseEClass.getEStructuralFeatures().get(1);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getFindClause_End()
  {
    return (EAttribute)findClauseEClass.getEStructuralFeatures().get(2);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getForClause()
  {
    return forClauseEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getForClause_Mode()
  {
    return (EAttribute)forClauseEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getForClause_EntityReferenceClause()
  {
    return (EReference)forClauseEClass.getEStructuralFeatures().get(1);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getEntityReferenceClause()
  {
    return entityReferenceClauseEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getEntityReferenceClause_EntityReferences()
  {
    return (EReference)entityReferenceClauseEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getEntityReference()
  {
    return entityReferenceEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getEntityReference_Type()
  {
    return (EAttribute)entityReferenceEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getEntityReference_Identifier()
  {
    return (EAttribute)entityReferenceEClass.getEStructuralFeatures().get(1);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getEntityReference_Alias()
  {
    return (EReference)entityReferenceEClass.getEStructuralFeatures().get(2);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getAliasClause()
  {
    return aliasClauseEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getAliasClause_Mode()
  {
    return (EAttribute)aliasClauseEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getAliasClause_Alias()
  {
    return (EAttribute)aliasClauseEClass.getEStructuralFeatures().get(1);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getUsingClause()
  {
    return usingClauseEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getUsingClause_Mode()
  {
    return (EAttribute)usingClauseEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getUsingClause_ModelReference()
  {
    return (EReference)usingClauseEClass.getEStructuralFeatures().get(1);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getWithClause()
  {
    return withClauseEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getWithClause_Mode()
  {
    return (EAttribute)withClauseEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getWithClause_ModelReference()
  {
    return (EReference)withClauseEClass.getEStructuralFeatures().get(1);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getModelReferenceClause()
  {
    return modelReferenceClauseEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getModelReferenceClause_Family()
  {
    return (EReference)modelReferenceClauseEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getModelReferenceClause_Model()
  {
    return (EReference)modelReferenceClauseEClass.getEStructuralFeatures().get(1);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getModelFamily()
  {
    return modelFamilyEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getModelFamily_Family()
  {
    return (EAttribute)modelFamilyEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getModelLocation()
  {
    return modelLocationEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getModelLocation_Location()
  {
    return (EAttribute)modelLocationEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getFilterClause()
  {
    return filterClauseEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getFilterClause_Mode()
  {
    return (EAttribute)filterClauseEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getFilterClause_FilterConditions()
  {
    return (EReference)filterClauseEClass.getEStructuralFeatures().get(1);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getFilterClause_FilterConjunctions()
  {
    return (EAttribute)filterClauseEClass.getEStructuralFeatures().get(2);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getFilterConditionClause()
  {
    return filterConditionClauseEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getFilterConditionClause_Mode()
  {
    return (EAttribute)filterConditionClauseEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getFilterConditionClause_Condition()
  {
    return (EAttribute)filterConditionClauseEClass.getEStructuralFeatures().get(1);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getFilterConditionClause_Value()
  {
    return (EReference)filterConditionClauseEClass.getEStructuralFeatures().get(2);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getFilterConditionValue()
  {
    return filterConditionValueEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getFilterConditionValue_Value()
  {
    return (EAttribute)filterConditionValueEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getObserveClause()
  {
    return observeClauseEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getObserveClause_Mode()
  {
    return (EAttribute)observeClauseEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getObserveClause_Observation()
  {
    return (EReference)observeClauseEClass.getEStructuralFeatures().get(1);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getObserveClause_SampleClause()
  {
    return (EReference)observeClauseEClass.getEStructuralFeatures().get(2);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getObservationClause()
  {
    return observationClauseEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getSampleClause()
  {
    return sampleClauseEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getSampleClause_Mode()
  {
    return (EAttribute)sampleClauseEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getSampleClause_DurationClause()
  {
    return (EReference)sampleClauseEClass.getEStructuralFeatures().get(1);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getConnectorTimeUnitClause()
  {
    return connectorTimeUnitClauseEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getConnectorTimeUnitClause_Count()
  {
    return (EAttribute)connectorTimeUnitClauseEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getConnectorTimeUnitClause_TimeIndicator()
  {
    return (EAttribute)connectorTimeUnitClauseEClass.getEStructuralFeatures().get(1);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getConnectorInstanceReferenceClause()
  {
    return connectorInstanceReferenceClauseEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getConnectorInstanceReferenceClause_Type()
  {
    return (EAttribute)connectorInstanceReferenceClauseEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getConnectorInstanceReferenceClause_Identifier()
  {
    return (EAttribute)connectorInstanceReferenceClauseEClass.getEStructuralFeatures().get(1);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getObserveRelativeClause()
  {
    return observeRelativeClauseEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getObserveRelativeClause_Direction()
  {
    return (EAttribute)observeRelativeClauseEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getObserveRelativeClause_TimeTarget()
  {
    return (EReference)observeRelativeClauseEClass.getEStructuralFeatures().get(1);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getObserveBetweenClause()
  {
    return observeBetweenClauseEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getObserveBetweenClause_Mode1()
  {
    return (EAttribute)observeBetweenClauseEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getObserveBetweenClause_StartingTime()
  {
    return (EReference)observeBetweenClauseEClass.getEStructuralFeatures().get(1);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getObserveBetweenClause_Mode2()
  {
    return (EAttribute)observeBetweenClauseEClass.getEStructuralFeatures().get(2);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getObserveBetweenClause_EndingTime()
  {
    return (EReference)observeBetweenClauseEClass.getEStructuralFeatures().get(3);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getRelativeTimeWithSignClause()
  {
    return relativeTimeWithSignClauseEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getRelativeTimeWithSignClause_Sign()
  {
    return (EAttribute)relativeTimeWithSignClauseEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getRelativeTimeWithSignClause_TimeClause()
  {
    return (EReference)relativeTimeWithSignClauseEClass.getEStructuralFeatures().get(1);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getBetweenTimeClause()
  {
    return betweenTimeClauseEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getTimeClause()
  {
    return timeClauseEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getAbsoluteTimeClause()
  {
    return absoluteTimeClauseEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getAbsoluteTimeClause_TimeSpec()
  {
    return (EAttribute)absoluteTimeClauseEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getRelativeTimeClause()
  {
    return relativeTimeClauseEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getRelativeTimeClause_DurationClause()
  {
    return (EReference)relativeTimeClauseEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getRelativeTimeDurationClause()
  {
    return relativeTimeDurationClauseEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getRelativeTimeDurationClause_Duration()
  {
    return (EAttribute)relativeTimeDurationClauseEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getRelativeTimeDurationClause_TimeModifier()
  {
    return (EAttribute)relativeTimeDurationClauseEClass.getEStructuralFeatures().get(1);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getWhatIfQuery()
  {
    return whatIfQueryEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getWhatIfQuery_WhatIfVariation()
  {
    return (EReference)whatIfQueryEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getWhatIfQuery_MetricReferenceClauses()
  {
    return (EReference)whatIfQueryEClass.getEStructuralFeatures().get(1);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getWhatIfQuery_ForClause()
  {
    return (EReference)whatIfQueryEClass.getEStructuralFeatures().get(2);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getWhatIfQuery_FilteringClause()
  {
    return (EReference)whatIfQueryEClass.getEStructuralFeatures().get(3);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getWhatIfQuery_DeltaClause()
  {
    return (EAttribute)whatIfQueryEClass.getEStructuralFeatures().get(4);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getWhatIfQuery_UsingClause()
  {
    return (EReference)whatIfQueryEClass.getEStructuralFeatures().get(5);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getWhatIfVariation()
  {
    return whatIfVariationEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getWhatIfVariation_WhatIfVariationClause()
  {
    return (EReference)whatIfVariationEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getFilteringClause()
  {
    return filteringClauseEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getFilteringClause_FilterungRule()
  {
    return (EReference)filteringClauseEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getFilteringClause_FilteringStrategy()
  {
    return (EReference)filteringClauseEClass.getEStructuralFeatures().get(1);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getFilteringStrategy()
  {
    return filteringStrategyEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getFilteringStrategy_FilteringStrategy()
  {
    return (EAttribute)filteringStrategyEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getFilterigRule()
  {
    return filterigRuleEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getFilterigRule_FilteringValue()
  {
    return (EReference)filterigRuleEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getFilterigRule_Modifier()
  {
    return (EAttribute)filterigRuleEClass.getEStructuralFeatures().get(1);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getWhatIfVariationClause()
  {
    return whatIfVariationClauseEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getWhatIfVariationClause_VariationPoint()
  {
    return (EAttribute)whatIfVariationClauseEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getWhatIfVariationClause_Values()
  {
    return (EReference)whatIfVariationClauseEClass.getEStructuralFeatures().get(1);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getWhatIfValueVariationClause()
  {
    return whatIfValueVariationClauseEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getWhatIfValueVariationClause_DofVariationClause()
  {
    return (EReference)whatIfValueVariationClauseEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getWhatIfValueVariationClause_MultipleArithmethicClause()
  {
    return (EReference)whatIfValueVariationClauseEClass.getEStructuralFeatures().get(1);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getMultipleArithmeticClause()
  {
    return multipleArithmeticClauseEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getMultipleArithmeticClause_MultiClause()
  {
    return (EReference)multipleArithmeticClauseEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getArithmeticClause()
  {
    return arithmeticClauseEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getArithmeticClause_Mode()
  {
    return (EAttribute)arithmeticClauseEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EReference getArithmeticClause_Value()
  {
    return (EReference)arithmeticClauseEClass.getEStructuralFeatures().get(1);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EClass getVariableValue()
  {
    return variableValueEClass;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getVariableValue_IntValue()
  {
    return (EAttribute)variableValueEClass.getEStructuralFeatures().get(0);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EAttribute getVariableValue_DoubleValue()
  {
    return (EAttribute)variableValueEClass.getEStructuralFeatures().get(1);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EEnum getComparator()
  {
    return comparatorEEnum;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EEnum getCurrency()
  {
    return currencyEEnum;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EEnum getFilterConjunction()
  {
    return filterConjunctionEEnum;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EEnum getFilterConditionType()
  {
    return filterConditionTypeEEnum;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EEnum getObserveRelativeDirectionType()
  {
    return observeRelativeDirectionTypeEEnum;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EEnum getRelativeTimeSignType()
  {
    return relativeTimeSignTypeEEnum;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EEnum getTimeModifierType()
  {
    return timeModifierTypeEEnum;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public EEnum getStatisticalAggregateType()
  {
    return statisticalAggregateTypeEEnum;
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public DescartesQLFactory getDescartesQLFactory()
  {
    return (DescartesQLFactory)getEFactoryInstance();
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private boolean isCreated = false;

  /**
   * Creates the meta-model objects for the package.  This method is
   * guarded to have no affect on any invocation but its first.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public void createPackageContents()
  {
    if (isCreated) return;
    isCreated = true;

    // Create classes and their features
    descartesQLEClass = createEClass(DESCARTES_QL);
    createEReference(descartesQLEClass, DESCARTES_QL__QUERY);

    goalEClass = createEClass(GOAL);
    createEAttribute(goalEClass, GOAL__QUERY_TYPE);
    createEReference(goalEClass, GOAL__SLA_QUERY);
    createEReference(goalEClass, GOAL__SLO_QUERY);
    createEReference(goalEClass, GOAL__FOR_CLAUSE);
    createEReference(goalEClass, GOAL__USING_CLAUSE);

    slaQueryEClass = createEClass(SLA_QUERY);
    createEAttribute(slaQueryEClass, SLA_QUERY__TYPE);
    createEReference(slaQueryEClass, SLA_QUERY__SLAS);
    createEReference(slaQueryEClass, SLA_QUERY__SLOA);

    sloQueryEClass = createEClass(SLO_QUERY);
    createEAttribute(sloQueryEClass, SLO_QUERY__TYPE);
    createEReference(sloQueryEClass, SLO_QUERY__SLOS);

    slaEClass = createEClass(SLA);
    createEAttribute(slaEClass, SLA__NAME);
    createEReference(slaEClass, SLA__WEIGHTED_SLO);

    sloEClass = createEClass(SLO);
    createEAttribute(sloEClass, SLO__NAME);
    createEReference(sloEClass, SLO__METRIC_CLAUSE_TYPE);
    createEAttribute(sloEClass, SLO__COMPARATOR);
    createEReference(sloEClass, SLO__VALUE);
    createEReference(sloEClass, SLO__FUZ);
    createEReference(sloEClass, SLO__PEN);

    weightedSloEClass = createEClass(WEIGHTED_SLO);
    createEReference(weightedSloEClass, WEIGHTED_SLO__SLO);
    createEAttribute(weightedSloEClass, WEIGHTED_SLO__WEIGHT);

    fuzzinessEClass = createEClass(FUZZINESS);
    createEAttribute(fuzzinessEClass, FUZZINESS__TYPE);
    createEReference(fuzzinessEClass, FUZZINESS__DEVIATION);

    penaltyEClass = createEClass(PENALTY);
    createEAttribute(penaltyEClass, PENALTY__TYPE);
    createEAttribute(penaltyEClass, PENALTY__VALUE);
    createEAttribute(penaltyEClass, PENALTY__CURRENCY);
    createEReference(penaltyEClass, PENALTY__VIOLATION);

    violationEClass = createEClass(VIOLATION);
    createEAttribute(violationEClass, VIOLATION__AMOUNT);

    modelStructureQueryEClass = createEClass(MODEL_STRUCTURE_QUERY);

    performanceMetricsQueryEClass = createEClass(PERFORMANCE_METRICS_QUERY);

    performanceIssueQueryEClass = createEClass(PERFORMANCE_ISSUE_QUERY);

    connectorCapabilityQueryEClass = createEClass(CONNECTOR_CAPABILITY_QUERY);

    listQueryEClass = createEClass(LIST_QUERY);
    createEReference(listQueryEClass, LIST_QUERY__QUERY_TYPE);
    createEReference(listQueryEClass, LIST_QUERY__FILTER_CLAUSE);
    createEReference(listQueryEClass, LIST_QUERY__USING_CLAUSE);

    getQueryEClass = createEClass(GET_QUERY);
    createEReference(getQueryEClass, GET_QUERY__QUERY_TAPE);
    createEReference(getQueryEClass, GET_QUERY__USING_CLAUSE);

    getConstraintsQueryEClass = createEClass(GET_CONSTRAINTS_QUERY);
    createEAttribute(getConstraintsQueryEClass, GET_CONSTRAINTS_QUERY__MODE);

    getExplorationStrategiesQueryEClass = createEClass(GET_EXPLORATION_STRATEGIES_QUERY);
    createEAttribute(getExplorationStrategiesQueryEClass, GET_EXPLORATION_STRATEGIES_QUERY__MODE);

    getTimeUnitsQueryEClass = createEClass(GET_TIME_UNITS_QUERY);
    createEAttribute(getTimeUnitsQueryEClass, GET_TIME_UNITS_QUERY__MODE);

    listDoFQueryEClass = createEClass(LIST_DO_FQUERY);
    createEAttribute(listDoFQueryEClass, LIST_DO_FQUERY__MODE);
    createEReference(listDoFQueryEClass, LIST_DO_FQUERY__WITH_CLAUSE);

    listEntitiesQueryEClass = createEClass(LIST_ENTITIES_QUERY);
    createEAttribute(listEntitiesQueryEClass, LIST_ENTITIES_QUERY__MODE);

    listMetricsQueryEClass = createEClass(LIST_METRICS_QUERY);
    createEAttribute(listMetricsQueryEClass, LIST_METRICS_QUERY__MODE);
    createEReference(listMetricsQueryEClass, LIST_METRICS_QUERY__ENTITY_REFERENCE_CLAUSE);

    selectQueryEClass = createEClass(SELECT_QUERY);
    createEReference(selectQueryEClass, SELECT_QUERY__METRIC_REFERENCE_CLAUSES);
    createEReference(selectQueryEClass, SELECT_QUERY__CONSTRAINT_CLAUSE);
    createEReference(selectQueryEClass, SELECT_QUERY__DOF_CLAUSE);
    createEReference(selectQueryEClass, SELECT_QUERY__FOR_CLAUSE);
    createEReference(selectQueryEClass, SELECT_QUERY__USING_CLAUSE);
    createEReference(selectQueryEClass, SELECT_QUERY__OBSERVE_CLAUSE);

    metricReferenceClausesEClass = createEClass(METRIC_REFERENCE_CLAUSES);
    createEReference(metricReferenceClausesEClass, METRIC_REFERENCE_CLAUSES__METRIC_CLAUSE_TYPES);

    metricClauseTypeEClass = createEClass(METRIC_CLAUSE_TYPE);

    detectQueryEClass = createEClass(DETECT_QUERY);
    createEReference(detectQueryEClass, DETECT_QUERY__QUERY_TYPE);

    detectBottlenecksQueryEClass = createEClass(DETECT_BOTTLENECKS_QUERY);
    createEReference(detectBottlenecksQueryEClass, DETECT_BOTTLENECKS_QUERY__DOF_CLAUSE);
    createEReference(detectBottlenecksQueryEClass, DETECT_BOTTLENECKS_QUERY__USING_CLAUSE);

    constraintClauseEClass = createEClass(CONSTRAINT_CLAUSE);
    createEAttribute(constraintClauseEClass, CONSTRAINT_CLAUSE__TYPE);

    doFClauseEClass = createEClass(DO_FCLAUSE);
    createEAttribute(doFClauseEClass, DO_FCLAUSE__MODE);
    createEReference(doFClauseEClass, DO_FCLAUSE__VARYING_CLAUSE);
    createEReference(doFClauseEClass, DO_FCLAUSE__EXPLORATION_STRATEGY);
    createEReference(doFClauseEClass, DO_FCLAUSE__CONSTRAINT_CLAUSE);
    createEReference(doFClauseEClass, DO_FCLAUSE__WITH_CLAUSE);

    explorationStrategyClauseEClass = createEClass(EXPLORATION_STRATEGY_CLAUSE);
    createEAttribute(explorationStrategyClauseEClass, EXPLORATION_STRATEGY_CLAUSE__MODE);
    createEAttribute(explorationStrategyClauseEClass, EXPLORATION_STRATEGY_CLAUSE__NAME);
    createEReference(explorationStrategyClauseEClass, EXPLORATION_STRATEGY_CLAUSE__PARAMETER_CLAUSE);

    configurationPropertiesClauseEClass = createEClass(CONFIGURATION_PROPERTIES_CLAUSE);
    createEAttribute(configurationPropertiesClauseEClass, CONFIGURATION_PROPERTIES_CLAUSE__MODE1);
    createEReference(configurationPropertiesClauseEClass, CONFIGURATION_PROPERTIES_CLAUSE__PROPERTIES);
    createEAttribute(configurationPropertiesClauseEClass, CONFIGURATION_PROPERTIES_CLAUSE__MODE2);

    configurationPropertyClauseEClass = createEClass(CONFIGURATION_PROPERTY_CLAUSE);
    createEAttribute(configurationPropertyClauseEClass, CONFIGURATION_PROPERTY_CLAUSE__KEY);
    createEAttribute(configurationPropertyClauseEClass, CONFIGURATION_PROPERTY_CLAUSE__VALUE);

    doFVariationClauseEClass = createEClass(DO_FVARIATION_CLAUSE);
    createEAttribute(doFVariationClauseEClass, DO_FVARIATION_CLAUSE__MODE1);
    createEReference(doFVariationClauseEClass, DO_FVARIATION_CLAUSE__VARIATION);
    createEAttribute(doFVariationClauseEClass, DO_FVARIATION_CLAUSE__MODE2);

    valueVariationClauseEClass = createEClass(VALUE_VARIATION_CLAUSE);
    createEAttribute(valueVariationClauseEClass, VALUE_VARIATION_CLAUSE__VALUE);

    intervalVariationClauseEClass = createEClass(INTERVAL_VARIATION_CLAUSE);
    createEAttribute(intervalVariationClauseEClass, INTERVAL_VARIATION_CLAUSE__START);
    createEAttribute(intervalVariationClauseEClass, INTERVAL_VARIATION_CLAUSE__END);
    createEAttribute(intervalVariationClauseEClass, INTERVAL_VARIATION_CLAUSE__STEP);

    varyingClauseEClass = createEClass(VARYING_CLAUSE);
    createEAttribute(varyingClauseEClass, VARYING_CLAUSE__MODE);
    createEReference(varyingClauseEClass, VARYING_CLAUSE__DOF_REFERENCES);

    doFReferenceEClass = createEClass(DO_FREFERENCE);
    createEAttribute(doFReferenceEClass, DO_FREFERENCE__DO_FIDENTIFIER);
    createEReference(doFReferenceEClass, DO_FREFERENCE__DO_FALIAS_CLAUSE);
    createEReference(doFReferenceEClass, DO_FREFERENCE__DO_FVARIATION_CLAUSE);

    metricClauseEClass = createEClass(METRIC_CLAUSE);
    createEReference(metricClauseEClass, METRIC_CLAUSE__METRIC_REFERENCE);

    aggregateMetricClauseEClass = createEClass(AGGREGATE_METRIC_CLAUSE);
    createEAttribute(aggregateMetricClauseEClass, AGGREGATE_METRIC_CLAUSE__FUNCTION);
    createEReference(aggregateMetricClauseEClass, AGGREGATE_METRIC_CLAUSE__METRICS);
    createEReference(aggregateMetricClauseEClass, AGGREGATE_METRIC_CLAUSE__PROPERTIES);

    metricClausesEClass = createEClass(METRIC_CLAUSES);
    createEReference(metricClausesEClass, METRIC_CLAUSES__METRICS);

    metricStarClauseEClass = createEClass(METRIC_STAR_CLAUSE);
    createEAttribute(metricStarClauseEClass, METRIC_STAR_CLAUSE__METRIC_NAME);

    metricReferenceEClass = createEClass(METRIC_REFERENCE);
    createEAttribute(metricReferenceEClass, METRIC_REFERENCE__ENTITY_REFERENCE);
    createEAttribute(metricReferenceEClass, METRIC_REFERENCE__SEPERATORN);
    createEReference(metricReferenceEClass, METRIC_REFERENCE__NAVIGATION_CLAUSE);
    createEAttribute(metricReferenceEClass, METRIC_REFERENCE__SEPARATOR);
    createEAttribute(metricReferenceEClass, METRIC_REFERENCE__METRIC_REFERENCE);
    createEAttribute(metricReferenceEClass, METRIC_REFERENCE__SEPARATORV);
    createEAttribute(metricReferenceEClass, METRIC_REFERENCE__STAT_TYPE_REFERENCE);

    navigationClauseEClass = createEClass(NAVIGATION_CLAUSE);

    childrenClauseEClass = createEClass(CHILDREN_CLAUSE);
    createEAttribute(childrenClauseEClass, CHILDREN_CLAUSE__CONTENT);

    parentClauseEClass = createEClass(PARENT_CLAUSE);
    createEAttribute(parentClauseEClass, PARENT_CLAUSE__CONTENT);

    findClauseEClass = createEClass(FIND_CLAUSE);
    createEAttribute(findClauseEClass, FIND_CLAUSE__START);
    createEAttribute(findClauseEClass, FIND_CLAUSE__CHILD_NAME);
    createEAttribute(findClauseEClass, FIND_CLAUSE__END);

    forClauseEClass = createEClass(FOR_CLAUSE);
    createEAttribute(forClauseEClass, FOR_CLAUSE__MODE);
    createEReference(forClauseEClass, FOR_CLAUSE__ENTITY_REFERENCE_CLAUSE);

    entityReferenceClauseEClass = createEClass(ENTITY_REFERENCE_CLAUSE);
    createEReference(entityReferenceClauseEClass, ENTITY_REFERENCE_CLAUSE__ENTITY_REFERENCES);

    entityReferenceEClass = createEClass(ENTITY_REFERENCE);
    createEAttribute(entityReferenceEClass, ENTITY_REFERENCE__TYPE);
    createEAttribute(entityReferenceEClass, ENTITY_REFERENCE__IDENTIFIER);
    createEReference(entityReferenceEClass, ENTITY_REFERENCE__ALIAS);

    aliasClauseEClass = createEClass(ALIAS_CLAUSE);
    createEAttribute(aliasClauseEClass, ALIAS_CLAUSE__MODE);
    createEAttribute(aliasClauseEClass, ALIAS_CLAUSE__ALIAS);

    usingClauseEClass = createEClass(USING_CLAUSE);
    createEAttribute(usingClauseEClass, USING_CLAUSE__MODE);
    createEReference(usingClauseEClass, USING_CLAUSE__MODEL_REFERENCE);

    withClauseEClass = createEClass(WITH_CLAUSE);
    createEAttribute(withClauseEClass, WITH_CLAUSE__MODE);
    createEReference(withClauseEClass, WITH_CLAUSE__MODEL_REFERENCE);

    modelReferenceClauseEClass = createEClass(MODEL_REFERENCE_CLAUSE);
    createEReference(modelReferenceClauseEClass, MODEL_REFERENCE_CLAUSE__FAMILY);
    createEReference(modelReferenceClauseEClass, MODEL_REFERENCE_CLAUSE__MODEL);

    modelFamilyEClass = createEClass(MODEL_FAMILY);
    createEAttribute(modelFamilyEClass, MODEL_FAMILY__FAMILY);

    modelLocationEClass = createEClass(MODEL_LOCATION);
    createEAttribute(modelLocationEClass, MODEL_LOCATION__LOCATION);

    filterClauseEClass = createEClass(FILTER_CLAUSE);
    createEAttribute(filterClauseEClass, FILTER_CLAUSE__MODE);
    createEReference(filterClauseEClass, FILTER_CLAUSE__FILTER_CONDITIONS);
    createEAttribute(filterClauseEClass, FILTER_CLAUSE__FILTER_CONJUNCTIONS);

    filterConditionClauseEClass = createEClass(FILTER_CONDITION_CLAUSE);
    createEAttribute(filterConditionClauseEClass, FILTER_CONDITION_CLAUSE__MODE);
    createEAttribute(filterConditionClauseEClass, FILTER_CONDITION_CLAUSE__CONDITION);
    createEReference(filterConditionClauseEClass, FILTER_CONDITION_CLAUSE__VALUE);

    filterConditionValueEClass = createEClass(FILTER_CONDITION_VALUE);
    createEAttribute(filterConditionValueEClass, FILTER_CONDITION_VALUE__VALUE);

    observeClauseEClass = createEClass(OBSERVE_CLAUSE);
    createEAttribute(observeClauseEClass, OBSERVE_CLAUSE__MODE);
    createEReference(observeClauseEClass, OBSERVE_CLAUSE__OBSERVATION);
    createEReference(observeClauseEClass, OBSERVE_CLAUSE__SAMPLE_CLAUSE);

    observationClauseEClass = createEClass(OBSERVATION_CLAUSE);

    sampleClauseEClass = createEClass(SAMPLE_CLAUSE);
    createEAttribute(sampleClauseEClass, SAMPLE_CLAUSE__MODE);
    createEReference(sampleClauseEClass, SAMPLE_CLAUSE__DURATION_CLAUSE);

    connectorTimeUnitClauseEClass = createEClass(CONNECTOR_TIME_UNIT_CLAUSE);
    createEAttribute(connectorTimeUnitClauseEClass, CONNECTOR_TIME_UNIT_CLAUSE__COUNT);
    createEAttribute(connectorTimeUnitClauseEClass, CONNECTOR_TIME_UNIT_CLAUSE__TIME_INDICATOR);

    connectorInstanceReferenceClauseEClass = createEClass(CONNECTOR_INSTANCE_REFERENCE_CLAUSE);
    createEAttribute(connectorInstanceReferenceClauseEClass, CONNECTOR_INSTANCE_REFERENCE_CLAUSE__TYPE);
    createEAttribute(connectorInstanceReferenceClauseEClass, CONNECTOR_INSTANCE_REFERENCE_CLAUSE__IDENTIFIER);

    observeRelativeClauseEClass = createEClass(OBSERVE_RELATIVE_CLAUSE);
    createEAttribute(observeRelativeClauseEClass, OBSERVE_RELATIVE_CLAUSE__DIRECTION);
    createEReference(observeRelativeClauseEClass, OBSERVE_RELATIVE_CLAUSE__TIME_TARGET);

    observeBetweenClauseEClass = createEClass(OBSERVE_BETWEEN_CLAUSE);
    createEAttribute(observeBetweenClauseEClass, OBSERVE_BETWEEN_CLAUSE__MODE1);
    createEReference(observeBetweenClauseEClass, OBSERVE_BETWEEN_CLAUSE__STARTING_TIME);
    createEAttribute(observeBetweenClauseEClass, OBSERVE_BETWEEN_CLAUSE__MODE2);
    createEReference(observeBetweenClauseEClass, OBSERVE_BETWEEN_CLAUSE__ENDING_TIME);

    relativeTimeWithSignClauseEClass = createEClass(RELATIVE_TIME_WITH_SIGN_CLAUSE);
    createEAttribute(relativeTimeWithSignClauseEClass, RELATIVE_TIME_WITH_SIGN_CLAUSE__SIGN);
    createEReference(relativeTimeWithSignClauseEClass, RELATIVE_TIME_WITH_SIGN_CLAUSE__TIME_CLAUSE);

    betweenTimeClauseEClass = createEClass(BETWEEN_TIME_CLAUSE);

    timeClauseEClass = createEClass(TIME_CLAUSE);

    absoluteTimeClauseEClass = createEClass(ABSOLUTE_TIME_CLAUSE);
    createEAttribute(absoluteTimeClauseEClass, ABSOLUTE_TIME_CLAUSE__TIME_SPEC);

    relativeTimeClauseEClass = createEClass(RELATIVE_TIME_CLAUSE);
    createEReference(relativeTimeClauseEClass, RELATIVE_TIME_CLAUSE__DURATION_CLAUSE);

    relativeTimeDurationClauseEClass = createEClass(RELATIVE_TIME_DURATION_CLAUSE);
    createEAttribute(relativeTimeDurationClauseEClass, RELATIVE_TIME_DURATION_CLAUSE__DURATION);
    createEAttribute(relativeTimeDurationClauseEClass, RELATIVE_TIME_DURATION_CLAUSE__TIME_MODIFIER);

    whatIfQueryEClass = createEClass(WHAT_IF_QUERY);
    createEReference(whatIfQueryEClass, WHAT_IF_QUERY__WHAT_IF_VARIATION);
    createEReference(whatIfQueryEClass, WHAT_IF_QUERY__METRIC_REFERENCE_CLAUSES);
    createEReference(whatIfQueryEClass, WHAT_IF_QUERY__FOR_CLAUSE);
    createEReference(whatIfQueryEClass, WHAT_IF_QUERY__FILTERING_CLAUSE);
    createEAttribute(whatIfQueryEClass, WHAT_IF_QUERY__DELTA_CLAUSE);
    createEReference(whatIfQueryEClass, WHAT_IF_QUERY__USING_CLAUSE);

    whatIfVariationEClass = createEClass(WHAT_IF_VARIATION);
    createEReference(whatIfVariationEClass, WHAT_IF_VARIATION__WHAT_IF_VARIATION_CLAUSE);

    filteringClauseEClass = createEClass(FILTERING_CLAUSE);
    createEReference(filteringClauseEClass, FILTERING_CLAUSE__FILTERUNG_RULE);
    createEReference(filteringClauseEClass, FILTERING_CLAUSE__FILTERING_STRATEGY);

    filteringStrategyEClass = createEClass(FILTERING_STRATEGY);
    createEAttribute(filteringStrategyEClass, FILTERING_STRATEGY__FILTERING_STRATEGY);

    filterigRuleEClass = createEClass(FILTERIG_RULE);
    createEReference(filterigRuleEClass, FILTERIG_RULE__FILTERING_VALUE);
    createEAttribute(filterigRuleEClass, FILTERIG_RULE__MODIFIER);

    whatIfVariationClauseEClass = createEClass(WHAT_IF_VARIATION_CLAUSE);
    createEAttribute(whatIfVariationClauseEClass, WHAT_IF_VARIATION_CLAUSE__VARIATION_POINT);
    createEReference(whatIfVariationClauseEClass, WHAT_IF_VARIATION_CLAUSE__VALUES);

    whatIfValueVariationClauseEClass = createEClass(WHAT_IF_VALUE_VARIATION_CLAUSE);
    createEReference(whatIfValueVariationClauseEClass, WHAT_IF_VALUE_VARIATION_CLAUSE__DOF_VARIATION_CLAUSE);
    createEReference(whatIfValueVariationClauseEClass, WHAT_IF_VALUE_VARIATION_CLAUSE__MULTIPLE_ARITHMETHIC_CLAUSE);

    multipleArithmeticClauseEClass = createEClass(MULTIPLE_ARITHMETIC_CLAUSE);
    createEReference(multipleArithmeticClauseEClass, MULTIPLE_ARITHMETIC_CLAUSE__MULTI_CLAUSE);

    arithmeticClauseEClass = createEClass(ARITHMETIC_CLAUSE);
    createEAttribute(arithmeticClauseEClass, ARITHMETIC_CLAUSE__MODE);
    createEReference(arithmeticClauseEClass, ARITHMETIC_CLAUSE__VALUE);

    variableValueEClass = createEClass(VARIABLE_VALUE);
    createEAttribute(variableValueEClass, VARIABLE_VALUE__INT_VALUE);
    createEAttribute(variableValueEClass, VARIABLE_VALUE__DOUBLE_VALUE);

    // Create enums
    comparatorEEnum = createEEnum(COMPARATOR);
    currencyEEnum = createEEnum(CURRENCY);
    filterConjunctionEEnum = createEEnum(FILTER_CONJUNCTION);
    filterConditionTypeEEnum = createEEnum(FILTER_CONDITION_TYPE);
    observeRelativeDirectionTypeEEnum = createEEnum(OBSERVE_RELATIVE_DIRECTION_TYPE);
    relativeTimeSignTypeEEnum = createEEnum(RELATIVE_TIME_SIGN_TYPE);
    timeModifierTypeEEnum = createEEnum(TIME_MODIFIER_TYPE);
    statisticalAggregateTypeEEnum = createEEnum(STATISTICAL_AGGREGATE_TYPE);
  }

  /**
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  private boolean isInitialized = false;

  /**
   * Complete the initialization of the package and its meta-model.  This
   * method is guarded to have no affect on any invocation but its first.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public void initializePackageContents()
  {
    if (isInitialized) return;
    isInitialized = true;

    // Initialize package
    setName(eNAME);
    setNsPrefix(eNS_PREFIX);
    setNsURI(eNS_URI);

    // Create type parameters

    // Set bounds for type parameters

    // Add supertypes to classes
    listQueryEClass.getESuperTypes().add(this.getModelStructureQuery());
    getQueryEClass.getESuperTypes().add(this.getConnectorCapabilityQuery());
    selectQueryEClass.getESuperTypes().add(this.getPerformanceMetricsQuery());
    detectQueryEClass.getESuperTypes().add(this.getPerformanceIssueQuery());
    metricClauseEClass.getESuperTypes().add(this.getMetricClauseType());
    aggregateMetricClauseEClass.getESuperTypes().add(this.getMetricClauseType());
    childrenClauseEClass.getESuperTypes().add(this.getNavigationClause());
    parentClauseEClass.getESuperTypes().add(this.getNavigationClause());
    findClauseEClass.getESuperTypes().add(this.getNavigationClause());
    connectorTimeUnitClauseEClass.getESuperTypes().add(this.getObservationClause());
    connectorInstanceReferenceClauseEClass.getESuperTypes().add(this.getObservationClause());
    observeRelativeClauseEClass.getESuperTypes().add(this.getObservationClause());
    observeBetweenClauseEClass.getESuperTypes().add(this.getObservationClause());
    relativeTimeWithSignClauseEClass.getESuperTypes().add(this.getBetweenTimeClause());
    absoluteTimeClauseEClass.getESuperTypes().add(this.getBetweenTimeClause());
    absoluteTimeClauseEClass.getESuperTypes().add(this.getTimeClause());
    relativeTimeClauseEClass.getESuperTypes().add(this.getTimeClause());

    // Initialize classes and features; add operations and parameters
    initEClass(descartesQLEClass, DescartesQL.class, "DescartesQL", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEReference(getDescartesQL_Query(), ecorePackage.getEObject(), null, "query", null, 0, 1, DescartesQL.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(goalEClass, Goal.class, "Goal", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEAttribute(getGoal_QueryType(), ecorePackage.getEString(), "queryType", null, 0, 1, Goal.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEReference(getGoal_SlaQuery(), this.getSlaQuery(), null, "slaQuery", null, 0, 1, Goal.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEReference(getGoal_SloQuery(), this.getSloQuery(), null, "sloQuery", null, 0, 1, Goal.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEReference(getGoal_ForClause(), this.getForClause(), null, "forClause", null, 0, 1, Goal.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEReference(getGoal_UsingClause(), this.getUsingClause(), null, "usingClause", null, 0, 1, Goal.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(slaQueryEClass, SlaQuery.class, "SlaQuery", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEAttribute(getSlaQuery_Type(), ecorePackage.getEString(), "type", null, 0, 1, SlaQuery.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEReference(getSlaQuery_Slas(), this.getSla(), null, "slas", null, 0, -1, SlaQuery.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEReference(getSlaQuery_Sloa(), this.getSla(), null, "sloa", null, 0, -1, SlaQuery.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(sloQueryEClass, SloQuery.class, "SloQuery", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEAttribute(getSloQuery_Type(), ecorePackage.getEString(), "type", null, 0, 1, SloQuery.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEReference(getSloQuery_Slos(), this.getSlo(), null, "slos", null, 0, -1, SloQuery.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(slaEClass, Sla.class, "Sla", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEAttribute(getSla_Name(), ecorePackage.getEString(), "name", null, 0, 1, Sla.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEReference(getSla_WeightedSlo(), this.getWeightedSlo(), null, "weightedSlo", null, 0, -1, Sla.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(sloEClass, Slo.class, "Slo", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEAttribute(getSlo_Name(), ecorePackage.getEString(), "name", null, 0, 1, Slo.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEReference(getSlo_MetricClauseType(), this.getMetricClauseType(), null, "metricClauseType", null, 0, 1, Slo.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEAttribute(getSlo_Comparator(), this.getComparator(), "comparator", null, 0, 1, Slo.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEReference(getSlo_Value(), this.getVariableValue(), null, "value", null, 0, 1, Slo.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEReference(getSlo_Fuz(), this.getFuzziness(), null, "fuz", null, 0, 1, Slo.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEReference(getSlo_Pen(), this.getPenalty(), null, "pen", null, 0, 1, Slo.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(weightedSloEClass, WeightedSlo.class, "WeightedSlo", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEReference(getWeightedSlo_Slo(), this.getSlo(), null, "slo", null, 0, 1, WeightedSlo.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_COMPOSITE, IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEAttribute(getWeightedSlo_Weight(), ecorePackage.getEInt(), "weight", null, 0, 1, WeightedSlo.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(fuzzinessEClass, Fuzziness.class, "Fuzziness", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEAttribute(getFuzziness_Type(), ecorePackage.getEString(), "type", null, 0, 1, Fuzziness.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEReference(getFuzziness_Deviation(), this.getVariableValue(), null, "deviation", null, 0, 1, Fuzziness.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(penaltyEClass, Penalty.class, "Penalty", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEAttribute(getPenalty_Type(), ecorePackage.getEString(), "type", null, 0, 1, Penalty.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEAttribute(getPenalty_Value(), ecorePackage.getEDouble(), "value", null, 0, 1, Penalty.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEAttribute(getPenalty_Currency(), this.getCurrency(), "currency", null, 0, 1, Penalty.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEReference(getPenalty_Violation(), this.getViolation(), null, "violation", null, 0, 1, Penalty.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(violationEClass, Violation.class, "Violation", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEAttribute(getViolation_Amount(), ecorePackage.getEInt(), "amount", null, 0, 1, Violation.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(modelStructureQueryEClass, ModelStructureQuery.class, "ModelStructureQuery", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);

    initEClass(performanceMetricsQueryEClass, PerformanceMetricsQuery.class, "PerformanceMetricsQuery", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);

    initEClass(performanceIssueQueryEClass, PerformanceIssueQuery.class, "PerformanceIssueQuery", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);

    initEClass(connectorCapabilityQueryEClass, ConnectorCapabilityQuery.class, "ConnectorCapabilityQuery", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);

    initEClass(listQueryEClass, ListQuery.class, "ListQuery", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEReference(getListQuery_QueryType(), ecorePackage.getEObject(), null, "queryType", null, 0, 1, ListQuery.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEReference(getListQuery_FilterClause(), this.getFilterClause(), null, "filterClause", null, 0, 1, ListQuery.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEReference(getListQuery_UsingClause(), this.getUsingClause(), null, "usingClause", null, 0, 1, ListQuery.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(getQueryEClass, GetQuery.class, "GetQuery", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEReference(getGetQuery_QueryTape(), ecorePackage.getEObject(), null, "queryTape", null, 0, 1, GetQuery.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEReference(getGetQuery_UsingClause(), this.getUsingClause(), null, "usingClause", null, 0, 1, GetQuery.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(getConstraintsQueryEClass, GetConstraintsQuery.class, "GetConstraintsQuery", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEAttribute(getGetConstraintsQuery_Mode(), ecorePackage.getEString(), "mode", null, 0, 1, GetConstraintsQuery.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(getExplorationStrategiesQueryEClass, GetExplorationStrategiesQuery.class, "GetExplorationStrategiesQuery", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEAttribute(getGetExplorationStrategiesQuery_Mode(), ecorePackage.getEString(), "mode", null, 0, 1, GetExplorationStrategiesQuery.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(getTimeUnitsQueryEClass, GetTimeUnitsQuery.class, "GetTimeUnitsQuery", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEAttribute(getGetTimeUnitsQuery_Mode(), ecorePackage.getEString(), "mode", null, 0, 1, GetTimeUnitsQuery.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(listDoFQueryEClass, ListDoFQuery.class, "ListDoFQuery", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEAttribute(getListDoFQuery_Mode(), ecorePackage.getEString(), "mode", null, 0, 1, ListDoFQuery.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEReference(getListDoFQuery_WithClause(), this.getWithClause(), null, "withClause", null, 0, 1, ListDoFQuery.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(listEntitiesQueryEClass, ListEntitiesQuery.class, "ListEntitiesQuery", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEAttribute(getListEntitiesQuery_Mode(), ecorePackage.getEString(), "mode", null, 0, 1, ListEntitiesQuery.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(listMetricsQueryEClass, ListMetricsQuery.class, "ListMetricsQuery", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEAttribute(getListMetricsQuery_Mode(), ecorePackage.getEString(), "mode", null, 0, 1, ListMetricsQuery.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEReference(getListMetricsQuery_EntityReferenceClause(), this.getEntityReferenceClause(), null, "entityReferenceClause", null, 0, 1, ListMetricsQuery.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(selectQueryEClass, SelectQuery.class, "SelectQuery", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEReference(getSelectQuery_MetricReferenceClauses(), this.getMetricReferenceClauses(), null, "metricReferenceClauses", null, 0, 1, SelectQuery.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEReference(getSelectQuery_ConstraintClause(), this.getConstraintClause(), null, "constraintClause", null, 0, 1, SelectQuery.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEReference(getSelectQuery_DofClause(), this.getDoFClause(), null, "dofClause", null, 0, 1, SelectQuery.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEReference(getSelectQuery_ForClause(), this.getForClause(), null, "forClause", null, 0, 1, SelectQuery.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEReference(getSelectQuery_UsingClause(), this.getUsingClause(), null, "usingClause", null, 0, 1, SelectQuery.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEReference(getSelectQuery_ObserveClause(), this.getObserveClause(), null, "observeClause", null, 0, 1, SelectQuery.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(metricReferenceClausesEClass, MetricReferenceClauses.class, "MetricReferenceClauses", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEReference(getMetricReferenceClauses_MetricClauseTypes(), this.getMetricClauseType(), null, "metricClauseTypes", null, 0, -1, MetricReferenceClauses.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(metricClauseTypeEClass, MetricClauseType.class, "MetricClauseType", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);

    initEClass(detectQueryEClass, DetectQuery.class, "DetectQuery", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEReference(getDetectQuery_QueryType(), this.getDetectBottlenecksQuery(), null, "queryType", null, 0, 1, DetectQuery.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(detectBottlenecksQueryEClass, DetectBottlenecksQuery.class, "DetectBottlenecksQuery", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEReference(getDetectBottlenecksQuery_DofClause(), this.getDoFClause(), null, "dofClause", null, 0, 1, DetectBottlenecksQuery.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEReference(getDetectBottlenecksQuery_UsingClause(), this.getUsingClause(), null, "usingClause", null, 0, 1, DetectBottlenecksQuery.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(constraintClauseEClass, ConstraintClause.class, "ConstraintClause", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEAttribute(getConstraintClause_Type(), ecorePackage.getEString(), "type", null, 0, 1, ConstraintClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(doFClauseEClass, DoFClause.class, "DoFClause", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEAttribute(getDoFClause_Mode(), ecorePackage.getEString(), "mode", null, 0, 1, DoFClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEReference(getDoFClause_VaryingClause(), this.getVaryingClause(), null, "varyingClause", null, 0, 1, DoFClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEReference(getDoFClause_ExplorationStrategy(), this.getExplorationStrategyClause(), null, "explorationStrategy", null, 0, 1, DoFClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEReference(getDoFClause_ConstraintClause(), this.getConstraintClause(), null, "constraintClause", null, 0, 1, DoFClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEReference(getDoFClause_WithClause(), this.getWithClause(), null, "withClause", null, 0, 1, DoFClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(explorationStrategyClauseEClass, ExplorationStrategyClause.class, "ExplorationStrategyClause", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEAttribute(getExplorationStrategyClause_Mode(), ecorePackage.getEString(), "mode", null, 0, 1, ExplorationStrategyClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEAttribute(getExplorationStrategyClause_Name(), ecorePackage.getEString(), "name", null, 0, 1, ExplorationStrategyClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEReference(getExplorationStrategyClause_ParameterClause(), this.getConfigurationPropertiesClause(), null, "parameterClause", null, 0, 1, ExplorationStrategyClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(configurationPropertiesClauseEClass, ConfigurationPropertiesClause.class, "ConfigurationPropertiesClause", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEAttribute(getConfigurationPropertiesClause_Mode1(), ecorePackage.getEString(), "mode1", null, 0, 1, ConfigurationPropertiesClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEReference(getConfigurationPropertiesClause_Properties(), this.getConfigurationPropertyClause(), null, "properties", null, 0, -1, ConfigurationPropertiesClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEAttribute(getConfigurationPropertiesClause_Mode2(), ecorePackage.getEString(), "mode2", null, 0, 1, ConfigurationPropertiesClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(configurationPropertyClauseEClass, ConfigurationPropertyClause.class, "ConfigurationPropertyClause", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEAttribute(getConfigurationPropertyClause_Key(), ecorePackage.getEString(), "key", null, 0, -1, ConfigurationPropertyClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, !IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEAttribute(getConfigurationPropertyClause_Value(), ecorePackage.getEString(), "value", null, 0, 1, ConfigurationPropertyClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(doFVariationClauseEClass, DoFVariationClause.class, "DoFVariationClause", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEAttribute(getDoFVariationClause_Mode1(), ecorePackage.getEString(), "mode1", null, 0, 1, DoFVariationClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEReference(getDoFVariationClause_Variation(), ecorePackage.getEObject(), null, "variation", null, 0, 1, DoFVariationClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEAttribute(getDoFVariationClause_Mode2(), ecorePackage.getEString(), "mode2", null, 0, 1, DoFVariationClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(valueVariationClauseEClass, ValueVariationClause.class, "ValueVariationClause", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEAttribute(getValueVariationClause_Value(), ecorePackage.getEInt(), "value", null, 0, -1, ValueVariationClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, !IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(intervalVariationClauseEClass, IntervalVariationClause.class, "IntervalVariationClause", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEAttribute(getIntervalVariationClause_Start(), ecorePackage.getEInt(), "start", null, 0, 1, IntervalVariationClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEAttribute(getIntervalVariationClause_End(), ecorePackage.getEInt(), "end", null, 0, 1, IntervalVariationClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEAttribute(getIntervalVariationClause_Step(), ecorePackage.getEInt(), "step", null, 0, 1, IntervalVariationClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(varyingClauseEClass, VaryingClause.class, "VaryingClause", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEAttribute(getVaryingClause_Mode(), ecorePackage.getEString(), "mode", null, 0, 1, VaryingClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEReference(getVaryingClause_DofReferences(), this.getDoFReference(), null, "dofReferences", null, 0, -1, VaryingClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(doFReferenceEClass, DoFReference.class, "DoFReference", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEAttribute(getDoFReference_DoFIdentifier(), ecorePackage.getEString(), "doFIdentifier", null, 0, 1, DoFReference.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEReference(getDoFReference_DoFAliasClause(), this.getAliasClause(), null, "doFAliasClause", null, 0, 1, DoFReference.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEReference(getDoFReference_DoFVariationClause(), ecorePackage.getEObject(), null, "doFVariationClause", null, 0, 1, DoFReference.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(metricClauseEClass, MetricClause.class, "MetricClause", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEReference(getMetricClause_MetricReference(), this.getMetricReference(), null, "metricReference", null, 0, 1, MetricClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(aggregateMetricClauseEClass, AggregateMetricClause.class, "AggregateMetricClause", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEAttribute(getAggregateMetricClause_Function(), this.getStatisticalAggregateType(), "function", null, 0, 1, AggregateMetricClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEReference(getAggregateMetricClause_Metrics(), ecorePackage.getEObject(), null, "metrics", null, 0, 1, AggregateMetricClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEReference(getAggregateMetricClause_Properties(), this.getConfigurationPropertiesClause(), null, "properties", null, 0, 1, AggregateMetricClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(metricClausesEClass, MetricClauses.class, "MetricClauses", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEReference(getMetricClauses_Metrics(), this.getMetricClause(), null, "metrics", null, 0, -1, MetricClauses.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(metricStarClauseEClass, MetricStarClause.class, "MetricStarClause", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEAttribute(getMetricStarClause_MetricName(), ecorePackage.getEString(), "metricName", null, 0, 1, MetricStarClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(metricReferenceEClass, MetricReference.class, "MetricReference", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEAttribute(getMetricReference_EntityReference(), ecorePackage.getEString(), "entityReference", null, 0, 1, MetricReference.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEAttribute(getMetricReference_Seperatorn(), ecorePackage.getEString(), "seperatorn", null, 0, 1, MetricReference.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEReference(getMetricReference_NavigationClause(), this.getNavigationClause(), null, "navigationClause", null, 0, 1, MetricReference.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEAttribute(getMetricReference_Separator(), ecorePackage.getEString(), "separator", null, 0, 1, MetricReference.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEAttribute(getMetricReference_MetricReference(), ecorePackage.getEString(), "metricReference", null, 0, 1, MetricReference.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEAttribute(getMetricReference_Separatorv(), ecorePackage.getEString(), "separatorv", null, 0, 1, MetricReference.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEAttribute(getMetricReference_StatTypeReference(), ecorePackage.getEString(), "statTypeReference", null, 0, 1, MetricReference.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(navigationClauseEClass, NavigationClause.class, "NavigationClause", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);

    initEClass(childrenClauseEClass, ChildrenClause.class, "ChildrenClause", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEAttribute(getChildrenClause_Content(), ecorePackage.getEString(), "content", null, 0, 1, ChildrenClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(parentClauseEClass, ParentClause.class, "ParentClause", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEAttribute(getParentClause_Content(), ecorePackage.getEString(), "content", null, 0, 1, ParentClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(findClauseEClass, FindClause.class, "FindClause", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEAttribute(getFindClause_Start(), ecorePackage.getEString(), "start", null, 0, 1, FindClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEAttribute(getFindClause_ChildName(), ecorePackage.getEString(), "childName", null, 0, 1, FindClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEAttribute(getFindClause_End(), ecorePackage.getEString(), "end", null, 0, 1, FindClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(forClauseEClass, ForClause.class, "ForClause", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEAttribute(getForClause_Mode(), ecorePackage.getEString(), "mode", null, 0, 1, ForClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEReference(getForClause_EntityReferenceClause(), this.getEntityReferenceClause(), null, "entityReferenceClause", null, 0, 1, ForClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(entityReferenceClauseEClass, EntityReferenceClause.class, "EntityReferenceClause", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEReference(getEntityReferenceClause_EntityReferences(), this.getEntityReference(), null, "entityReferences", null, 0, -1, EntityReferenceClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(entityReferenceEClass, EntityReference.class, "EntityReference", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEAttribute(getEntityReference_Type(), ecorePackage.getEString(), "type", null, 0, 1, EntityReference.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEAttribute(getEntityReference_Identifier(), ecorePackage.getEString(), "identifier", null, 0, 1, EntityReference.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEReference(getEntityReference_Alias(), this.getAliasClause(), null, "alias", null, 0, 1, EntityReference.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(aliasClauseEClass, AliasClause.class, "AliasClause", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEAttribute(getAliasClause_Mode(), ecorePackage.getEString(), "mode", null, 0, 1, AliasClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEAttribute(getAliasClause_Alias(), ecorePackage.getEString(), "alias", null, 0, 1, AliasClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(usingClauseEClass, UsingClause.class, "UsingClause", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEAttribute(getUsingClause_Mode(), ecorePackage.getEString(), "mode", null, 0, 1, UsingClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEReference(getUsingClause_ModelReference(), this.getModelReferenceClause(), null, "modelReference", null, 0, 1, UsingClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(withClauseEClass, WithClause.class, "WithClause", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEAttribute(getWithClause_Mode(), ecorePackage.getEString(), "mode", null, 0, 1, WithClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEReference(getWithClause_ModelReference(), this.getModelReferenceClause(), null, "modelReference", null, 0, 1, WithClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(modelReferenceClauseEClass, ModelReferenceClause.class, "ModelReferenceClause", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEReference(getModelReferenceClause_Family(), this.getModelFamily(), null, "family", null, 0, 1, ModelReferenceClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEReference(getModelReferenceClause_Model(), this.getModelLocation(), null, "model", null, 0, 1, ModelReferenceClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(modelFamilyEClass, ModelFamily.class, "ModelFamily", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEAttribute(getModelFamily_Family(), ecorePackage.getEString(), "family", null, 0, 1, ModelFamily.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(modelLocationEClass, ModelLocation.class, "ModelLocation", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEAttribute(getModelLocation_Location(), ecorePackage.getEString(), "location", null, 0, 1, ModelLocation.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(filterClauseEClass, FilterClause.class, "FilterClause", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEAttribute(getFilterClause_Mode(), ecorePackage.getEString(), "mode", null, 0, 1, FilterClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEReference(getFilterClause_FilterConditions(), this.getFilterConditionClause(), null, "filterConditions", null, 0, -1, FilterClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEAttribute(getFilterClause_FilterConjunctions(), this.getFilterConjunction(), "filterConjunctions", null, 0, -1, FilterClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, !IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(filterConditionClauseEClass, FilterConditionClause.class, "FilterConditionClause", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEAttribute(getFilterConditionClause_Mode(), ecorePackage.getEString(), "mode", null, 0, 1, FilterConditionClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEAttribute(getFilterConditionClause_Condition(), this.getFilterConditionType(), "condition", null, 0, 1, FilterConditionClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEReference(getFilterConditionClause_Value(), this.getFilterConditionValue(), null, "value", null, 0, 1, FilterConditionClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(filterConditionValueEClass, FilterConditionValue.class, "FilterConditionValue", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEAttribute(getFilterConditionValue_Value(), ecorePackage.getEString(), "value", null, 0, 1, FilterConditionValue.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(observeClauseEClass, ObserveClause.class, "ObserveClause", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEAttribute(getObserveClause_Mode(), ecorePackage.getEString(), "mode", null, 0, 1, ObserveClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEReference(getObserveClause_Observation(), this.getObservationClause(), null, "observation", null, 0, 1, ObserveClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEReference(getObserveClause_SampleClause(), this.getSampleClause(), null, "sampleClause", null, 0, 1, ObserveClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(observationClauseEClass, ObservationClause.class, "ObservationClause", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);

    initEClass(sampleClauseEClass, SampleClause.class, "SampleClause", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEAttribute(getSampleClause_Mode(), ecorePackage.getEString(), "mode", null, 0, 1, SampleClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEReference(getSampleClause_DurationClause(), this.getRelativeTimeDurationClause(), null, "durationClause", null, 0, -1, SampleClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(connectorTimeUnitClauseEClass, ConnectorTimeUnitClause.class, "ConnectorTimeUnitClause", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEAttribute(getConnectorTimeUnitClause_Count(), ecorePackage.getEInt(), "count", null, 0, 1, ConnectorTimeUnitClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEAttribute(getConnectorTimeUnitClause_TimeIndicator(), ecorePackage.getEString(), "timeIndicator", null, 0, 1, ConnectorTimeUnitClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(connectorInstanceReferenceClauseEClass, ConnectorInstanceReferenceClause.class, "ConnectorInstanceReferenceClause", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEAttribute(getConnectorInstanceReferenceClause_Type(), ecorePackage.getEString(), "type", null, 0, 1, ConnectorInstanceReferenceClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEAttribute(getConnectorInstanceReferenceClause_Identifier(), ecorePackage.getEString(), "identifier", null, 0, 1, ConnectorInstanceReferenceClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(observeRelativeClauseEClass, ObserveRelativeClause.class, "ObserveRelativeClause", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEAttribute(getObserveRelativeClause_Direction(), this.getObserveRelativeDirectionType(), "direction", null, 0, 1, ObserveRelativeClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEReference(getObserveRelativeClause_TimeTarget(), this.getTimeClause(), null, "timeTarget", null, 0, 1, ObserveRelativeClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(observeBetweenClauseEClass, ObserveBetweenClause.class, "ObserveBetweenClause", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEAttribute(getObserveBetweenClause_Mode1(), ecorePackage.getEString(), "mode1", null, 0, 1, ObserveBetweenClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEReference(getObserveBetweenClause_StartingTime(), this.getBetweenTimeClause(), null, "startingTime", null, 0, 1, ObserveBetweenClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEAttribute(getObserveBetweenClause_Mode2(), ecorePackage.getEString(), "mode2", null, 0, 1, ObserveBetweenClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEReference(getObserveBetweenClause_EndingTime(), this.getBetweenTimeClause(), null, "endingTime", null, 0, 1, ObserveBetweenClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(relativeTimeWithSignClauseEClass, RelativeTimeWithSignClause.class, "RelativeTimeWithSignClause", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEAttribute(getRelativeTimeWithSignClause_Sign(), this.getRelativeTimeSignType(), "sign", null, 0, 1, RelativeTimeWithSignClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEReference(getRelativeTimeWithSignClause_TimeClause(), this.getRelativeTimeClause(), null, "timeClause", null, 0, 1, RelativeTimeWithSignClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(betweenTimeClauseEClass, BetweenTimeClause.class, "BetweenTimeClause", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);

    initEClass(timeClauseEClass, TimeClause.class, "TimeClause", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);

    initEClass(absoluteTimeClauseEClass, AbsoluteTimeClause.class, "AbsoluteTimeClause", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEAttribute(getAbsoluteTimeClause_TimeSpec(), ecorePackage.getEString(), "timeSpec", null, 0, 1, AbsoluteTimeClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(relativeTimeClauseEClass, RelativeTimeClause.class, "RelativeTimeClause", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEReference(getRelativeTimeClause_DurationClause(), this.getRelativeTimeDurationClause(), null, "durationClause", null, 0, -1, RelativeTimeClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(relativeTimeDurationClauseEClass, RelativeTimeDurationClause.class, "RelativeTimeDurationClause", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEAttribute(getRelativeTimeDurationClause_Duration(), ecorePackage.getEInt(), "duration", null, 0, 1, RelativeTimeDurationClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEAttribute(getRelativeTimeDurationClause_TimeModifier(), this.getTimeModifierType(), "timeModifier", null, 0, 1, RelativeTimeDurationClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(whatIfQueryEClass, WhatIfQuery.class, "WhatIfQuery", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEReference(getWhatIfQuery_WhatIfVariation(), this.getWhatIfVariation(), null, "whatIfVariation", null, 0, 1, WhatIfQuery.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEReference(getWhatIfQuery_MetricReferenceClauses(), this.getMetricReferenceClauses(), null, "metricReferenceClauses", null, 0, 1, WhatIfQuery.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEReference(getWhatIfQuery_ForClause(), this.getForClause(), null, "forClause", null, 0, 1, WhatIfQuery.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEReference(getWhatIfQuery_FilteringClause(), this.getFilteringClause(), null, "filteringClause", null, 0, 1, WhatIfQuery.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEAttribute(getWhatIfQuery_DeltaClause(), ecorePackage.getEString(), "deltaClause", null, 0, 1, WhatIfQuery.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEReference(getWhatIfQuery_UsingClause(), this.getUsingClause(), null, "usingClause", null, 0, 1, WhatIfQuery.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(whatIfVariationEClass, WhatIfVariation.class, "WhatIfVariation", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEReference(getWhatIfVariation_WhatIfVariationClause(), this.getWhatIfVariationClause(), null, "whatIfVariationClause", null, 0, -1, WhatIfVariation.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(filteringClauseEClass, FilteringClause.class, "FilteringClause", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEReference(getFilteringClause_FilterungRule(), this.getFilterigRule(), null, "filterungRule", null, 0, 1, FilteringClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEReference(getFilteringClause_FilteringStrategy(), this.getFilteringStrategy(), null, "filteringStrategy", null, 0, 1, FilteringClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(filteringStrategyEClass, FilteringStrategy.class, "FilteringStrategy", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEAttribute(getFilteringStrategy_FilteringStrategy(), ecorePackage.getEString(), "filteringStrategy", null, 0, 1, FilteringStrategy.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(filterigRuleEClass, FilterigRule.class, "FilterigRule", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEReference(getFilterigRule_FilteringValue(), this.getVariableValue(), null, "filteringValue", null, 0, 1, FilterigRule.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEAttribute(getFilterigRule_Modifier(), ecorePackage.getEString(), "modifier", null, 0, 1, FilterigRule.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(whatIfVariationClauseEClass, WhatIfVariationClause.class, "WhatIfVariationClause", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEAttribute(getWhatIfVariationClause_VariationPoint(), ecorePackage.getEString(), "variationPoint", null, 0, 1, WhatIfVariationClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEReference(getWhatIfVariationClause_Values(), this.getWhatIfValueVariationClause(), null, "values", null, 0, 1, WhatIfVariationClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(whatIfValueVariationClauseEClass, WhatIfValueVariationClause.class, "WhatIfValueVariationClause", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEReference(getWhatIfValueVariationClause_DofVariationClause(), this.getDoFVariationClause(), null, "dofVariationClause", null, 0, 1, WhatIfValueVariationClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEReference(getWhatIfValueVariationClause_MultipleArithmethicClause(), this.getMultipleArithmeticClause(), null, "multipleArithmethicClause", null, 0, 1, WhatIfValueVariationClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(multipleArithmeticClauseEClass, MultipleArithmeticClause.class, "MultipleArithmeticClause", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEReference(getMultipleArithmeticClause_MultiClause(), this.getArithmeticClause(), null, "multiClause", null, 0, -1, MultipleArithmeticClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(arithmeticClauseEClass, ArithmeticClause.class, "ArithmeticClause", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEAttribute(getArithmeticClause_Mode(), ecorePackage.getEString(), "mode", null, 0, 1, ArithmeticClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEReference(getArithmeticClause_Value(), this.getVariableValue(), null, "value", null, 0, 1, ArithmeticClause.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, IS_COMPOSITE, !IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    initEClass(variableValueEClass, VariableValue.class, "VariableValue", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
    initEAttribute(getVariableValue_IntValue(), ecorePackage.getEInt(), "intValue", null, 0, 1, VariableValue.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
    initEAttribute(getVariableValue_DoubleValue(), ecorePackage.getEDouble(), "doubleValue", null, 0, 1, VariableValue.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);

    // Initialize enums and add enum literals
    initEEnum(comparatorEEnum, Comparator.class, "Comparator");
    addEEnumLiteral(comparatorEEnum, Comparator.LESS);
    addEEnumLiteral(comparatorEEnum, Comparator.LESS_EQUAL);
    addEEnumLiteral(comparatorEEnum, Comparator.GREATER);
    addEEnumLiteral(comparatorEEnum, Comparator.GREATER_EQUAL);
    addEEnumLiteral(comparatorEEnum, Comparator.EQUAL);

    initEEnum(currencyEEnum, Currency.class, "Currency");
    addEEnumLiteral(currencyEEnum, Currency.EURO);
    addEEnumLiteral(currencyEEnum, Currency.US_DOLLAR);

    initEEnum(filterConjunctionEEnum, FilterConjunction.class, "FilterConjunction");
    addEEnumLiteral(filterConjunctionEEnum, FilterConjunction.AND);
    addEEnumLiteral(filterConjunctionEEnum, FilterConjunction.XOR);
    addEEnumLiteral(filterConjunctionEEnum, FilterConjunction.OR);

    initEEnum(filterConditionTypeEEnum, FilterConditionType.class, "FilterConditionType");
    addEEnumLiteral(filterConditionTypeEEnum, FilterConditionType.INSTANCEOF);
    addEEnumLiteral(filterConditionTypeEEnum, FilterConditionType.CLASSREGEX);

    initEEnum(observeRelativeDirectionTypeEEnum, ObserveRelativeDirectionType.class, "ObserveRelativeDirectionType");
    addEEnumLiteral(observeRelativeDirectionTypeEEnum, ObserveRelativeDirectionType.SINCE);
    addEEnumLiteral(observeRelativeDirectionTypeEEnum, ObserveRelativeDirectionType.NEXT);

    initEEnum(relativeTimeSignTypeEEnum, RelativeTimeSignType.class, "RelativeTimeSignType");
    addEEnumLiteral(relativeTimeSignTypeEEnum, RelativeTimeSignType.MINUS);
    addEEnumLiteral(relativeTimeSignTypeEEnum, RelativeTimeSignType.PLUS);

    initEEnum(timeModifierTypeEEnum, TimeModifierType.class, "TimeModifierType");
    addEEnumLiteral(timeModifierTypeEEnum, TimeModifierType.YEAR);
    addEEnumLiteral(timeModifierTypeEEnum, TimeModifierType.MONTH);
    addEEnumLiteral(timeModifierTypeEEnum, TimeModifierType.WEEK);
    addEEnumLiteral(timeModifierTypeEEnum, TimeModifierType.DAY);
    addEEnumLiteral(timeModifierTypeEEnum, TimeModifierType.HOUR);
    addEEnumLiteral(timeModifierTypeEEnum, TimeModifierType.MINUTE);
    addEEnumLiteral(timeModifierTypeEEnum, TimeModifierType.SECOND);
    addEEnumLiteral(timeModifierTypeEEnum, TimeModifierType.MILLISECOND);

    initEEnum(statisticalAggregateTypeEEnum, StatisticalAggregateType.class, "StatisticalAggregateType");
    addEEnumLiteral(statisticalAggregateTypeEEnum, StatisticalAggregateType.MIN);
    addEEnumLiteral(statisticalAggregateTypeEEnum, StatisticalAggregateType.MAX);
    addEEnumLiteral(statisticalAggregateTypeEEnum, StatisticalAggregateType.GEOMEAN);
    addEEnumLiteral(statisticalAggregateTypeEEnum, StatisticalAggregateType.N);
    addEEnumLiteral(statisticalAggregateTypeEEnum, StatisticalAggregateType.SUM);
    addEEnumLiteral(statisticalAggregateTypeEEnum, StatisticalAggregateType.SUMOFSQUARES);
    addEEnumLiteral(statisticalAggregateTypeEEnum, StatisticalAggregateType.STDDEV);
    addEEnumLiteral(statisticalAggregateTypeEEnum, StatisticalAggregateType.VAR);
    addEEnumLiteral(statisticalAggregateTypeEEnum, StatisticalAggregateType.PERCENTILE);
    addEEnumLiteral(statisticalAggregateTypeEEnum, StatisticalAggregateType.MEAN);

    // Create resource
    createResource(eNS_URI);
  }

} //DescartesQLPackageImpl
