/**
 * ==============================================
 *  DQL : Descartes Query Language
 * ==============================================
 * 
 * (c) Copyright 2014-2016, by Juergen Walter, Fabian Gorsler, Fabian Brosig and other contributors.
 * 
 * Project Info:   http://descartes.tools/dql
 * 
 * All rights reserved. This software is made available under the terms of the 
 * Eclipse Public License (EPL) v1.0 as published by the Eclipse Foundation
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * This software is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the Eclipse Public License (EPL)
 * for more details.
 * 
 * You should have received a copy of the Eclipse Public License (EPL)
 * along with this software; if not visit http://www.eclipse.org or write to
 * Eclipse Foundation, Inc., 308 SW First Avenue, Suite 110, Portland, 97204 USA
 * Email: license (at) eclipse.org 
 * 
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
 * in the United States and other countries.]
 */
package tools.descartes.dql.lang.descartesQL.util;

import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.EPackage;

import org.eclipse.emf.ecore.util.Switch;

import tools.descartes.dql.lang.descartesQL.*;

/**
 * <!-- begin-user-doc -->
 * The <b>Switch</b> for the model's inheritance hierarchy.
 * It supports the call {@link #doSwitch(EObject) doSwitch(object)}
 * to invoke the <code>caseXXX</code> method for each class of the model,
 * starting with the actual class of the object
 * and proceeding up the inheritance hierarchy
 * until a non-null result is returned,
 * which is the result of the switch.
 * <!-- end-user-doc -->
 * @see tools.descartes.dql.lang.descartesQL.DescartesQLPackage
 * @generated
 */
public class DescartesQLSwitch<T> extends Switch<T>
{
  /**
   * The cached model package
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  protected static DescartesQLPackage modelPackage;

  /**
   * Creates an instance of the switch.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @generated
   */
  public DescartesQLSwitch()
  {
    if (modelPackage == null)
    {
      modelPackage = DescartesQLPackage.eINSTANCE;
    }
  }

  /**
   * Checks whether this is a switch for the given package.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @param ePackage the package in question.
   * @return whether this is a switch for the given package.
   * @generated
   */
  @Override
  protected boolean isSwitchFor(EPackage ePackage)
  {
    return ePackage == modelPackage;
  }

  /**
   * Calls <code>caseXXX</code> for each class of the model until one returns a non null result; it yields that result.
   * <!-- begin-user-doc -->
   * <!-- end-user-doc -->
   * @return the first non-null result returned by a <code>caseXXX</code> call.
   * @generated
   */
  @Override
  protected T doSwitch(int classifierID, EObject theEObject)
  {
    switch (classifierID)
    {
      case DescartesQLPackage.DESCARTES_QL:
      {
        DescartesQL descartesQL = (DescartesQL)theEObject;
        T result = caseDescartesQL(descartesQL);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.GOAL:
      {
        Goal goal = (Goal)theEObject;
        T result = caseGoal(goal);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.SLA_QUERY:
      {
        SlaQuery slaQuery = (SlaQuery)theEObject;
        T result = caseSlaQuery(slaQuery);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.SLO_QUERY:
      {
        SloQuery sloQuery = (SloQuery)theEObject;
        T result = caseSloQuery(sloQuery);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.SLA:
      {
        Sla sla = (Sla)theEObject;
        T result = caseSla(sla);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.SLO:
      {
        Slo slo = (Slo)theEObject;
        T result = caseSlo(slo);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.WEIGHTED_SLO:
      {
        WeightedSlo weightedSlo = (WeightedSlo)theEObject;
        T result = caseWeightedSlo(weightedSlo);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.FUZZINESS:
      {
        Fuzziness fuzziness = (Fuzziness)theEObject;
        T result = caseFuzziness(fuzziness);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.PENALTY:
      {
        Penalty penalty = (Penalty)theEObject;
        T result = casePenalty(penalty);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.VIOLATION:
      {
        Violation violation = (Violation)theEObject;
        T result = caseViolation(violation);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.MODEL_STRUCTURE_QUERY:
      {
        ModelStructureQuery modelStructureQuery = (ModelStructureQuery)theEObject;
        T result = caseModelStructureQuery(modelStructureQuery);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.PERFORMANCE_METRICS_QUERY:
      {
        PerformanceMetricsQuery performanceMetricsQuery = (PerformanceMetricsQuery)theEObject;
        T result = casePerformanceMetricsQuery(performanceMetricsQuery);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.PERFORMANCE_ISSUE_QUERY:
      {
        PerformanceIssueQuery performanceIssueQuery = (PerformanceIssueQuery)theEObject;
        T result = casePerformanceIssueQuery(performanceIssueQuery);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.CONNECTOR_CAPABILITY_QUERY:
      {
        ConnectorCapabilityQuery connectorCapabilityQuery = (ConnectorCapabilityQuery)theEObject;
        T result = caseConnectorCapabilityQuery(connectorCapabilityQuery);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.LIST_QUERY:
      {
        ListQuery listQuery = (ListQuery)theEObject;
        T result = caseListQuery(listQuery);
        if (result == null) result = caseModelStructureQuery(listQuery);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.GET_QUERY:
      {
        GetQuery getQuery = (GetQuery)theEObject;
        T result = caseGetQuery(getQuery);
        if (result == null) result = caseConnectorCapabilityQuery(getQuery);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.GET_CONSTRAINTS_QUERY:
      {
        GetConstraintsQuery getConstraintsQuery = (GetConstraintsQuery)theEObject;
        T result = caseGetConstraintsQuery(getConstraintsQuery);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.GET_EXPLORATION_STRATEGIES_QUERY:
      {
        GetExplorationStrategiesQuery getExplorationStrategiesQuery = (GetExplorationStrategiesQuery)theEObject;
        T result = caseGetExplorationStrategiesQuery(getExplorationStrategiesQuery);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.GET_TIME_UNITS_QUERY:
      {
        GetTimeUnitsQuery getTimeUnitsQuery = (GetTimeUnitsQuery)theEObject;
        T result = caseGetTimeUnitsQuery(getTimeUnitsQuery);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.LIST_DO_FQUERY:
      {
        ListDoFQuery listDoFQuery = (ListDoFQuery)theEObject;
        T result = caseListDoFQuery(listDoFQuery);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.LIST_ENTITIES_QUERY:
      {
        ListEntitiesQuery listEntitiesQuery = (ListEntitiesQuery)theEObject;
        T result = caseListEntitiesQuery(listEntitiesQuery);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.LIST_METRICS_QUERY:
      {
        ListMetricsQuery listMetricsQuery = (ListMetricsQuery)theEObject;
        T result = caseListMetricsQuery(listMetricsQuery);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.SELECT_QUERY:
      {
        SelectQuery selectQuery = (SelectQuery)theEObject;
        T result = caseSelectQuery(selectQuery);
        if (result == null) result = casePerformanceMetricsQuery(selectQuery);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.METRIC_REFERENCE_CLAUSES:
      {
        MetricReferenceClauses metricReferenceClauses = (MetricReferenceClauses)theEObject;
        T result = caseMetricReferenceClauses(metricReferenceClauses);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.METRIC_CLAUSE_TYPE:
      {
        MetricClauseType metricClauseType = (MetricClauseType)theEObject;
        T result = caseMetricClauseType(metricClauseType);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.DETECT_QUERY:
      {
        DetectQuery detectQuery = (DetectQuery)theEObject;
        T result = caseDetectQuery(detectQuery);
        if (result == null) result = casePerformanceIssueQuery(detectQuery);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.DETECT_BOTTLENECKS_QUERY:
      {
        DetectBottlenecksQuery detectBottlenecksQuery = (DetectBottlenecksQuery)theEObject;
        T result = caseDetectBottlenecksQuery(detectBottlenecksQuery);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.CONSTRAINT_CLAUSE:
      {
        ConstraintClause constraintClause = (ConstraintClause)theEObject;
        T result = caseConstraintClause(constraintClause);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.DO_FCLAUSE:
      {
        DoFClause doFClause = (DoFClause)theEObject;
        T result = caseDoFClause(doFClause);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.EXPLORATION_STRATEGY_CLAUSE:
      {
        ExplorationStrategyClause explorationStrategyClause = (ExplorationStrategyClause)theEObject;
        T result = caseExplorationStrategyClause(explorationStrategyClause);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.CONFIGURATION_PROPERTIES_CLAUSE:
      {
        ConfigurationPropertiesClause configurationPropertiesClause = (ConfigurationPropertiesClause)theEObject;
        T result = caseConfigurationPropertiesClause(configurationPropertiesClause);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.CONFIGURATION_PROPERTY_CLAUSE:
      {
        ConfigurationPropertyClause configurationPropertyClause = (ConfigurationPropertyClause)theEObject;
        T result = caseConfigurationPropertyClause(configurationPropertyClause);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.DO_FVARIATION_CLAUSE:
      {
        DoFVariationClause doFVariationClause = (DoFVariationClause)theEObject;
        T result = caseDoFVariationClause(doFVariationClause);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.VALUE_VARIATION_CLAUSE:
      {
        ValueVariationClause valueVariationClause = (ValueVariationClause)theEObject;
        T result = caseValueVariationClause(valueVariationClause);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.INTERVAL_VARIATION_CLAUSE:
      {
        IntervalVariationClause intervalVariationClause = (IntervalVariationClause)theEObject;
        T result = caseIntervalVariationClause(intervalVariationClause);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.VARYING_CLAUSE:
      {
        VaryingClause varyingClause = (VaryingClause)theEObject;
        T result = caseVaryingClause(varyingClause);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.DO_FREFERENCE:
      {
        DoFReference doFReference = (DoFReference)theEObject;
        T result = caseDoFReference(doFReference);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.METRIC_CLAUSE:
      {
        MetricClause metricClause = (MetricClause)theEObject;
        T result = caseMetricClause(metricClause);
        if (result == null) result = caseMetricClauseType(metricClause);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.AGGREGATE_METRIC_CLAUSE:
      {
        AggregateMetricClause aggregateMetricClause = (AggregateMetricClause)theEObject;
        T result = caseAggregateMetricClause(aggregateMetricClause);
        if (result == null) result = caseMetricClauseType(aggregateMetricClause);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.METRIC_CLAUSES:
      {
        MetricClauses metricClauses = (MetricClauses)theEObject;
        T result = caseMetricClauses(metricClauses);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.METRIC_STAR_CLAUSE:
      {
        MetricStarClause metricStarClause = (MetricStarClause)theEObject;
        T result = caseMetricStarClause(metricStarClause);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.METRIC_REFERENCE:
      {
        MetricReference metricReference = (MetricReference)theEObject;
        T result = caseMetricReference(metricReference);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.NAVIGATION_CLAUSE:
      {
        NavigationClause navigationClause = (NavigationClause)theEObject;
        T result = caseNavigationClause(navigationClause);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.CHILDREN_CLAUSE:
      {
        ChildrenClause childrenClause = (ChildrenClause)theEObject;
        T result = caseChildrenClause(childrenClause);
        if (result == null) result = caseNavigationClause(childrenClause);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.PARENT_CLAUSE:
      {
        ParentClause parentClause = (ParentClause)theEObject;
        T result = caseParentClause(parentClause);
        if (result == null) result = caseNavigationClause(parentClause);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.FIND_CLAUSE:
      {
        FindClause findClause = (FindClause)theEObject;
        T result = caseFindClause(findClause);
        if (result == null) result = caseNavigationClause(findClause);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.FOR_CLAUSE:
      {
        ForClause forClause = (ForClause)theEObject;
        T result = caseForClause(forClause);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.ENTITY_REFERENCE_CLAUSE:
      {
        EntityReferenceClause entityReferenceClause = (EntityReferenceClause)theEObject;
        T result = caseEntityReferenceClause(entityReferenceClause);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.ENTITY_REFERENCE:
      {
        EntityReference entityReference = (EntityReference)theEObject;
        T result = caseEntityReference(entityReference);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.ALIAS_CLAUSE:
      {
        AliasClause aliasClause = (AliasClause)theEObject;
        T result = caseAliasClause(aliasClause);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.USING_CLAUSE:
      {
        UsingClause usingClause = (UsingClause)theEObject;
        T result = caseUsingClause(usingClause);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.WITH_CLAUSE:
      {
        WithClause withClause = (WithClause)theEObject;
        T result = caseWithClause(withClause);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.MODEL_REFERENCE_CLAUSE:
      {
        ModelReferenceClause modelReferenceClause = (ModelReferenceClause)theEObject;
        T result = caseModelReferenceClause(modelReferenceClause);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.MODEL_FAMILY:
      {
        ModelFamily modelFamily = (ModelFamily)theEObject;
        T result = caseModelFamily(modelFamily);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.MODEL_LOCATION:
      {
        ModelLocation modelLocation = (ModelLocation)theEObject;
        T result = caseModelLocation(modelLocation);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.FILTER_CLAUSE:
      {
        FilterClause filterClause = (FilterClause)theEObject;
        T result = caseFilterClause(filterClause);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.FILTER_CONDITION_CLAUSE:
      {
        FilterConditionClause filterConditionClause = (FilterConditionClause)theEObject;
        T result = caseFilterConditionClause(filterConditionClause);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.FILTER_CONDITION_VALUE:
      {
        FilterConditionValue filterConditionValue = (FilterConditionValue)theEObject;
        T result = caseFilterConditionValue(filterConditionValue);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.OBSERVE_CLAUSE:
      {
        ObserveClause observeClause = (ObserveClause)theEObject;
        T result = caseObserveClause(observeClause);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.OBSERVATION_CLAUSE:
      {
        ObservationClause observationClause = (ObservationClause)theEObject;
        T result = caseObservationClause(observationClause);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.SAMPLE_CLAUSE:
      {
        SampleClause sampleClause = (SampleClause)theEObject;
        T result = caseSampleClause(sampleClause);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.CONNECTOR_TIME_UNIT_CLAUSE:
      {
        ConnectorTimeUnitClause connectorTimeUnitClause = (ConnectorTimeUnitClause)theEObject;
        T result = caseConnectorTimeUnitClause(connectorTimeUnitClause);
        if (result == null) result = caseObservationClause(connectorTimeUnitClause);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.CONNECTOR_INSTANCE_REFERENCE_CLAUSE:
      {
        ConnectorInstanceReferenceClause connectorInstanceReferenceClause = (ConnectorInstanceReferenceClause)theEObject;
        T result = caseConnectorInstanceReferenceClause(connectorInstanceReferenceClause);
        if (result == null) result = caseObservationClause(connectorInstanceReferenceClause);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.OBSERVE_RELATIVE_CLAUSE:
      {
        ObserveRelativeClause observeRelativeClause = (ObserveRelativeClause)theEObject;
        T result = caseObserveRelativeClause(observeRelativeClause);
        if (result == null) result = caseObservationClause(observeRelativeClause);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.OBSERVE_BETWEEN_CLAUSE:
      {
        ObserveBetweenClause observeBetweenClause = (ObserveBetweenClause)theEObject;
        T result = caseObserveBetweenClause(observeBetweenClause);
        if (result == null) result = caseObservationClause(observeBetweenClause);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.RELATIVE_TIME_WITH_SIGN_CLAUSE:
      {
        RelativeTimeWithSignClause relativeTimeWithSignClause = (RelativeTimeWithSignClause)theEObject;
        T result = caseRelativeTimeWithSignClause(relativeTimeWithSignClause);
        if (result == null) result = caseBetweenTimeClause(relativeTimeWithSignClause);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.BETWEEN_TIME_CLAUSE:
      {
        BetweenTimeClause betweenTimeClause = (BetweenTimeClause)theEObject;
        T result = caseBetweenTimeClause(betweenTimeClause);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.TIME_CLAUSE:
      {
        TimeClause timeClause = (TimeClause)theEObject;
        T result = caseTimeClause(timeClause);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.ABSOLUTE_TIME_CLAUSE:
      {
        AbsoluteTimeClause absoluteTimeClause = (AbsoluteTimeClause)theEObject;
        T result = caseAbsoluteTimeClause(absoluteTimeClause);
        if (result == null) result = caseBetweenTimeClause(absoluteTimeClause);
        if (result == null) result = caseTimeClause(absoluteTimeClause);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.RELATIVE_TIME_CLAUSE:
      {
        RelativeTimeClause relativeTimeClause = (RelativeTimeClause)theEObject;
        T result = caseRelativeTimeClause(relativeTimeClause);
        if (result == null) result = caseTimeClause(relativeTimeClause);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.RELATIVE_TIME_DURATION_CLAUSE:
      {
        RelativeTimeDurationClause relativeTimeDurationClause = (RelativeTimeDurationClause)theEObject;
        T result = caseRelativeTimeDurationClause(relativeTimeDurationClause);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.WHAT_IF_QUERY:
      {
        WhatIfQuery whatIfQuery = (WhatIfQuery)theEObject;
        T result = caseWhatIfQuery(whatIfQuery);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.WHAT_IF_VARIATION:
      {
        WhatIfVariation whatIfVariation = (WhatIfVariation)theEObject;
        T result = caseWhatIfVariation(whatIfVariation);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.FILTERING_CLAUSE:
      {
        FilteringClause filteringClause = (FilteringClause)theEObject;
        T result = caseFilteringClause(filteringClause);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.FILTERING_STRATEGY:
      {
        FilteringStrategy filteringStrategy = (FilteringStrategy)theEObject;
        T result = caseFilteringStrategy(filteringStrategy);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.FILTERIG_RULE:
      {
        FilterigRule filterigRule = (FilterigRule)theEObject;
        T result = caseFilterigRule(filterigRule);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.WHAT_IF_VARIATION_CLAUSE:
      {
        WhatIfVariationClause whatIfVariationClause = (WhatIfVariationClause)theEObject;
        T result = caseWhatIfVariationClause(whatIfVariationClause);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.WHAT_IF_VALUE_VARIATION_CLAUSE:
      {
        WhatIfValueVariationClause whatIfValueVariationClause = (WhatIfValueVariationClause)theEObject;
        T result = caseWhatIfValueVariationClause(whatIfValueVariationClause);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.MULTIPLE_ARITHMETIC_CLAUSE:
      {
        MultipleArithmeticClause multipleArithmeticClause = (MultipleArithmeticClause)theEObject;
        T result = caseMultipleArithmeticClause(multipleArithmeticClause);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.ARITHMETIC_CLAUSE:
      {
        ArithmeticClause arithmeticClause = (ArithmeticClause)theEObject;
        T result = caseArithmeticClause(arithmeticClause);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      case DescartesQLPackage.VARIABLE_VALUE:
      {
        VariableValue variableValue = (VariableValue)theEObject;
        T result = caseVariableValue(variableValue);
        if (result == null) result = defaultCase(theEObject);
        return result;
      }
      default: return defaultCase(theEObject);
    }
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Descartes QL</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Descartes QL</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseDescartesQL(DescartesQL object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Goal</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Goal</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseGoal(Goal object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Sla Query</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Sla Query</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseSlaQuery(SlaQuery object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Slo Query</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Slo Query</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseSloQuery(SloQuery object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Sla</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Sla</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseSla(Sla object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Slo</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Slo</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseSlo(Slo object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Weighted Slo</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Weighted Slo</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseWeightedSlo(WeightedSlo object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Fuzziness</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Fuzziness</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseFuzziness(Fuzziness object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Penalty</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Penalty</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T casePenalty(Penalty object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Violation</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Violation</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseViolation(Violation object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Model Structure Query</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Model Structure Query</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseModelStructureQuery(ModelStructureQuery object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Performance Metrics Query</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Performance Metrics Query</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T casePerformanceMetricsQuery(PerformanceMetricsQuery object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Performance Issue Query</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Performance Issue Query</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T casePerformanceIssueQuery(PerformanceIssueQuery object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Connector Capability Query</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Connector Capability Query</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseConnectorCapabilityQuery(ConnectorCapabilityQuery object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>List Query</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>List Query</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseListQuery(ListQuery object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Get Query</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Get Query</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseGetQuery(GetQuery object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Get Constraints Query</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Get Constraints Query</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseGetConstraintsQuery(GetConstraintsQuery object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Get Exploration Strategies Query</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Get Exploration Strategies Query</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseGetExplorationStrategiesQuery(GetExplorationStrategiesQuery object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Get Time Units Query</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Get Time Units Query</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseGetTimeUnitsQuery(GetTimeUnitsQuery object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>List Do FQuery</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>List Do FQuery</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseListDoFQuery(ListDoFQuery object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>List Entities Query</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>List Entities Query</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseListEntitiesQuery(ListEntitiesQuery object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>List Metrics Query</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>List Metrics Query</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseListMetricsQuery(ListMetricsQuery object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Select Query</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Select Query</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseSelectQuery(SelectQuery object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Metric Reference Clauses</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Metric Reference Clauses</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseMetricReferenceClauses(MetricReferenceClauses object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Metric Clause Type</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Metric Clause Type</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseMetricClauseType(MetricClauseType object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Detect Query</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Detect Query</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseDetectQuery(DetectQuery object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Detect Bottlenecks Query</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Detect Bottlenecks Query</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseDetectBottlenecksQuery(DetectBottlenecksQuery object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Constraint Clause</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Constraint Clause</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseConstraintClause(ConstraintClause object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Do FClause</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Do FClause</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseDoFClause(DoFClause object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Exploration Strategy Clause</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Exploration Strategy Clause</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseExplorationStrategyClause(ExplorationStrategyClause object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Configuration Properties Clause</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Configuration Properties Clause</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseConfigurationPropertiesClause(ConfigurationPropertiesClause object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Configuration Property Clause</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Configuration Property Clause</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseConfigurationPropertyClause(ConfigurationPropertyClause object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Do FVariation Clause</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Do FVariation Clause</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseDoFVariationClause(DoFVariationClause object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Value Variation Clause</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Value Variation Clause</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseValueVariationClause(ValueVariationClause object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Interval Variation Clause</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Interval Variation Clause</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseIntervalVariationClause(IntervalVariationClause object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Varying Clause</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Varying Clause</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseVaryingClause(VaryingClause object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Do FReference</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Do FReference</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseDoFReference(DoFReference object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Metric Clause</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Metric Clause</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseMetricClause(MetricClause object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Aggregate Metric Clause</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Aggregate Metric Clause</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseAggregateMetricClause(AggregateMetricClause object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Metric Clauses</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Metric Clauses</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseMetricClauses(MetricClauses object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Metric Star Clause</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Metric Star Clause</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseMetricStarClause(MetricStarClause object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Metric Reference</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Metric Reference</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseMetricReference(MetricReference object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Navigation Clause</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Navigation Clause</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseNavigationClause(NavigationClause object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Children Clause</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Children Clause</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseChildrenClause(ChildrenClause object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Parent Clause</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Parent Clause</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseParentClause(ParentClause object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Find Clause</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Find Clause</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseFindClause(FindClause object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>For Clause</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>For Clause</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseForClause(ForClause object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Entity Reference Clause</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Entity Reference Clause</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseEntityReferenceClause(EntityReferenceClause object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Entity Reference</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Entity Reference</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseEntityReference(EntityReference object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Alias Clause</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Alias Clause</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseAliasClause(AliasClause object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Using Clause</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Using Clause</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseUsingClause(UsingClause object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>With Clause</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>With Clause</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseWithClause(WithClause object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Model Reference Clause</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Model Reference Clause</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseModelReferenceClause(ModelReferenceClause object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Model Family</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Model Family</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseModelFamily(ModelFamily object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Model Location</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Model Location</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseModelLocation(ModelLocation object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Filter Clause</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Filter Clause</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseFilterClause(FilterClause object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Filter Condition Clause</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Filter Condition Clause</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseFilterConditionClause(FilterConditionClause object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Filter Condition Value</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Filter Condition Value</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseFilterConditionValue(FilterConditionValue object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Observe Clause</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Observe Clause</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseObserveClause(ObserveClause object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Observation Clause</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Observation Clause</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseObservationClause(ObservationClause object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Sample Clause</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Sample Clause</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseSampleClause(SampleClause object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Connector Time Unit Clause</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Connector Time Unit Clause</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseConnectorTimeUnitClause(ConnectorTimeUnitClause object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Connector Instance Reference Clause</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Connector Instance Reference Clause</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseConnectorInstanceReferenceClause(ConnectorInstanceReferenceClause object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Observe Relative Clause</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Observe Relative Clause</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseObserveRelativeClause(ObserveRelativeClause object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Observe Between Clause</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Observe Between Clause</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseObserveBetweenClause(ObserveBetweenClause object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Relative Time With Sign Clause</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Relative Time With Sign Clause</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseRelativeTimeWithSignClause(RelativeTimeWithSignClause object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Between Time Clause</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Between Time Clause</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseBetweenTimeClause(BetweenTimeClause object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Time Clause</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Time Clause</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseTimeClause(TimeClause object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Absolute Time Clause</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Absolute Time Clause</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseAbsoluteTimeClause(AbsoluteTimeClause object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Relative Time Clause</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Relative Time Clause</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseRelativeTimeClause(RelativeTimeClause object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Relative Time Duration Clause</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Relative Time Duration Clause</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseRelativeTimeDurationClause(RelativeTimeDurationClause object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>What If Query</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>What If Query</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseWhatIfQuery(WhatIfQuery object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>What If Variation</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>What If Variation</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseWhatIfVariation(WhatIfVariation object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Filtering Clause</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Filtering Clause</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseFilteringClause(FilteringClause object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Filtering Strategy</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Filtering Strategy</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseFilteringStrategy(FilteringStrategy object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Filterig Rule</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Filterig Rule</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseFilterigRule(FilterigRule object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>What If Variation Clause</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>What If Variation Clause</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseWhatIfVariationClause(WhatIfVariationClause object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>What If Value Variation Clause</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>What If Value Variation Clause</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseWhatIfValueVariationClause(WhatIfValueVariationClause object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Multiple Arithmetic Clause</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Multiple Arithmetic Clause</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseMultipleArithmeticClause(MultipleArithmeticClause object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Arithmetic Clause</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Arithmetic Clause</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseArithmeticClause(ArithmeticClause object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>Variable Value</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>Variable Value</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
   * @generated
   */
  public T caseVariableValue(VariableValue object)
  {
    return null;
  }

  /**
   * Returns the result of interpreting the object as an instance of '<em>EObject</em>'.
   * <!-- begin-user-doc -->
   * This implementation returns null;
   * returning a non-null result will terminate the switch, but this is the last case anyway.
   * <!-- end-user-doc -->
   * @param object the target of the switch.
   * @return the result of interpreting the object as an instance of '<em>EObject</em>'.
   * @see #doSwitch(org.eclipse.emf.ecore.EObject)
   * @generated
   */
  @Override
  public T defaultCase(EObject object)
  {
    return null;
  }

} //DescartesQLSwitch
