/**
 * ==============================================
 *  DQL : Descartes Query Language
 * ==============================================
 *
 * (c) Copyright 2014-2016, by Juergen Walter, Fabian Gorsler, Fabian Brosig and other contributors.
 *
 * Project Info:   http://descartes.tools/dql
 *
 * All rights reserved. This software is made available under the terms of the
 * Eclipse Public License (EPL) v1.0 as published by the Eclipse Foundation
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * This software is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the Eclipse Public License (EPL)
 * for more details.
 *
 * You should have received a copy of the Eclipse Public License (EPL)
 * along with this software; if not visit http://www.eclipse.org or write to
 * Eclipse Foundation, Inc., 308 SW First Avenue, Suite 110, Portland, 97204 USA
 * Email: license (at) eclipse.org
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
 * in the United States and other countries.]
 */
package tools.descartes.pavo.controller;

import java.awt.Rectangle;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.WindowEvent;
import java.awt.event.WindowListener;
import java.io.File;
import java.io.IOException;
import java.io.PrintWriter;
import java.math.BigDecimal;
import javax.swing.JFileChooser;
import org.jfree.chart.ChartUtilities;
import org.jfree.chart.JFreeChart;
import org.jfree.graphics2d.svg.SVGGraphics2D;
import org.jfree.graphics2d.svg.SVGUtils;
import tools.descartes.pavo.view.ExportDialogFrame;
import tools.descartes.pavo.view.View;
import tools.descartes.pavo.result.*;;


/**
 * class to visualize all probes of one resource into one pane. These panes are
 * merged within the graphicsengine
 */

public class ExportController {

	private static JFileChooser c = new JFileChooser();
	private ExportDialogFrame select;
	private ResultContainerPavo result;
	private JFreeChart chart;
	private View view;
	ActionListener normal;
	ActionListener test;
	


	public void exportDiagram(View viewN, JFreeChart chartN, ResultContainerPavo resultN) {
		view = viewN;
		chart = chartN;
		result = resultN;
		double d = (double) (view.getChartPanel().getHeight());
		double b = (double) (view.getChartPanel().getWidth());
		double faktorforWandH = d / b;
		select = new ExportDialogFrame(faktorforWandH);

		createActionListener();
		select.getFinishButton().addActionListener(normal);
		
	}
	
	public void createActionListener()
	{
		
				

		normal = new ActionListener() {
			
		@Override
		public void actionPerformed(ActionEvent e) {
			select.setSaveSuccessful(true);
			
			
			
			int a = c.showSaveDialog(null);
			
			if (a == JFileChooser.CANCEL_OPTION) {
				System.out.println("Canceled Save Action!");
			} else {
				final File file = c.getSelectedFile();
				String name = file.getPath();
				final File fileToUse;

				if(select.getKindOfExport().getSelectedItem().equals("CSV Export"))
				{
					if (name.length() < 3 || !name.substring(name.length() - 3, name.length()).equals("csv")) {
						fileToUse = new File(name + ".csv");
					} else {
						fileToUse = file;
					}
					
					saveAsCSV(fileToUse);
					
					
				}
				
				else if(select.getKindOfExport().getSelectedItem().equals("Vector Graphic"))
				{
					if (name.length() < 3 || !name.substring(name.length() - 3, name.length()).equals("svg")) {
						fileToUse = new File(name + ".svg");
					} else {
						fileToUse = file;
					}
					
					saveAsVector(fileToUse);
					
				}
				
				else if(select.getKindOfExport().getSelectedItem().equals("PNG Export"))
				{
					if (name.length() < 3 || !name.substring(name.length() - 3, name.length()).equals("png")) {
						fileToUse = new File(name + ".png");
					} else {
						fileToUse = file;
					}
					
					select.addWindowListener(new WindowListener() {

						@Override
						public void windowOpened(WindowEvent e) {
						}

						@Override
						public void windowIconified(WindowEvent e) {
						}

						@Override
						public void windowDeiconified(WindowEvent e) {
						}

						@Override
						public void windowDeactivated(WindowEvent e) {
						}

						@Override
						public void windowClosing(WindowEvent e) {
						}

						@Override
						public void windowClosed(WindowEvent e) {
							try {
								if (select.getSuccess() == true) {
									ChartUtilities.saveChartAsPNG(fileToUse, chart, select.getWidthFromText(),
											select.getHeightFromText());
								}

							} catch (IOException e1) {
							}

						}

						@Override
						public void windowActivated(WindowEvent e) {
						}
					});
				}
					
		
			}
			
			
			
			
			
			select.close();
			
		}

		private void saveAsVector(File fileToUse) {
			SVGGraphics2D g2 = new SVGGraphics2D(600, 400); 
	        Rectangle r = new Rectangle(0, 0, 600, 400); 
	        chart.draw(g2, r); 
	        File f = new File(fileToUse.getPath()); 
	        try {
				SVGUtils.writeToSVG(f, g2.getSVGElement());
			} catch (IOException e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			} 
			
		}
	};
		
		
		
		

	}


	public String writeLine(String string, Double double1, Double double2, BigDecimal bigDecimal)
	{
		String s = string + "," + double1 + "," + double2 + ","+ bigDecimal.toString()+"\n";
		return s;
	}
	

	private void saveAsCSV(File csvFile) {
		//SeriesName, KindOfResult
		//SeriesName, X, Y, ConfidenceIntervalHalfLength
		StringBuilder csv = new StringBuilder();
		for(AbstractQuantitativeResult r : result.getResults())
		{
			for(int i = 0; i < ((SeriesResultPavo) r).getXvalues().size(); i++)
			{
				csv.append(writeLine(r.getQueryableElement()+r.getMetric()+r.getStatisticType(), ((SeriesResultPavo) r).getXvalues().get(i),  ((SeriesResultPavo) r).getYvalues().get(i), ((SeriesResultPavo) r).getConfidences().get(i).getIntervalHalfLength()));
			}
			
		}
		
		try {
			   PrintWriter pw = new PrintWriter(csvFile);
				pw.write(csv.toString());
				pw.close();
		} catch (IOException e) {
			e.printStackTrace();
		}	
		
	}

}