/**
 * ==============================================
 *  DQL : Descartes Query Language
 * ==============================================
 *
 * (c) Copyright 2014-2016, by Juergen Walter, Fabian Gorsler, Fabian Brosig and other contributors.
 *
 * Project Info:   http://descartes.tools/dql
 *
 * All rights reserved. This software is made available under the terms of the
 * Eclipse Public License (EPL) v1.0 as published by the Eclipse Foundation
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * This software is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the Eclipse Public License (EPL)
 * for more details.
 *
 * You should have received a copy of the Eclipse Public License (EPL)
 * along with this software; if not visit http://www.eclipse.org or write to
 * Eclipse Foundation, Inc., 308 SW First Avenue, Suite 110, Portland, 97204 USA
 * Email: license (at) eclipse.org
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
 * in the United States and other countries.]
 */
package tools.descartes.pavo.controller;

import java.util.ArrayList;
import java.util.LinkedList;
import java.util.List;

import org.eclipse.emf.common.util.EList;
import tools.descartes.dql.models.mapping.domain.ConfidenceInterval;
import tools.descartes.dql.models.mapping.domain.ContinuousSeriesResult;
import tools.descartes.dql.models.mapping.domain.DecimalResult;
import tools.descartes.dql.models.mapping.domain.DiscreteSeriesResult;
import tools.descartes.dql.models.mapping.domain.OnlineResult;
import tools.descartes.dql.models.mapping.domain.Result;
import tools.descartes.dql.models.mapping.domain.ResultList;
import tools.descartes.dql.models.mapping.domain.SeriesResultElement;
import tools.descartes.dql.models.mapping.domain.StatType;
import tools.descartes.dql.models.mapping.domain.StringResult;
import tools.descartes.pavo.result.AbstractQuantitativeResult;
import tools.descartes.pavo.result.ResultContainerPavo;
import tools.descartes.pavo.result.SeriesResultPavo;
import tools.descartes.pavo.result.StringResultPavo;
import tools.descartes.pavo.result.ValueResultPavo;

/**
 * class to visualize all probes of one resource into one pane. These panes are
 * merged within the graphicsengine
 */
public class TransformEntityMappingToResult {


	public static ResultContainerPavo transformEntityMapping(List<StatType> currentProbes, List<String> resourcesToProbes, String metricName) {
		ResultContainerPavo resultContainer = new ResultContainerPavo();
		
		int j = 0;
		for (StatType currentProbe : currentProbes) {
			
			
				
			if (currentProbe.getResult() instanceof DecimalResult) {

				AbstractQuantitativeResult r = new ValueResultPavo(resourcesToProbes.get(j), metricName, "StatType", "Scale", ((DecimalResult) currentProbe.getResult()).getValue().doubleValue());
				resultContainer.addResult(r);

			} else if (currentProbe.getResult() instanceof StringResult) {

				AbstractQuantitativeResult r = new StringResultPavo(resourcesToProbes.get(j), metricName, "StatType", "Scale", ((StringResult) currentProbe.getResult()).getValue().toString());
				resultContainer.addResult(r);
			}

			else if (currentProbe.getResult() instanceof DiscreteSeriesResult) {
				
				
				EList<SeriesResultElement> list = ((DiscreteSeriesResult) currentProbe.getResult()).getElements();
				List<Double> x = new ArrayList<Double>();
				List<Double> y = new ArrayList<Double>();
				for (SeriesResultElement a : list) {
					x.add(a.getX().doubleValue());
					y.add(a.getY().doubleValue());
				}

				List<ConfidenceInterval> confidences = new ArrayList<ConfidenceInterval>();
				for (SeriesResultElement a : list) {
					confidences.add(a.getConfidenceInterval());
				}

				AbstractQuantitativeResult r = new SeriesResultPavo(resourcesToProbes.get(j), metricName, "StatType", "Scale", x, y, false, "XSCALE", "YSCALE", confidences, currentProbe.getResult());
				resultContainer.addResult(r);
			}

			else if (currentProbe.getResult() instanceof ContinuousSeriesResult) {

				EList<SeriesResultElement> list = ((ContinuousSeriesResult) currentProbe.getResult()).getElements();
				List<Double> x = new ArrayList<Double>();
				List<Double> y = new ArrayList<Double>();
				for (SeriesResultElement a : list) {
					x.add(a.getX().doubleValue());
					y.add(a.getY().doubleValue());
				}

				List<ConfidenceInterval> confidences = new ArrayList<ConfidenceInterval>();
				for (SeriesResultElement a : list) {
					confidences.add(a.getConfidenceInterval());
				}

				
				AbstractQuantitativeResult r = new SeriesResultPavo(resourcesToProbes.get(j), metricName, "StatType", "Scale", x, y, true, "XSCALE", "YSCALE", confidences, currentProbe.getResult());
				resultContainer.addResult(r);
				 
			} else if (currentProbe.getResult() instanceof ResultList<?>) {
				int i = 1;
				for (Result c : ((ResultList<?>) currentProbe.getResult()).getResults()) {
					if(c instanceof DecimalResult)
					{
						System.out.println(c.toString());
						resultContainer.addResult(new ValueResultPavo(resourcesToProbes.get(j)+"_"+i,metricName 
								,"StatType", "Scale", 
								((DecimalResult) c).getValue().doubleValue()));
					}
					else
					{
					
					EList<SeriesResultElement> list = ((ContinuousSeriesResult) c).getElements();
					List<Double> x = new ArrayList<Double>();
					List<Double> y = new ArrayList<Double>();
					List<ConfidenceInterval> confidences = new ArrayList<ConfidenceInterval>();
					for (SeriesResultElement a : list) {
						x.add(a.getX().doubleValue());
						y.add(a.getY().doubleValue());
						confidences.add(a.getConfidenceInterval());
					}
					boolean continous = false;
					if(c instanceof ContinuousSeriesResult)
						continous = true;
System.out.println(resourcesToProbes.get(j)+" Series "+i);
					resultContainer.addResult(new SeriesResultPavo(resourcesToProbes.get(j)+" Series "+i, metricName, "StatType", "Scale", x, y, continous, "XSCALE", "YSCALE", confidences, c));
					i++;
					}
				}

			
						

			} else if (currentProbe.getResult() instanceof OnlineResult) {
				
				AbstractQuantitativeResult r = new SeriesResultPavo(resourcesToProbes.get(j), metricName, "StatType", "Scale", new LinkedList<Double>(), new LinkedList<Double>(), true, "XSCALE", "YSCALE", new LinkedList<ConfidenceInterval>(), ((OnlineResult) currentProbe.getResult()).getResult());
				resultContainer.addResult(r);
				//Plan um alles online zu machen --> jede Series hat noch ein ResultOrt, der der dann geupdated wird, bzw. an den der Adapter dann angelegt wird
				//Bis jetzt hat das nur der complette container --> online ausweitung mit confidence und min max mean und auch switch ermoeglichen 
				
			}
			j++;
		}
		return resultContainer;

	}

	}


//OnlineResultPavo rO = new OnlineResultPavo(resourcesToProbes.get(j), metricName, "StatType", "Scale", new LinkedList<Double>(), new LinkedList<Double>(), true, "X", "Y",  (ContinuousSeriesResult) ((OnlineResult) currentProbe.getResult()).getResult());
//result.setOnlineResult(rO);
//result.addResult(rO);

//currentResult = ((OnlineResult) currentProbe.getResult()).getResult();
//result.setxAxisLabel("x");
//result.setyAxisLabel("y");
//
//result.getSeriesNames().add(resourcesToProbes.get(j));
//result.getxValues().add(new ArrayList<Double>());
//result.getyValues().add(new ArrayList<Double>());
//result.getConfidences().add(new ArrayList<ConfidenceInterval>());
//System.out.println(result.getSeriesNames());
//
//Adapter adapter = new AdapterImpl() {
//	public synchronized void notifyChanged(Notification notification) {
//		
//		
//
////		EList<SeriesResultElement> c = ((ContinuousSeriesResult) currentResult).getElements();
////		SeriesResultElement element = c.get(DotsShown);
////		result.getxValues().get(numberOnlineSeries).add(element.getX().doubleValue());
////		result.getyValues().get(numberOnlineSeries).add(element.getY().doubleValue());
////		result.getConfidences().get(numberOnlineSeries).add(element.getConfidenceInterval());
////		draw();
////		DotsShown++;
//
//	}
//};
//currentResult.eAdapters().add(adapter);