/**
 * ==============================================
 *  DQL : Descartes Query Language
 * ==============================================
 *
 * (c) Copyright 2014-2016, by Juergen Walter, Fabian Gorsler, Fabian Brosig and other contributors.
 *
 * Project Info:   http://descartes.tools/dql
 *
 * All rights reserved. This software is made available under the terms of the
 * Eclipse Public License (EPL) v1.0 as published by the Eclipse Foundation
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * This software is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the Eclipse Public License (EPL)
 * for more details.
 *
 * You should have received a copy of the Eclipse Public License (EPL)
 * along with this software; if not visit http://www.eclipse.org or write to
 * Eclipse Foundation, Inc., 308 SW First Avenue, Suite 110, Portland, 97204 USA
 * Email: license (at) eclipse.org
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
 * in the United States and other countries.]
 */
package tools.descartes.pavo.controller;

import java.awt.Color;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.util.ArrayList;
import java.util.LinkedList;
import java.util.List;
import org.eclipse.emf.common.notify.Adapter;
import org.eclipse.emf.common.notify.Notification;
import org.eclipse.emf.common.notify.impl.AdapterImpl;
import org.eclipse.emf.common.util.EList;
import org.jfree.chart.JFreeChart;
import org.jfree.chart.plot.Marker;
import org.jfree.chart.plot.ValueMarker;
import org.jfree.ui.RectangleAnchor;

import tools.descartes.dql.models.mapping.domain.AbstractSeriesResult;
import tools.descartes.dql.models.mapping.domain.SeriesResultElement;
import tools.descartes.pavo.types.BarChart;
import tools.descartes.pavo.types.BoxPlot;
import tools.descartes.pavo.types.DifferenceChart;
import tools.descartes.pavo.types.HeatMap;
import tools.descartes.pavo.types.IVisualizationType;
import tools.descartes.pavo.types.LineChart;
import tools.descartes.pavo.types.PieChart;
import tools.descartes.pavo.types.ScatterPlot;
import tools.descartes.pavo.view.View;
import tools.descartes.pavo.helper.MathHelper;
import tools.descartes.pavo.result.*;

/**
 * class to visualize all probes of one resource into one pane. These panes are
 * merged within the graphicsengine
 */

public class VisualizationController {

	View view;
	private boolean min = false;
	private boolean max = false;
	private boolean mean = false;
	private List<ValueMarker> minMarkers = new ArrayList<ValueMarker>();
	private List<ValueMarker> maxMarkers = new ArrayList<ValueMarker>();
	private List<ValueMarker> meanMarkers = new ArrayList<ValueMarker>();

	private JFreeChart chart = null;
	
	private ExportController exportController = new ExportController();
	private ResultContainerPavo result = new ResultContainerPavo();

	private List<Class<? extends IVisualizationType>> AllDiagramClasses = new LinkedList<Class<? extends IVisualizationType>>();
	private Class<? extends IVisualizationType> currentShownDiagramClass;

	public VisualizationController(ResultContainerPavo resultContainerN) {

		view = new View();
		this.setActionListener();

		result = resultContainerN;

		for (AbstractQuantitativeResult singleResultSeries : result.getResults()) {
			if (singleResultSeries instanceof StringResultPavo || singleResultSeries instanceof ValueResultPavo) {
			} else {
				Adapter adapter = new AdapterImpl() {
					public synchronized void notifyChanged(Notification notification) {

						EList<SeriesResultElement> c = ((AbstractSeriesResult) singleResultSeries.getResultLocation())
								.getElements();
						SeriesResultElement element = c.get(singleResultSeries.getDotsShown());
						((SeriesResultPavo) singleResultSeries).getXvalues().add(element.getX().doubleValue());
						((SeriesResultPavo) singleResultSeries).getYvalues().add(element.getY().doubleValue());
						((SeriesResultPavo) singleResultSeries).getConfidences().add(element.getConfidenceInterval());
						singleResultSeries.setDotsShown(singleResultSeries.getDotsShown() + 1);
						draw(currentShownDiagramClass);

					}
				};

				singleResultSeries.getResultLocation().eAdapters().add(adapter);
			}

		}
		AllDiagramClasses.add(PieChart.class);
		
		AllDiagramClasses.add(LineChart.class);
		AllDiagramClasses.add(ScatterPlot.class);
		AllDiagramClasses.add(BarChart.class);
		AllDiagramClasses.add(BoxPlot.class);
		AllDiagramClasses.add(DifferenceChart.class);
		AllDiagramClasses.add(HeatMap.class);
		
		
		this.draw(this.selectFirstShownDiagram());
		checkButtons();
		fillComboBoxToDiagram();

	}

	public void addMin() {

		for (AbstractQuantitativeResult r : result.getResults()) {

			double value = MathHelper.getMin(((SeriesResultPavo) r).getyvalues());
			String res = "Minimum of " + r.getQueryableElement();
			boolean found = false;

			for (ValueMarker m : minMarkers) {
				if (m.getValue() == value) {
					m.setLabel(m.getLabel() + " and " + res);
					found = true;
				}
			}

			if (found == false) {
				ValueMarker marker = new ValueMarker(value);
				marker.setPaint(Color.green);
				marker.setLabel(res);
				marker.setLabelAnchor(RectangleAnchor.CENTER);
				chart.getXYPlot().addRangeMarker(marker);
				minMarkers.add(marker);
			}

		}
	}

	public void addMax() {
		for (AbstractQuantitativeResult r : result.getResults()) {

			double value = MathHelper.getMax(((SeriesResultPavo) r).getyvalues());
			String res = "Maximum of " + r.getQueryableElement();
			boolean found = false;

			for (ValueMarker m : maxMarkers) {
				if (m.getValue() == value) {
					m.setLabel(m.getLabel() + " and " + res);
					found = true;
				}
			}

			if (found == false) {
				ValueMarker marker = new ValueMarker(value);
				marker.setPaint(Color.orange);
				marker.setLabel(res);
				marker.setLabelAnchor(RectangleAnchor.CENTER);
				chart.getXYPlot().addRangeMarker(marker);
				maxMarkers.add(marker);
			}

		}

	}

	public void addMean() {
		for (AbstractQuantitativeResult r : result.getResults()) {

			double value = MathHelper.getMean(((SeriesResultPavo) r).getyvalues());
			String res = "Mean of " + r.getQueryableElement();
			boolean found = false;

			for (ValueMarker m : meanMarkers) {
				if (m.getValue() == value) {
					m.setLabel(m.getLabel() + " and " + res);
					found = true;
				}
			}

			if (found == false) {
				ValueMarker marker = new ValueMarker(value);
				marker.setPaint(Color.blue);
				marker.setLabel(res);
				marker.setLabelAnchor(RectangleAnchor.CENTER);
				chart.getXYPlot().addRangeMarker(marker);
				meanMarkers.add(marker);
			}

		}
	}

	public void setActionListener() {

		view.setActionListenerMinRadio(new ActionListener() {

			@Override
			public void actionPerformed(ActionEvent e) {

				if (min) {
					for (Marker m : minMarkers) {
						chart.getXYPlot().removeRangeMarker(m);
					}
					min = false;
				} else {
					addMin();
					min = true;
				}

			}
		});

		view.setActionListenerMaxRadio(new ActionListener() {

			@Override
			public void actionPerformed(ActionEvent e) {

				if (max) {
					for (Marker m : maxMarkers) {
						chart.getXYPlot().removeRangeMarker(m);
					}
					max = false;
				} else {
					addMax();
					max = true;
				}

			}
		});

		view.setActionListenerMeanRadio(new ActionListener() {

			@Override
			public void actionPerformed(ActionEvent e) {

				if (mean) {
					for (Marker m : meanMarkers) {
						chart.getXYPlot().removeRangeMarker(m);
					}
					mean = false;
				} else {
					addMean();
					mean = true;
				}

			}
		});

		view.setActionListenerConfidenceRadio(new ActionListener() {

			@Override
			public void actionPerformed(ActionEvent e) {
				transformDiagram();
			}
		});

		view.setActionListenerChangeButton(new ActionListener() {
			@Override
			public void actionPerformed(ActionEvent e) {
				transformDiagram();

			}
		});

		view.setActionListenerExportButton(new ActionListener() {
			@Override
			public void actionPerformed(ActionEvent e) {
				exportController.exportDiagram(view, chart, result);
			}
		});
	}

	public View getView() {
		return view;
	}

	public void setView(View view) {
		this.view = view;
	}



	public void checkButtons() {
		if(result.getResults().size() == 1 && result.getResults().get(0) instanceof StringResultPavo)
			return;

		Object helpObject = null;
		try {
			helpObject = currentShownDiagramClass.getDeclaredConstructor(ResultContainerPavo.class).newInstance(result);
		} catch (InstantiationException | IllegalAccessException | IllegalArgumentException | InvocationTargetException
				| NoSuchMethodException | SecurityException e) {
			e.printStackTrace();
		}
		Method canConfidenceMethod = null;
		try {
			canConfidenceMethod = currentShownDiagramClass.getMethod("supportsConfidenceInterval");
		} catch (NoSuchMethodException | SecurityException e) {
			e.printStackTrace();
		}
		boolean MethodReturn = false;
		try {
			MethodReturn = (boolean) canConfidenceMethod.invoke(helpObject);
		} catch (IllegalAccessException | IllegalArgumentException | InvocationTargetException e) {
			e.printStackTrace();
		}
		view.getConfidenceRadio().setEnabled(MethodReturn);

		Method canAnalyses = null;
		try {
			canAnalyses = currentShownDiagramClass.getMethod("supportsAnalyses");
		} catch (NoSuchMethodException | SecurityException e) {
			e.printStackTrace();
		}
		try {
			MethodReturn = (boolean) canAnalyses.invoke(helpObject);
		} catch (IllegalAccessException | IllegalArgumentException | InvocationTargetException e) {
			e.printStackTrace();
		}

		view.getMaxRadio().setEnabled(MethodReturn);
		view.getMinRadio().setEnabled(MethodReturn);
		view.getMeanRadio().setEnabled(MethodReturn);

		Method heatControls = null;
		try {
			heatControls = currentShownDiagramClass.getMethod("normalOrHeatMapControls");
		} catch (NoSuchMethodException | SecurityException e) {
			e.printStackTrace();
		}
		try {
			MethodReturn = (boolean) heatControls.invoke(helpObject);
		} catch (IllegalAccessException | IllegalArgumentException | InvocationTargetException e) {
			e.printStackTrace();
		}

		if (MethodReturn) {
			view.switchToNormal();
		} else {
			view.switchToHeat();
			//Hier noch die jeweiligen benennungen der Series in die ComboBoxen und dannach noch einmal das update im view für die combos und deren werte
			String[] names = {result.getResults().get(0).getQueryableElement(), result.getResults().get(1).getQueryableElement(), result.getResults().get(2).getQueryableElement()};
			view.fillHeatCombos(names);
			view.updateCurrentXYZ();
		}

		boolean noseries = true;
		for (AbstractQuantitativeResult r : result.getResults()) {
			if (r instanceof SeriesResultPavo) {
				noseries = false;
			}
		}
		if (noseries || view.getConfidenceRadio().isSelected()) {
			view.getMaxRadio().setEnabled(false);
			view.getMinRadio().setEnabled(false);
			view.getMeanRadio().setEnabled(false);
		}
	}

	public Class<? extends IVisualizationType> selectFirstShownDiagram() {
		if(result.getResults().size() == 1 && result.getResults().get(0) instanceof StringResultPavo)
		{
			return null;
		}
		
		for (Class<? extends IVisualizationType> c : AllDiagramClasses) {
			Object helpObject = null;
			try {
				helpObject = c.getDeclaredConstructor(ResultContainerPavo.class).newInstance(result);

			} catch (InstantiationException | IllegalAccessException | IllegalArgumentException
					| InvocationTargetException | NoSuchMethodException | SecurityException e) {
				e.printStackTrace();
			}

			Method canVisualizeMethod = null;
			try {
				canVisualizeMethod = c.getMethod("canVisualize");
			} catch (NoSuchMethodException | SecurityException e) {
				e.printStackTrace();
			}
			boolean MethodReturn = false;
			try {
				MethodReturn = (boolean) canVisualizeMethod.invoke(helpObject, new Object[] {});
			} catch (IllegalAccessException | IllegalArgumentException | InvocationTargetException e) {
				e.printStackTrace();
			}
			if (MethodReturn)
				return c;
		}
		view.setError();
		return null;

	}

	public void draw(Class<? extends IVisualizationType> c) {
		
		if(result.getResults().size() == 1 && result.getResults().get(0) instanceof StringResultPavo)
		{
			view.setStringResult(((StringResultPavo) result.getResults().get(0)).getValue());
			return;
		}
		
		Object helpObject = null;
		try {
			helpObject = c.getDeclaredConstructor(ResultContainerPavo.class).newInstance(result);

		} catch (InstantiationException | IllegalAccessException | IllegalArgumentException | InvocationTargetException
				| NoSuchMethodException | SecurityException e) {
			e.printStackTrace();
		}
		Method visualizeMethod = null;
		if (view.getConfidenceRadio().isSelected()) {
			try {
				visualizeMethod = c.getMethod("visualizeConfidence");
				clearMarkerForTransform();
				chart = (JFreeChart) visualizeMethod.invoke(helpObject);
				currentShownDiagramClass = c;
				view.updateChart(chart);
				return;

			} catch (NoSuchMethodException | SecurityException | IllegalAccessException | IllegalArgumentException
					| InvocationTargetException e) {
				e.printStackTrace();
			}
		} else {
			try {
				visualizeMethod = c.getMethod("visualize");
			} catch (NoSuchMethodException | SecurityException e) {
				e.printStackTrace();
			}
			try {
				chart = (JFreeChart) visualizeMethod.invoke(helpObject);
				currentShownDiagramClass = c;
				view.updateChart(chart);
				if (min)
					this.addMin();
				if (max)
					this.addMax();
				if (mean)
					this.addMean();
				return;
			} catch (IllegalAccessException | IllegalArgumentException | InvocationTargetException e) {
				e.printStackTrace();
			}
		}

		try {
			chart = (JFreeChart) visualizeMethod.invoke(helpObject);
			currentShownDiagramClass = c;
			view.updateChart(chart);
			if (min)
				this.addMin();
			if (max)
				this.addMax();
			if (mean)
				this.addMean();
			return;
		} catch (IllegalAccessException | IllegalArgumentException | InvocationTargetException e) {
			e.printStackTrace();
		}
	}

	public void fillComboBoxToDiagram() {

		view.getDiagramSwitchTypes().removeAllItems();
		if(result.getResults().size() == 1 && result.getResults().get(0) instanceof StringResultPavo)
		{
			view.addItemToCombo("StringResult");
			return;
		}
		view.addItemToCombo(currentShownDiagramClass.getName().substring(
				currentShownDiagramClass.getName().lastIndexOf('.') + 1, currentShownDiagramClass.getName().length()));

		for (Class<? extends IVisualizationType> c : AllDiagramClasses) {
			Object helpObject = null;
			try {
				helpObject = c.getDeclaredConstructor(ResultContainerPavo.class).newInstance(result);

			} catch (InstantiationException | IllegalAccessException | IllegalArgumentException
					| InvocationTargetException | NoSuchMethodException | SecurityException e) {
				e.printStackTrace();
			}

			Method canVisualizeMethod = null;
			try {
				canVisualizeMethod = c.getMethod("canVisualize");
			} catch (NoSuchMethodException | SecurityException e) {
				e.printStackTrace();
			}
			boolean MethodReturn = false;
			try {
				MethodReturn = (boolean) canVisualizeMethod.invoke(helpObject, new Object[] {});
			} catch (IllegalAccessException | IllegalArgumentException | InvocationTargetException e) {
				e.printStackTrace();
			}

			if (MethodReturn && !currentShownDiagramClass.equals(c)) {
				view.addItemToCombo(c.getName().substring(c.getName().lastIndexOf('.') + 1, c.getName().length()));
			}

		}
	}

	public void clearMarkerForTransform() {
		view.resetAnalysesRadios();
		min = false;
		max = false;
		mean = false;
		minMarkers.clear();
		maxMarkers.clear();
		meanMarkers.clear();
	}

	public void transformDiagram() {
		String switchType = view.getDiagramSwitchTypes().getSelectedItem().toString();
		clearMarkerForTransform();

		for (Class<? extends IVisualizationType> c : AllDiagramClasses) {
			if (c.getName().substring(c.getName().lastIndexOf('.') + 1, c.getName().length()).equals(switchType)) {
				Object helpObject = null;
				try {
					helpObject = c.getDeclaredConstructor(ResultContainerPavo.class).newInstance(result);

				} catch (InstantiationException | IllegalAccessException | IllegalArgumentException
						| InvocationTargetException | NoSuchMethodException | SecurityException e) {
					e.printStackTrace();
				}

				Method visualizeMethod = null;
				if (view.getConfidenceRadio().isSelected()) {
					try {
						visualizeMethod = c.getMethod("visualizeConfidence");

					} catch (NoSuchMethodException | SecurityException e) {
						e.printStackTrace();
					}
					try {
						chart = (JFreeChart) visualizeMethod.invoke(helpObject, new Object[] {});
						currentShownDiagramClass = c;
						view.updateChart(chart);
						fillComboBoxToDiagram();
						checkButtons();
					} catch (IllegalAccessException | IllegalArgumentException | InvocationTargetException e) {
						e.printStackTrace();
					}
				} else {
					try {
						visualizeMethod = c.getMethod("visualize");
					} catch (NoSuchMethodException | SecurityException e) {
						e.printStackTrace();
					}
					try {
						chart = (JFreeChart) visualizeMethod.invoke(helpObject, new Object[] {});
						currentShownDiagramClass = c;
						view.updateChart(chart);
						fillComboBoxToDiagram();
						checkButtons();
					} catch (IllegalAccessException | IllegalArgumentException | InvocationTargetException e) {
						e.printStackTrace();
					}
				}
			}
		}
	}

}