/**
 * ==============================================
 *  DQL : Descartes Query Language
 * ==============================================
 *
 * (c) Copyright 2014-2016, by Juergen Walter, Fabian Gorsler, Fabian Brosig and other contributors.
 *
 * Project Info:   http://descartes.tools/dql
 *
 * All rights reserved. This software is made available under the terms of the
 * Eclipse Public License (EPL) v1.0 as published by the Eclipse Foundation
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * This software is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the Eclipse Public License (EPL)
 * for more details.
 *
 * You should have received a copy of the Eclipse Public License (EPL)
 * along with this software; if not visit http://www.eclipse.org or write to
 * Eclipse Foundation, Inc., 308 SW First Avenue, Suite 110, Portland, 97204 USA
 * Email: license (at) eclipse.org
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
 * in the United States and other countries.]
 */
package tools.descartes.pavo.types;

import java.awt.Color;

import org.jfree.chart.JFreeChart;
import org.jfree.chart.axis.CategoryAxis;
import org.jfree.chart.axis.NumberAxis;
import org.jfree.chart.axis.ValueAxis;
import org.jfree.chart.plot.CategoryPlot;
import org.jfree.chart.plot.Marker;
import org.jfree.chart.plot.ValueMarker;
import org.jfree.chart.plot.XYPlot;
import org.jfree.chart.renderer.category.CategoryItemRenderer;
import org.jfree.chart.renderer.category.StatisticalBarRenderer;
import org.jfree.chart.renderer.xy.ClusteredXYBarRenderer;
import org.jfree.chart.renderer.xy.XYBarRenderer;
import org.jfree.data.statistics.DefaultStatisticalCategoryDataset;
import org.jfree.data.xy.XYSeries;
import org.jfree.data.xy.XYSeriesCollection;
import org.jfree.ui.RectangleAnchor;
import org.jfree.ui.TextAnchor;

import tools.descartes.pavo.result.AbstractQuantitativeResult;
import tools.descartes.pavo.result.ResultContainerPavo;
import tools.descartes.pavo.result.SeriesResultPavo;
import tools.descartes.pavo.result.ValueResultPavo;


public class BarChart extends AbstractVisualizationType implements IVisualizationType{
	
public BarChart()
{
	
}
	
	public BarChart(ResultContainerPavo resultN) {
		super(resultN);
	}


	public JFreeChart visualizeConfidence()
	{
		final DefaultStatisticalCategoryDataset dataset = new DefaultStatisticalCategoryDataset();
		
			CategoryAxis xAxis = new CategoryAxis("X");
	        final ValueAxis yAxis = new NumberAxis("Y");
	        final CategoryItemRenderer renderer = new StatisticalBarRenderer();
	        final CategoryPlot plot = new CategoryPlot(dataset, xAxis, yAxis, renderer);
	        JFreeChart chart =  new JFreeChart("", JFreeChart.DEFAULT_TITLE_FONT, plot, true);
	        
	        for(AbstractQuantitativeResult r : this.getResult().getResults())
			{
				if(r instanceof SeriesResultPavo)
				{
					for(int i = 0; i < ((SeriesResultPavo) r).getXvalues().size(); i++)
					{
						dataset.add(((SeriesResultPavo) r).getYvalues().get(i), ((SeriesResultPavo) r).getConfidences().get(i).getIntervalHalfLength() ,r.getQueryableElement() , ((SeriesResultPavo) r).getXvalues().get(i));
					}
					
				}
			}
	        chart.setBackgroundPaint(Color.WHITE);
	        chart.setBorderPaint(Color.WHITE);
	        return chart;
	}
	

	@Override
	public JFreeChart visualize() {
		XYSeriesCollection dataset = new XYSeriesCollection();
		XYBarRenderer renderer = new ClusteredXYBarRenderer(0.2, false);
		NumberAxis domainAxis = new NumberAxis("X");
		domainAxis.setAutoRangeIncludesZero(false);
		NumberAxis valueAxis = new NumberAxis("Y");
		XYPlot plot = new XYPlot(dataset, domainAxis, valueAxis, renderer);
		JFreeChart chart = new JFreeChart("", JFreeChart.DEFAULT_TITLE_FONT, plot, true);
		int i = 0;
		for(AbstractQuantitativeResult r : this.getResult().getResults())
		{
			if(r instanceof ValueResultPavo)
			{
				ValueMarker marker = new ValueMarker(((ValueResultPavo) r).getValue()); 
				marker.setPaint(Color.green);
				marker.setLabel(r.getMetric()+" "+i);
				i++;
				marker.setLabelAnchor(RectangleAnchor.BOTTOM_RIGHT);
				marker.setLabelTextAnchor(TextAnchor.TOP_RIGHT);
				((XYPlot) chart.getPlot()).addRangeMarker(marker);
				ValueAxis yAxis = plot.getRangeAxis();
				if(marker.getValue() > yAxis.getUpperBound())
					yAxis.setRange(yAxis.getLowerBound(), marker.getValue()+1);
			}
			else if(r instanceof SeriesResultPavo)
			{
				XYSeries series1 = new XYSeries(r.getQueryableElement());
				for(int j = 0; j < ((SeriesResultPavo) r).getXvalues().size(); j++)
				{
					series1.add(((SeriesResultPavo) r).getXvalues().get(j), ((SeriesResultPavo) r).getYvalues().get(j));
				}
				dataset.addSeries(series1);
			}
		}
		chart.setBackgroundPaint(Color.WHITE);
		chart.setBorderPaint(Color.WHITE);
		return chart;
	}


	@Override
	public boolean canVisualize() {
		for (AbstractQuantitativeResult r : this.getResult().getResults()) {
			if(!(r instanceof ValueResultPavo) && !(r instanceof SeriesResultPavo))
			{
				return false;
			}
		}
		return true;
	}
	
	public boolean supportsConfidenceInterval()
	{
		return true;
	}


}