/**
 * ==============================================
 *  DQL : Descartes Query Language
 * ==============================================
 *
 * (c) Copyright 2014-2016, by Juergen Walter, Fabian Gorsler, Fabian Brosig and other contributors.
 *
 * Project Info:   http://descartes.tools/dql
 *
 * All rights reserved. This software is made available under the terms of the
 * Eclipse Public License (EPL) v1.0 as published by the Eclipse Foundation
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * This software is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the Eclipse Public License (EPL)
 * for more details.
 *
 * You should have received a copy of the Eclipse Public License (EPL)
 * along with this software; if not visit http://www.eclipse.org or write to
 * Eclipse Foundation, Inc., 308 SW First Avenue, Suite 110, Portland, 97204 USA
 * Email: license (at) eclipse.org
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
 * in the United States and other countries.]
 */
package tools.descartes.pavo.types;

import java.awt.Color;

import org.jfree.chart.JFreeChart;
import org.jfree.chart.axis.CategoryAxis;
import org.jfree.chart.axis.NumberAxis;
import org.jfree.chart.plot.CategoryPlot;
import org.jfree.chart.renderer.category.BoxAndWhiskerRenderer;
import org.jfree.data.statistics.DefaultBoxAndWhiskerCategoryDataset;

import tools.descartes.pavo.result.AbstractQuantitativeResult;
import tools.descartes.pavo.result.ResultContainerPavo;
import tools.descartes.pavo.result.SeriesResultPavo;
import tools.descartes.pavo.result.ValueResultPavo;


public class BoxPlot  extends AbstractVisualizationType implements IVisualizationType{
	
	public BoxPlot()
	{
		
	}

		
	public BoxPlot(ResultContainerPavo resultN) {
		super(resultN);
	}


		@Override
		public JFreeChart visualize() {
			DefaultBoxAndWhiskerCategoryDataset dataset = new DefaultBoxAndWhiskerCategoryDataset();
			final CategoryAxis xAxis = new CategoryAxis("X");
			final NumberAxis yAxis = new NumberAxis("Y");
			BoxAndWhiskerRenderer renderer = new BoxAndWhiskerRenderer();
			renderer.setMeanVisible(false);
			CategoryPlot plot = new CategoryPlot(dataset, xAxis, yAxis, renderer);
			JFreeChart chart = new JFreeChart(plot);
			
			for(AbstractQuantitativeResult r: result.getResults())
			{
				if(r instanceof SeriesResultPavo)
				{
					dataset.add(((SeriesResultPavo) r).getXvalues(), r.getQueryableElement(), "");
				}
			}
			
			chart.setBackgroundPaint(Color.WHITE);
			chart.setBorderPaint(Color.WHITE);
			return chart;
		}

		@Override
		public boolean canVisualize() {
			for (AbstractQuantitativeResult r : this.getResult().getResults()) {
				if(!(r instanceof ValueResultPavo) && !(r instanceof SeriesResultPavo))
				{
					return false;
				}
			}
			return true;
		}
		
		@Override
		public boolean supportsAnalyses()
		{
			return false;
		}

}