/**
 * ==============================================
 *  DQL : Descartes Query Language
 * ==============================================
 *
 * (c) Copyright 2014-2016, by Juergen Walter, Fabian Gorsler, Fabian Brosig and other contributors.
 *
 * Project Info:   http://descartes.tools/dql
 *
 * All rights reserved. This software is made available under the terms of the
 * Eclipse Public License (EPL) v1.0 as published by the Eclipse Foundation
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * This software is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the Eclipse Public License (EPL)
 * for more details.
 *
 * You should have received a copy of the Eclipse Public License (EPL)
 * along with this software; if not visit http://www.eclipse.org or write to
 * Eclipse Foundation, Inc., 308 SW First Avenue, Suite 110, Portland, 97204 USA
 * Email: license (at) eclipse.org
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
 * in the United States and other countries.]
 */
package tools.descartes.pavo.types;




import java.awt.BasicStroke;
import java.awt.Color;
import java.awt.Font;

import org.jfree.chart.ChartFactory;
import org.jfree.chart.JFreeChart;
import org.jfree.chart.axis.NumberAxis;
import org.jfree.chart.axis.ValueAxis;
import org.jfree.chart.plot.IntervalMarker;
import org.jfree.chart.plot.Marker;
import org.jfree.chart.plot.PlotOrientation;
import org.jfree.chart.plot.ValueMarker;
import org.jfree.chart.plot.XYPlot;
import org.jfree.chart.renderer.xy.XYDifferenceRenderer;
import org.jfree.chart.renderer.xy.XYLineAndShapeRenderer;
import org.jfree.data.time.Day;
import org.jfree.data.xy.XYSeries;
import org.jfree.data.xy.XYSeriesCollection;
import org.jfree.ui.Layer;
import org.jfree.ui.RectangleAnchor;
import org.jfree.ui.TextAnchor;

import tools.descartes.pavo.result.AbstractQuantitativeResult;
import tools.descartes.pavo.result.ResultContainerPavo;
import tools.descartes.pavo.result.SeriesResultPavo;
import tools.descartes.pavo.result.ValueResultPavo;

public class DifferenceChart extends AbstractVisualizationType implements IVisualizationType{


	public DifferenceChart(ResultContainerPavo result)
	{
		this.setResult(result);
	}
	

    
	@Override
	public boolean canVisualize() {
		
		int counterSeries=0;
		for (AbstractQuantitativeResult result : this.getResult().getResults()) {
			if(result instanceof SeriesResultPavo)
				counterSeries++;
			if(!(result instanceof ValueResultPavo) && !(result instanceof SeriesResultPavo && ((SeriesResultPavo) result).getIsContinous()))
			{
				return false;
			}
		}
		if(counterSeries!=2)
			return false;
		return true;
	}
    

	@Override
	public JFreeChart visualize() {

		XYSeriesCollection dataset = new XYSeriesCollection();
		NumberAxis domainAxis = new NumberAxis("X");
		domainAxis.setAutoRangeIncludesZero(false);
		NumberAxis valueAxis = new NumberAxis("Y");
		 final XYDifferenceRenderer renderer = new XYDifferenceRenderer(
		           new Color(193, 204, 204, 80), new Color(193, 204, 204, 80), false
		        );
		        renderer.setStroke(new BasicStroke(2.0f));
		        renderer.setSeriesPaint(0, Color.yellow);
		        renderer.setSeriesPaint(1, Color.red);
		XYPlot plot = new XYPlot(dataset, domainAxis, valueAxis, renderer);
		JFreeChart chart = new JFreeChart("", JFreeChart.DEFAULT_TITLE_FONT, plot, true);
		int i = 0;
		for(AbstractQuantitativeResult r : this.getResult().getResults())
		{
			if(r instanceof ValueResultPavo)
			{
				ValueMarker marker = new ValueMarker(((ValueResultPavo) r).getValue()); 
				marker.setPaint(Color.green);
				marker.setLabel(r.getMetric()+" "+i);
				i++;
				marker.setLabelAnchor(RectangleAnchor.BOTTOM_RIGHT);
				marker.setLabelTextAnchor(TextAnchor.TOP_RIGHT);
				((XYPlot) chart.getPlot()).addRangeMarker(marker);
				ValueAxis yAxis = plot.getRangeAxis();
				if(marker.getValue() > yAxis.getUpperBound())
					yAxis.setRange(yAxis.getLowerBound(), marker.getValue()+1);
			}
			else
			{
				XYSeries series1 = new XYSeries(r.getQueryableElement());
				for(int j = 0; j < ((SeriesResultPavo) r).getXvalues().size(); j++)
				{
					series1.add(((SeriesResultPavo) r).getXvalues().get(j), ((SeriesResultPavo) r).getyvalues().get(j));
				}
				dataset.addSeries(series1);
			}
			
		}
		
		 
		        

		        final Color c = new Color(92, 109, 127);
		        final Marker bst = new IntervalMarker(
		            new Day(28, 3, 2004).getFirstMillisecond(), new Day(30, 10, 2004).getFirstMillisecond(),
		            c, new BasicStroke(2.0f), null, null, 1.0f
		        );
		        bst.setLabel("British Summer Time");
		        bst.setLabelAnchor(RectangleAnchor.BOTTOM_RIGHT);
		        bst.setLabelFont(new Font("SansSerif", Font.ITALIC + Font.BOLD, 10));
		        bst.setLabelTextAnchor(TextAnchor.BASELINE_RIGHT);
		        plot.addDomainMarker(bst, Layer.BACKGROUND);

		        chart.setBackgroundPaint(Color.WHITE);
		        chart.setBorderPaint(Color.WHITE);
	        return chart;      
	}

    

    
}
