package tools.descartes.pavo.types;
/**
 * ==============================================
 *  DQL : Descartes Query Language
 * ==============================================
 *
 * (c) Copyright 2014-2016, by Juergen Walter, Fabian Gorsler, Fabian Brosig and other contributors.
 *
 * Project Info:   http://descartes.tools/dql
 *
 * All rights reserved. This software is made available under the terms of the
 * Eclipse Public License (EPL) v1.0 as published by the Eclipse Foundation
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * This software is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the Eclipse Public License (EPL)
 * for more details.
 *
 * You should have received a copy of the Eclipse Public License (EPL)
 * along with this software; if not visit http://www.eclipse.org or write to
 * Eclipse Foundation, Inc., 308 SW First Avenue, Suite 110, Portland, 97204 USA
 * Email: license (at) eclipse.org
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
 * in the United States and other countries.]
 */



import java.awt.Color;
import java.awt.Paint;
import java.util.List;

import javax.swing.JPanel; 

import org.jfree.chart.ChartPanel; 
import org.jfree.chart.JFreeChart; 
import org.jfree.chart.axis.NumberAxis; 
import org.jfree.chart.plot.XYPlot;
import org.jfree.chart.renderer.GrayPaintScale;
import org.jfree.chart.renderer.LookupPaintScale;
import org.jfree.chart.renderer.PaintScale;
import org.jfree.chart.renderer.xy.XYBlockRenderer;
import org.jfree.data.DomainOrder; 
import org.jfree.data.general.DatasetChangeListener; 
import org.jfree.data.general.DatasetGroup;
import org.jfree.data.xy.DefaultXYDataset;
import org.jfree.data.xy.XYDataset;
import org.jfree.data.xy.XYZDataset; 
import org.jfree.ui.ApplicationFrame;

import tools.descartes.pavo.result.ResultContainerPavo;
import tools.descartes.pavo.result.SeriesResultPavo;
public class HeatMap extends AbstractVisualizationType implements IVisualizationType { 


     private List<Double> seriesX;
     private  List<Double> seriesY;
     private  List<Double> seriesZ;
    
    public HeatMap(ResultContainerPavo resultN) {
		super(resultN);
	}
    
    
    public void setXYZSeries(SeriesResultPavo x, SeriesResultPavo y, SeriesResultPavo z)
    {
    	
    }


	@Override
	public JFreeChart visualize() {
		NumberAxis xAxis = new NumberAxis("X"); 
        xAxis.setStandardTickUnits(NumberAxis.createIntegerTickUnits()); 
        xAxis.setLowerMargin(0.0); 
        xAxis.setUpperMargin(0.0); 
        NumberAxis yAxis = new NumberAxis("Y"); 
        yAxis.setStandardTickUnits(NumberAxis.createIntegerTickUnits()); 
        yAxis.setLowerMargin(0.0); 
        yAxis.setUpperMargin(0.0); 
        XYBlockRenderer renderer = new XYBlockRenderer(); 
        PaintScale scale =  new GrayPaintScale(-2.0, 1.0);
        renderer.setPaintScale(scale); 
        
        
        XYDataset dataset =new XYZDataset() { 
            public int getSeriesCount() { 
                return 1; 
            } 
            public int getItemCount(int series) { 
                return 10000; 
            } 
            public Number getX(int series, int item) { 
                return new Double(getXValue(series, item)); 
            } 
            public double getXValue(int series, int item) { 
                return item / 100 - 50; 
            } 
            public Number getY(int series, int item) { 
                return new Double(getYValue(series, item)); 
            } 
            public double getYValue(int series, int item) { 
                return item - (item / 100) * 100 - 50; 
            } 
            public Number getZ(int series, int item) { 
                return new Double(getZValue(series, item)); 
            } 
            public double getZValue(int series, int item) { 
                result.getResults().get(series);
            	double x = getXValue(series, item); 
                double y = getYValue(series, item); 
                return Math.sin(Math.sqrt(x * x + y * y) / 5.0); 
            } 
            public void addChangeListener(DatasetChangeListener listener) { 
                // ignore - this dataset never changes 
            } 
            public void removeChangeListener(DatasetChangeListener listener) { 
                // ignore 
            } 
            public DatasetGroup getGroup() { 
                return null; 
            } 
            public void setGroup(DatasetGroup group) { 
                // ignore 
            } 
            public Comparable getSeriesKey(int series) { 
                return "Test Series"; 
            } 
            public int indexOf(Comparable seriesKey) { 
                return 0; 
            } 
            public DomainOrder getDomainOrder() { 
                return DomainOrder.ASCENDING; 
            }         
        }; 
        XYPlot plot = new XYPlot(dataset, xAxis, yAxis, renderer); 
        plot.setBackgroundPaint(Color.lightGray); 
        plot.setDomainGridlinesVisible(false); 
        plot.setRangeGridlinePaint(Color.white); 
        JFreeChart chart = new JFreeChart("", plot); 
        chart.setBackgroundPaint(Color.white); 
        return chart; 
	}


	@Override
	public boolean canVisualize() {
		if(this.getResult().getResults().size() == 3)
			return true;
		return false;
	}
	
	@Override
	public boolean supportsAnalyses()
	{
		return false;
	}
	
	public boolean normalOrHeatMapControls()
	{
		return false;
	}
	


}