/**
 * ==============================================
 *  DQL : Descartes Query Language
 * ==============================================
 *
 * (c) Copyright 2014-2016, by Juergen Walter, Fabian Gorsler, Fabian Brosig and other contributors.
 *
 * Project Info:   http://descartes.tools/dql
 *
 * All rights reserved. This software is made available under the terms of the
 * Eclipse Public License (EPL) v1.0 as published by the Eclipse Foundation
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * This software is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the Eclipse Public License (EPL)
 * for more details.
 *
 * You should have received a copy of the Eclipse Public License (EPL)
 * along with this software; if not visit http://www.eclipse.org or write to
 * Eclipse Foundation, Inc., 308 SW First Avenue, Suite 110, Portland, 97204 USA
 * Email: license (at) eclipse.org
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
 * in the United States and other countries.]
 */
package tools.descartes.pavo.types;

import java.lang.reflect.InvocationTargetException;

import org.jfree.chart.JFreeChart;

import tools.descartes.pavo.result.ResultContainerPavo;

public interface IVisualizationType {
	
	static IVisualizationType getInstance(ResultContainerPavo result) {
		Object initargs = result;
		IVisualizationType abc;
		try {
			abc = (IVisualizationType) (new Object().getClass().getConstructor(null).newInstance(initargs));
			return abc;
		} catch (InstantiationException e) {
			e.printStackTrace();
		} catch (IllegalAccessException e) {
			e.printStackTrace();
		} catch (IllegalArgumentException e) {
			e.printStackTrace();
		} catch (InvocationTargetException e) {
			e.printStackTrace();
		} catch (NoSuchMethodException e) {
			e.printStackTrace();
		} catch (SecurityException e) {
			e.printStackTrace();
		}
		return null;
	}

	JFreeChart visualize(); 
	
	default JFreeChart visualizeConfidence()
	{
		return visualize();
	}
	
	boolean canVisualize();
	
	
	default boolean supportsAnalyses()
	{
		return true;
	}
	

	default boolean supportsConfidenceInterval() {
		return false;
	}
	
	//Return true if normal Controls false for HeatMapControls
	default boolean normalOrHeatMapControls()
	{
		return true;
	}


}