/**
 * ==============================================
 *  DQL : Descartes Query Language
 * ==============================================
 *
 * (c) Copyright 2014-2016, by Juergen Walter, Fabian Gorsler, Fabian Brosig and other contributors.
 *
 * Project Info:   http://descartes.tools/dql
 *
 * All rights reserved. This software is made available under the terms of the
 * Eclipse Public License (EPL) v1.0 as published by the Eclipse Foundation
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * This software is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the Eclipse Public License (EPL)
 * for more details.
 *
 * You should have received a copy of the Eclipse Public License (EPL)
 * along with this software; if not visit http://www.eclipse.org or write to
 * Eclipse Foundation, Inc., 308 SW First Avenue, Suite 110, Portland, 97204 USA
 * Email: license (at) eclipse.org
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
 * in the United States and other countries.]
 */
package tools.descartes.pavo.types;


import java.awt.Color;

import org.jfree.chart.ChartFactory;
import org.jfree.chart.JFreeChart;
import org.jfree.chart.axis.NumberAxis;
import org.jfree.chart.axis.ValueAxis;
import org.jfree.chart.plot.Marker;
import org.jfree.chart.plot.PlotOrientation;
import org.jfree.chart.plot.ValueMarker;
import org.jfree.chart.plot.XYPlot;
import org.jfree.chart.renderer.xy.ClusteredXYBarRenderer;
import org.jfree.chart.renderer.xy.XYBarRenderer;
import org.jfree.chart.renderer.xy.XYErrorRenderer;
import org.jfree.chart.renderer.xy.XYLine3DRenderer;
import org.jfree.chart.renderer.xy.XYLineAndShapeRenderer;
import org.jfree.data.xy.XYSeries;
import org.jfree.data.xy.XYSeriesCollection;
import org.jfree.data.xy.YIntervalSeries;
import org.jfree.data.xy.YIntervalSeriesCollection;
import org.jfree.ui.RectangleAnchor;
import org.jfree.ui.TextAnchor;

import tools.descartes.dql.models.mapping.domain.ConfidenceInterval;
import tools.descartes.pavo.result.AbstractQuantitativeResult;
import tools.descartes.pavo.result.ResultContainerPavo;
import tools.descartes.pavo.result.SeriesResultPavo;
import tools.descartes.pavo.result.ValueResultPavo;

public class LineChart  extends AbstractVisualizationType implements IVisualizationType{
	
	public LineChart()
	{
		
	}
 
	public LineChart(ResultContainerPavo resultN) {
		super(resultN);
	}

	
	public boolean supportsConfidenceInterval()
	{
		return true;
	}
	


	@Override
	public JFreeChart visualize() {
		
		
		XYSeriesCollection dataset = new XYSeriesCollection();
		XYLineAndShapeRenderer renderer = new XYLineAndShapeRenderer();
		NumberAxis domainAxis = new NumberAxis("X");
		domainAxis.setAutoRangeIncludesZero(false);
		NumberAxis valueAxis = new NumberAxis("Y");
		XYPlot plot = new XYPlot(dataset, domainAxis, valueAxis, renderer);
		JFreeChart chart = new JFreeChart("", JFreeChart.DEFAULT_TITLE_FONT, plot, true);
		int i = 0;
		for(AbstractQuantitativeResult r : this.getResult().getResults())
		{
			if(r instanceof ValueResultPavo)
			{
				ValueMarker marker = new ValueMarker(((ValueResultPavo) r).getValue()); 
				marker.setPaint(Color.green);
				marker.setLabel(r.getMetric()+" "+i);
				i++;
				marker.setLabelAnchor(RectangleAnchor.BOTTOM_RIGHT);
				marker.setLabelTextAnchor(TextAnchor.TOP_RIGHT);
				((XYPlot) chart.getPlot()).addRangeMarker(marker);
				ValueAxis yAxis = plot.getRangeAxis();
				if(marker.getValue() > yAxis.getUpperBound())
					yAxis.setRange(yAxis.getLowerBound(), marker.getValue()+1);
			}
			else
			{
				XYSeries series1 = new XYSeries(r.getQueryableElement());
				for(int j = 0; j < ((SeriesResultPavo) r).getXvalues().size(); j++)
				{
					series1.add(((SeriesResultPavo) r).getXvalues().get(j), ((SeriesResultPavo) r).getyvalues().get(j));
				}
				dataset.addSeries(series1);
			}
			
		}
		chart.getPlot().setBackgroundPaint(Color.WHITE);
		chart.getPlot().setOutlineVisible(true);
		return chart;
	}


	@Override
	public boolean canVisualize() {
		for (AbstractQuantitativeResult result : this.getResult().getResults()) {
			if(!(result instanceof ValueResultPavo) && !(result instanceof SeriesResultPavo && ((SeriesResultPavo) result).getIsContinous()))
			{
				return false;
			}
		}
		return true;
	}


	
	public JFreeChart visualizeConfidence()
	{
		YIntervalSeriesCollection dataset = new YIntervalSeriesCollection();
		 NumberAxis xAxis = new NumberAxis("X");
	      NumberAxis yAxis = new NumberAxis("Y");
	      XYErrorRenderer renderer = new XYErrorRenderer();
	      renderer.setBaseLinesVisible(true);
	      renderer.setBaseShapesVisible(false);
	      XYPlot plot = new XYPlot(dataset, xAxis, yAxis, renderer);
	      JFreeChart chart = new JFreeChart("", plot);
		int i = 0;
		for(AbstractQuantitativeResult r : this.getResult().getResults())
		{
			if(r instanceof ValueResultPavo)
			{
				ValueMarker marker = new ValueMarker(((ValueResultPavo) r).getValue()); 
				marker.setPaint(Color.green);
				marker.setLabel(r.getMetric()+" "+i);
				i++;
				marker.setLabelAnchor(RectangleAnchor.BOTTOM_RIGHT);
				marker.setLabelTextAnchor(TextAnchor.TOP_RIGHT);
				((XYPlot) chart.getPlot()).addRangeMarker(marker);
				if(marker.getValue() > yAxis.getUpperBound())
					yAxis.setRange(yAxis.getLowerBound(), marker.getValue()+1);
			}
			else
			{
				YIntervalSeries s1 = new YIntervalSeries(r.getQueryableElement());
				for(int j = 0; j < ((SeriesResultPavo) r).getXvalues().size(); j++)
				{
					 ConfidenceInterval c =  ((SeriesResultPavo) r).getConfidences().get(j);
		    		 Double x = ((SeriesResultPavo) r).getXvalues().get(j);
		    		 Double y = ((SeriesResultPavo) r).getyvalues().get(j);
		    		 s1.add(x, y, y-c.getIntervalHalfLength().doubleValue(), y+c.getIntervalHalfLength().doubleValue());
				}
				dataset.addSeries(s1);
			}
			
		}
		chart.setBackgroundPaint(Color.WHITE);
		chart.setBorderPaint(Color.WHITE);
      return  chart;
	}
	
	
}