/**
 * ==============================================
 *  DQL : Descartes Query Language
 * ==============================================
 *
 * (c) Copyright 2014-2016, by Juergen Walter, Fabian Gorsler, Fabian Brosig and other contributors.
 *
 * Project Info:   http://descartes.tools/dql
 *
 * All rights reserved. This software is made available under the terms of the
 * Eclipse Public License (EPL) v1.0 as published by the Eclipse Foundation
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * This software is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the Eclipse Public License (EPL)
 * for more details.
 *
 * You should have received a copy of the Eclipse Public License (EPL)
 * along with this software; if not visit http://www.eclipse.org or write to
 * Eclipse Foundation, Inc., 308 SW First Avenue, Suite 110, Portland, 97204 USA
 * Email: license (at) eclipse.org
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
 * in the United States and other countries.]
 */
package tools.descartes.pavo.types;

import org.jfree.chart.ChartFactory;
import org.jfree.chart.JFreeChart;
import org.jfree.data.xy.XYSeries;
import org.jfree.data.xy.XYSeriesCollection;
import tools.descartes.pavo.result.AbstractQuantitativeResult;
import tools.descartes.pavo.result.ResultContainerPavo;
import tools.descartes.pavo.result.SeriesResultPavo;
import tools.descartes.pavo.result.ValueResultPavo;

public class ScatterPlot extends AbstractVisualizationType implements IVisualizationType {

	public ScatterPlot() {

	}

	public ScatterPlot(ResultContainerPavo resultN) {
		super(resultN);
	}

	@Override
	public JFreeChart visualize() {
		XYSeriesCollection dataset = new XYSeriesCollection();
		
		JFreeChart chart = ChartFactory.createScatterPlot("", "X", "Y", dataset);
		
		for (AbstractQuantitativeResult r : this.getResult().getResults()) {
			XYSeries series1 = new XYSeries(r.getQueryableElement());
			for (int j = 0; j < ((SeriesResultPavo) r).getXvalues().size(); j++) {
				series1.add(((SeriesResultPavo) r).getXvalues().get(j), ((SeriesResultPavo) r).getyvalues().get(j));
			}
			dataset.addSeries(series1);
		}
		return chart;

		
		
	}

	@Override
	public boolean canVisualize() {
		for (AbstractQuantitativeResult r : this.getResult().getResults()) {
			if (!(r instanceof ValueResultPavo) && !(r instanceof SeriesResultPavo)) {
				return false;
			}
		}
		return true;
	}

}