/**
 * ==============================================
 *  DQL : Descartes Query Language
 * ==============================================
 *
 * (c) Copyright 2014-2016, by Juergen Walter, Fabian Gorsler, Fabian Brosig and other contributors.
 *
 * Project Info:   http://descartes.tools/dql
 *
 * All rights reserved. This software is made available under the terms of the
 * Eclipse Public License (EPL) v1.0 as published by the Eclipse Foundation
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * This software is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the Eclipse Public License (EPL)
 * for more details.
 *
 * You should have received a copy of the Eclipse Public License (EPL)
 * along with this software; if not visit http://www.eclipse.org or write to
 * Eclipse Foundation, Inc., 308 SW First Avenue, Suite 110, Portland, 97204 USA
 * Email: license (at) eclipse.org
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
 * in the United States and other countries.]
 */
package tools.descartes.pavo.view;


import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.FlowLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import javax.swing.BorderFactory;
import javax.swing.BoxLayout;
import javax.swing.JButton;
import javax.swing.JComboBox;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JRadioButton;
import javax.swing.border.LineBorder;

import org.jfree.chart.ChartPanel;
import org.jfree.chart.JFreeChart;

public class View  {
	
	private JPanel frame = new JPanel(new BorderLayout());
	private JPanel visualizationPanel = new JPanel();
	private JPanel buttonPanel;
	
	private JButton changeButton;
	private JButton exportButton;;
	
	private ChartPanel chartPanel = new ChartPanel(null);
	
	
	private JComboBox<String> heatX;
	private JComboBox<String> heatY;
	private JComboBox<String> heatZ;
	private String actualHeatX;
	private String actualHeatY;
	private String actualHeatZ;
	private JPanel heatXPanel;
	private JPanel heatYPanel;
	private JPanel heatZPanel;
	boolean blockerHeat = false;
	

	private JRadioButton confidenceRadio;
	
	private JRadioButton minRadio;
	private JRadioButton maxRadio;
	private JRadioButton meanRadio;
	private JComboBox<String> DiagramSwitchTypes;
	
	public View()
	{
		BoxLayout layoutForViz = new BoxLayout(visualizationPanel, BoxLayout.Y_AXIS);
		visualizationPanel.setLayout(layoutForViz);
		frame.add(visualizationPanel, BorderLayout.CENTER);
		visualizationPanel.add(chartPanel);
		frame.setBorder(BorderFactory.createEmptyBorder(10, 10, 10, 10));
		frame.setVisible(true);

		buttonPanel = initializeButtons();
		updateCurrentXYZ();
		setActionListenerForHeatControls();
		//Controller muss erst die Comboboxen fillen und dann das update aufrufen 
		frame.add(buttonPanel, BorderLayout.SOUTH);
	}
	
	
	public void setActionListenerForHeatControls()
	{
		//Das gleiche was hiernach kommt auch noch für Y und Z 
		heatX.addActionListener(new ActionListener() {
			
			@Override
			public void actionPerformed(ActionEvent e) {
				if(blockerHeat == true)
				{
					
				}
				else
				{
				blockerHeat = true;
				String now = heatX.getSelectedItem().toString();
				if(heatY.getSelectedItem().toString().equals(now))
				{
					heatY.removeAllItems();
					heatY.addItem(actualHeatX);
					heatY.addItem(actualHeatY);
					heatY.addItem(actualHeatZ);
					updateCurrentXYZ();
					//Mache Combo Y leer und füge als erstes actualX hinzu und dann die anderen beiden 
				}
				else if(heatZ.getSelectedItem().equals(now))
				{
					heatZ.removeAllItems();
					heatZ.addItem(actualHeatX);
					heatZ.addItem(actualHeatZ);
					heatZ.addItem(actualHeatY);
					updateCurrentXYZ();
					//Mache Combo Y leer und füge als erstes actualX hinzu und dann die anderen beiden
				}	
				blockerHeat = false;
				}
			}
		});
		
		heatY.addActionListener(new ActionListener() {
			
			@Override
			public void actionPerformed(ActionEvent e) {
				if(blockerHeat == true)
				{
					
				}
				else
				{
					blockerHeat = true;
				String now = heatY.getSelectedItem().toString();
				if(heatX.getSelectedItem().toString().equals(now))
				{
					heatX.removeAllItems();
					heatX.addItem(actualHeatY);
					heatX.addItem(actualHeatX);
					heatX.addItem(actualHeatZ);
					updateCurrentXYZ();
					//Mache Combo Y leer und füge als erstes actualX hinzu und dann die anderen beiden 
				}
				else if(heatZ.getSelectedItem().equals(now))
				{
					heatZ.removeAllItems();
					heatZ.addItem(actualHeatY);
					heatZ.addItem(actualHeatZ);
					heatZ.addItem(actualHeatX);
					updateCurrentXYZ();
					//Mache Combo Y leer und füge als erstes actualX hinzu und dann die anderen beiden
				}
				blockerHeat = false;
			}
			}
		});
		
heatZ.addActionListener(new ActionListener() {
			
			@Override
			public void actionPerformed(ActionEvent e) {
				if(blockerHeat == true)
				{
					
				}
				else
				{
				blockerHeat = true;
				String now = heatZ.getSelectedItem().toString();
				if(heatX.getSelectedItem().toString().equals(now))
				{
					heatX.removeAllItems();
					heatX.addItem(actualHeatZ);
					heatX.addItem(actualHeatX);
					heatX.addItem(actualHeatY);
					updateCurrentXYZ();
					//Mache Combo Y leer und füge als erstes actualX hinzu und dann die anderen beiden 
				}
				else if(heatY.getSelectedItem().equals(now))
				{
					heatY.removeAllItems();
					heatY.addItem(actualHeatZ);
					heatY.addItem(actualHeatY);
					heatY.addItem(actualHeatX);
					updateCurrentXYZ();
					//Mache Combo Y leer und füge als erstes actualX hinzu und dann die anderen beiden
				}	
				blockerHeat = false;
			}
			}
		});
	}
	
	public void fillHeatCombos(String[] array)
	{
		if(array.length == 3 )
		{
			heatX.removeAllItems();
			heatX.addItem(array[0]);
			heatX.addItem(array[1]);
			heatX.addItem(array[2]);
			heatY.removeAllItems();
			heatY.addItem(array[1]);
			heatY.addItem(array[2]);
			heatY.addItem(array[0]);
			heatZ.removeAllItems();
			heatZ.addItem(array[2]);
			heatZ.addItem(array[0]);
			heatZ.addItem(array[1]);
		}
		else
		{
			System.out.println("Error at filling the ComboBox for HeatMaps");
		}
	}
	
	
	public void updateCurrentXYZ()
	{
		actualHeatX = heatX.getSelectedItem().toString();
		actualHeatY = heatY.getSelectedItem().toString();
		actualHeatZ = heatZ.getSelectedItem().toString();
	}
	
	
	public void resetAnalysesRadios()
	{
		this.getMinRadio().setSelected(false);
		this.getMaxRadio().setSelected(false);
		this.getMeanRadio().setSelected(false);
	}

	public void switchToHeat()
	{
		heatXPanel.setVisible(true);
		heatYPanel.setVisible(true);
		heatZPanel.setVisible(true);
		minRadio.setVisible(false);
		maxRadio.setVisible(false);
		meanRadio.setVisible(false);
	}
	
	public void switchToNormal()
	{
		heatXPanel.setVisible(false);
		heatYPanel.setVisible(false);
		heatZPanel.setVisible(false);
		minRadio.setVisible(true);
		maxRadio.setVisible(true);
		meanRadio.setVisible(true);
	}
	
	
	public void setActionListenerHeatX(ActionListener a )
	{
		heatX.addActionListener(a);
	}
	public void setActionListenerHeatY(ActionListener a )
	{
		heatY.addActionListener(a);
	}
	public void setActionListenerHeatZ(ActionListener a )
	{
		heatZ.addActionListener(a);
	}
	
	
	
	public void setActionListenerChangeButton(ActionListener a )
	{
		changeButton.addActionListener(a);
	}
	
	public void setActionListenerExportButton(ActionListener a )
	{
		exportButton.addActionListener(a);
	}
	
	public void setActionListenerConfidenceRadio(ActionListener a )
	{
		confidenceRadio.addActionListener(a);
	}
	public void setActionListenerMinRadio(ActionListener a )
	{
		minRadio.addActionListener(a);
	}
	public void setActionListenerMaxRadio(ActionListener a )
	{
		maxRadio.addActionListener(a);
	}
	public void setActionListenerMeanRadio(ActionListener a )
	{
		meanRadio.addActionListener(a);
	}
	
	public void addItemToCombo(String s)
	{
		DiagramSwitchTypes.addItem(s);
	}
	
	/**
	 * @return the buttonPanel
	 */
	public JPanel getButtonPanel() {
		return buttonPanel;
	}


	/**
	 * @param buttonPanel the buttonPanel to set
	 */
	public void setButtonPanel(JPanel buttonPanel) {
		this.buttonPanel = buttonPanel;
	}


	/**
	 * @return the changeButton
	 */
	public JButton getChangeButton() {
		return changeButton;
	}


	/**
	 * @param changeButton the changeButton to set
	 */
	public void setChangeButton(JButton changeButton) {
		this.changeButton = changeButton;
	}


	/**
	 * @return the exportButton
	 */
	public JButton getExportButton() {
		return exportButton;
	}


	/**
	 * @param exportButton the exportButton to set
	 */
	public void setExportButton(JButton exportButton) {
		this.exportButton = exportButton;
	}


	/**
	 * @return the confidenceRadio
	 */
	public JRadioButton getConfidenceRadio() {
		return confidenceRadio;
	}


	/**
	 * @param confidenceRadio the confidenceRadio to set
	 */
	public void setConfidenceRadio(JRadioButton confidenceRadio) {
		this.confidenceRadio = confidenceRadio;
	}


	/**
	 * @return the minRadio
	 */
	public JRadioButton getMinRadio() {
		return minRadio;
	}


	/**
	 * @param minRadio the minRadio to set
	 */
	public void setMinRadio(JRadioButton minRadio) {
		this.minRadio = minRadio;
	}
	
	


	/**
	 * @return the chartPanel
	 */
	public ChartPanel getChartPanel() {
		return chartPanel;
	}


	/**
	 * @param chartPanel the chartPanel to set
	 */
	public void setChartPanel(ChartPanel chartPanel) {
		this.chartPanel = chartPanel;
	}


	/**
	 * @return the maxRadio
	 */
	public JRadioButton getMaxRadio() {
		return maxRadio;
	}


	/**
	 * @param maxRadio the maxRadio to set
	 */
	public void setMaxRadio(JRadioButton maxRadio) {
		this.maxRadio = maxRadio;
	}


	/**
	 * @return the meanRadio
	 */
	public JRadioButton getMeanRadio() {
		return meanRadio;
	}


	/**
	 * @param meanRadio the meanRadio to set
	 */
	public void setMeanRadio(JRadioButton meanRadio) {
		this.meanRadio = meanRadio;
	}


	/**
	 * @return the diagramSwitchTypes
	 */
	public JComboBox<String> getDiagramSwitchTypes() {
		return DiagramSwitchTypes;
	}

	
	

	/**
	 * @param diagramSwitchTypes the diagramSwitchTypes to set
	 */
	public void setDiagramSwitchTypes(JComboBox<String> diagramSwitchTypes) {
		DiagramSwitchTypes = diagramSwitchTypes;
	}
	
	public JPanel initializeButtons()
	{
		JPanel analysisPanel = new JPanel();
		analysisPanel.setLayout(new BoxLayout(analysisPanel, BoxLayout.Y_AXIS));
		minRadio = new JRadioButton("Show Minimum");
		maxRadio = new JRadioButton("Show Maximum");	
		meanRadio = new JRadioButton("Show Mean");
		heatXPanel = new JPanel();
		heatXPanel.setLayout(new FlowLayout());
		heatYPanel = new JPanel();
		heatYPanel.setLayout(new FlowLayout());
		heatZPanel = new JPanel();
		heatZPanel.setLayout(new FlowLayout());
		heatXPanel.add(new JLabel("X:"));
		heatYPanel.add(new JLabel("Y:"));
		heatZPanel.add(new JLabel("Z:"));
		heatX = new JComboBox<String>();
		heatY = new JComboBox<String>();
		heatZ = new JComboBox<String>();
		heatX.setToolTipText("X Axis Series");
		heatY.setToolTipText("Y Axis Series");
		heatZ.setToolTipText("Z Axis Series");
		
		//Hier nicht diese Namen sondern die namen der resourcen der über controller einfügen
		heatX.addItem("Series 1");
		heatX.addItem("Series 2");
		heatX.addItem("Series 3");
		
		heatY.addItem("Series 2");
		heatY.addItem("Series 3");
		heatY.addItem("Series 1");
		
		heatZ.addItem("Series 3");
		heatZ.addItem("Series 1");
		heatZ.addItem("Series 2");
		
		heatXPanel.setVisible(false);
		heatYPanel.setVisible(false);
		heatZPanel.setVisible(false);
		heatXPanel.add(heatX);
		heatYPanel.add(heatY);
		heatZPanel.add(heatZ);
		
		analysisPanel.add(minRadio);
		analysisPanel.add(maxRadio);
		analysisPanel.add(meanRadio);
		analysisPanel.add(heatXPanel);
		analysisPanel.add(heatYPanel);
		analysisPanel.add(heatZPanel);

		confidenceRadio = new JRadioButton("confidence intervals");
		
		changeButton = new JButton("Switch Diagram");
		
		exportButton = new JButton("Export Diagram");
		

		DiagramSwitchTypes = new JComboBox<String>();
		JPanel buttons = new JPanel();
		buttons.add(changeButton);
		buttons.add(DiagramSwitchTypes);
		buttons.add(confidenceRadio);
		buttons.add(exportButton);
		buttons.add(analysisPanel);

		return buttons;
	}
	
	public JPanel getCompletePanel() {
		frame.validate();
		return frame;
	}
	
	public void setStringResult(String s)
	{
		JLabel labelZahl = new JLabel(s);
		labelZahl.setBackground(Color.WHITE);
		labelZahl.setOpaque(true);
		visualizationPanel.add(labelZahl);
		visualizationPanel.add(new JLabel("    "));
	}
	
	public void setError()
	{
		JLabel error = new JLabel();

		error.setText(
				"PAVO is not able to visualize this result, sorry!");
		error.setBorder(new LineBorder(Color.RED, 5, true));
		visualizationPanel.add(error, BorderLayout.CENTER);
	}
	
	public void updateChart(JFreeChart chart) {
		
	visualizationPanel.remove(chartPanel);
	chartPanel = new ChartPanel(chart);
	visualizationPanel.add(chartPanel, BorderLayout.CENTER);
	visualizationPanel.repaint();
	visualizationPanel.validate();
	visualizationPanel.setVisible(true);

}

	/**
	 * @return the heatX
	 */
	public JComboBox<String> getHeatX() {
		return heatX;
	}

	/**
	 * @param heatX the heatX to set
	 */
	public void setHeatX(JComboBox<String> heatX) {
		this.heatX = heatX;
	}

	/**
	 * @return the heatY
	 */
	public JComboBox<String> getHeatY() {
		return heatY;
	}

	/**
	 * @param heatY the heatY to set
	 */
	public void setHeatY(JComboBox<String> heatY) {
		this.heatY = heatY;
	}

	/**
	 * @return the heatZ
	 */
	public JComboBox<String> getHeatZ() {
		return heatZ;
	}

	/**
	 * @param heatZ the heatZ to set
	 */
	public void setHeatZ(JComboBox<String> heatZ) {
		this.heatZ = heatZ;
	}
	
	
	

}